@@ -1,7 +1,7 @@
 /*
  * $RCSfile: branch.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.14 $ $Date: 2006/04/23 09:56:12 $ $Author: christian $
+ * @version $Revision: 1.20 $ $Date: 2007/05/26 21:19:57 $ $Author: christian $
  * @author Rolf Holzmueller <rolf.holzmueller@gmx.de>
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
@@ -28,11 +28,12 @@
 #ifndef BRANCH_SOURCE
 #define BRANCH_SOURCE
 
-#include "../globals/constants/abstraction_constants.c"
-#include "../globals/constants/boolean_constants.c"
-#include "../globals/constants/log_constants.c"
-#include "../globals/constants/name_constants.c"
-#include "../globals/constants/structure_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../globals/constants/boolean/boolean_constants.c"
+#include "../globals/constants/log/log_message_constants.c"
+#include "../globals/constants/cybol/cybol_name_constants.c"
+#include "../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../globals/constants/pointer/pointer_constants.c"
 #include "../globals/logger/logger.c"
 #include "../memoriser/accessor/compound_accessor.c"
 #include "../memoriser/array.c"
@@ -60,8 +61,8 @@ void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
  * @param p4 the signal memory
  * @param p5 the signal memory count
  * @param p6 the signal memory size
- * @param p7 the signal memory blocked flag
- * @param p8 the interrupt request flag
+ * @param p7 the interrupt request flag
+ * @param p8 the signal memory mutex
  * @param p9 the shutdown flag
  * @param p10 the parameters
  * @param p11 the parameters count
@@ -74,48 +75,50 @@ void branch(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
     log_message_debug("\n\n");
     log_message_debug("Branch program flow.");
 
-    // The criterion abstraction.
-    void** ca = &NULL_POINTER;
-    void** cac = &NULL_POINTER;
-    void** cas = &NULL_POINTER;
-    // The criterion model.
-    void** cm = &NULL_POINTER;
-    void** cmc = &NULL_POINTER;
-    void** cms = &NULL_POINTER;
-    // The criterion details.
-    void** cd = &NULL_POINTER;
-    void** cdc = &NULL_POINTER;
-    void** cds = &NULL_POINTER;
-
-    // The true model abstraction.
-    void** ta = &NULL_POINTER;
-    void** tac = &NULL_POINTER;
-    void** tas = &NULL_POINTER;
-    // The true model model.
-    void** tm = &NULL_POINTER;
-    void** tmc = &NULL_POINTER;
-    void** tms = &NULL_POINTER;
-    // The true model details.
-    void** td = &NULL_POINTER;
-    void** tdc = &NULL_POINTER;
-    void** tds = &NULL_POINTER;
-
-    // The false model abstraction.
-    void** fa = &NULL_POINTER;
-    void** fac = &NULL_POINTER;
-    void** fas = &NULL_POINTER;
-    // The false model model.
-    void** fm = &NULL_POINTER;
-    void** fmc = &NULL_POINTER;
-    void** fms = &NULL_POINTER;
-    // The false model details.
-    void** fd = &NULL_POINTER;
-    void** fdc = &NULL_POINTER;
-    void** fds = &NULL_POINTER;
+    // The criterion name, abstraction, model, details.
+    void** cn = NULL_POINTER;
+    void** cnc = NULL_POINTER;
+    void** cns = NULL_POINTER;
+    void** ca = NULL_POINTER;
+    void** cac = NULL_POINTER;
+    void** cas = NULL_POINTER;
+    void** cm = NULL_POINTER;
+    void** cmc = NULL_POINTER;
+    void** cms = NULL_POINTER;
+    void** cd = NULL_POINTER;
+    void** cdc = NULL_POINTER;
+    void** cds = NULL_POINTER;
+    // The true model name, abstraction, model, details.
+    void** tn = NULL_POINTER;
+    void** tnc = NULL_POINTER;
+    void** tns = NULL_POINTER;
+    void** ta = NULL_POINTER;
+    void** tac = NULL_POINTER;
+    void** tas = NULL_POINTER;
+    void** tm = NULL_POINTER;
+    void** tmc = NULL_POINTER;
+    void** tms = NULL_POINTER;
+    void** td = NULL_POINTER;
+    void** tdc = NULL_POINTER;
+    void** tds = NULL_POINTER;
+    // The false model name, abstraction, model, details.
+    void** fn = NULL_POINTER;
+    void** fnc = NULL_POINTER;
+    void** fns = NULL_POINTER;
+    void** fa = NULL_POINTER;
+    void** fac = NULL_POINTER;
+    void** fas = NULL_POINTER;
+    void** fm = NULL_POINTER;
+    void** fmc = NULL_POINTER;
+    void** fms = NULL_POINTER;
+    void** fd = NULL_POINTER;
+    void** fdc = NULL_POINTER;
+    void** fds = NULL_POINTER;
 
     // Get criterion.
     get_universal_compound_element_by_name(p10, p11,
         (void*) CRITERION_NAME, (void*) CRITERION_NAME_COUNT,
+        (void*) &cn, (void*) &cnc, (void*) &cns,
         (void*) &ca, (void*) &cac, (void*) &cas,
         (void*) &cm, (void*) &cmc, (void*) &cms,
         (void*) &cd, (void*) &cdc, (void*) &cds,
@@ -124,6 +127,7 @@ void branch(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
     // Get true model.
     get_universal_compound_element_by_name(p10, p11,
         (void*) FALSE_MODEL_NAME, (void*) FALSE_MODEL_NAME_COUNT,
+        (void*) &tn, (void*) &tnc, (void*) &tns,
         (void*) &ta, (void*) &tac, (void*) &tas,
         (void*) &tm, (void*) &tmc, (void*) &tms,
         (void*) &td, (void*) &tdc, (void*) &tds,
@@ -132,40 +136,41 @@ void branch(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
     // Get false model.
     get_universal_compound_element_by_name(p10, p11,
         (void*) TRUE_MODEL_NAME, (void*) TRUE_MODEL_NAME_COUNT,
+        (void*) &fn, (void*) &fnc, (void*) &fns,
         (void*) &fa, (void*) &fac, (void*) &fas,
         (void*) &fm, (void*) &fmc, (void*) &fms,
         (void*) &fd, (void*) &fdc, (void*) &fds,
         p1, p2);
 
-    if ((*ca != NULL_POINTER)
-        && (*cac != NULL_POINTER)
-        && (*cas != NULL_POINTER)
-        && (*cm != NULL_POINTER)
-        && (*cmc != NULL_POINTER)
-        && (*cms != NULL_POINTER)
-        && (*cd != NULL_POINTER)
-        && (*cdc != NULL_POINTER)
-        && (*cds != NULL_POINTER)
+    if ((*ca != *NULL_POINTER)
+        && (*cac != *NULL_POINTER)
+        && (*cas != *NULL_POINTER)
+        && (*cm != *NULL_POINTER)
+        && (*cmc != *NULL_POINTER)
+        && (*cms != *NULL_POINTER)
+        && (*cd != *NULL_POINTER)
+        && (*cdc != *NULL_POINTER)
+        && (*cds != *NULL_POINTER)
         // Check true model.
-        && (*ta != NULL_POINTER)
-        && (*tac != NULL_POINTER)
-        && (*tas != NULL_POINTER)
-        && (*tm != NULL_POINTER)
-        && (*tmc != NULL_POINTER)
-        && (*tms != NULL_POINTER)
-        && (*td != NULL_POINTER)
-        && (*tdc != NULL_POINTER)
-        && (*tds != NULL_POINTER)
+        && (*ta != *NULL_POINTER)
+        && (*tac != *NULL_POINTER)
+        && (*tas != *NULL_POINTER)
+        && (*tm != *NULL_POINTER)
+        && (*tmc != *NULL_POINTER)
+        && (*tms != *NULL_POINTER)
+        && (*td != *NULL_POINTER)
+        && (*tdc != *NULL_POINTER)
+        && (*tds != *NULL_POINTER)
         // check false model
-        && (*fa != NULL_POINTER)
-        && (*fac != NULL_POINTER)
-        && (*fas != NULL_POINTER)
-        && (*fm != NULL_POINTER)
-        && (*fmc != NULL_POINTER)
-        && (*fms != NULL_POINTER)
-        && (*fd != NULL_POINTER)
-        && (*fdc != NULL_POINTER)
-        && (*fds != NULL_POINTER)) {
+        && (*fa != *NULL_POINTER)
+        && (*fac != *NULL_POINTER)
+        && (*fas != *NULL_POINTER)
+        && (*fm != *NULL_POINTER)
+        && (*fmc != *NULL_POINTER)
+        && (*fms != *NULL_POINTER)
+        && (*fd != *NULL_POINTER)
+        && (*fdc != *NULL_POINTER)
+        && (*fds != *NULL_POINTER)) {
 
         // The comparison result.
         int r = 0;
@@ -176,7 +181,7 @@ void branch(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
         if (r == 1) {
 
             // The criterion.
-            void* c = NULL_POINTER;
+            void* c = *NULL_POINTER;
 
             // Get criterion.
             get_array_elements(*cm, (void*) PRIMITIVE_VALUE_INDEX, (void*) &c, (void*) INTEGER_ARRAY);
