@@ -1,7 +1,7 @@
 /*
  * $RCSfile: compare.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.10 $ $Date: 2006/04/23 09:56:12 $ $Author: christian $
+ * @version $Revision: 1.15 $ $Date: 2007/05/26 21:19:57 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -32,10 +32,11 @@
 #include "../applicator/compare/compare_greater_or_equal.c"
 #include "../applicator/compare/compare_smaller.c"
 #include "../applicator/compare/compare_smaller_or_equal.c"
-#include "../globals/constants/abstraction_constants.c"
-#include "../globals/constants/log_constants.c"
-#include "../globals/constants/model_constants.c"
-#include "../globals/constants/name_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../globals/constants/log/log_message_constants.c"
+#include "../globals/constants/cybol/cybol_model_constants.c"
+#include "../globals/constants/cybol/cybol_name_constants.c"
+#include "../globals/constants/pointer/pointer_constants.c"
 #include "../globals/logger/logger.c"
 #include "../memoriser/accessor/compound_accessor.c"
 #include "../memoriser/array.c"
@@ -59,61 +60,63 @@ void compare(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
     log_message_debug("Compare two parameters.");
 
-    // The comparison abstraction.
-    void** ca = &NULL_POINTER;
-    void** cac = &NULL_POINTER;
-    void** cas = &NULL_POINTER;
-    // The comparison model.
-    void** cm = &NULL_POINTER;
-    void** cmc = &NULL_POINTER;
-    void** cms = &NULL_POINTER;
-    // The comparison details.
-    void** cd = &NULL_POINTER;
-    void** cdc = &NULL_POINTER;
-    void** cds = &NULL_POINTER;
-
-    // The left side abstraction.
-    void** lsa = &NULL_POINTER;
-    void** lsac = &NULL_POINTER;
-    void** lsas = &NULL_POINTER;
-    // The left side model.
-    void** lsm = &NULL_POINTER;
-    void** lsmc = &NULL_POINTER;
-    void** lsms = &NULL_POINTER;
-    // The left side details.
-    void** lsd = &NULL_POINTER;
-    void** lsdc = &NULL_POINTER;
-    void** lsds = &NULL_POINTER;
-
-    // The right side abstraction.
-    void** rsa = &NULL_POINTER;
-    void** rsac = &NULL_POINTER;
-    void** rsas = &NULL_POINTER;
-    // The right side model.
-    void** rsm = &NULL_POINTER;
-    void** rsmc = &NULL_POINTER;
-    void** rsms = &NULL_POINTER;
-    // The right side details.
-    void** rsd = &NULL_POINTER;
-    void** rsdc = &NULL_POINTER;
-    void** rsds = &NULL_POINTER;
-
-    // The result abstraction.
-    void** ra = &NULL_POINTER;
-    void** rac = &NULL_POINTER;
-    void** ras = &NULL_POINTER;
-    // The result model.
-    void** rm = &NULL_POINTER;
-    void** rmc = &NULL_POINTER;
-    void** rms = &NULL_POINTER;
-    // The result details.
-    void** rd = &NULL_POINTER;
-    void** rdc = &NULL_POINTER;
-    void** rds = &NULL_POINTER;
+    // The comparison name, abstraction, model, details.
+    void** cn = NULL_POINTER;
+    void** cnc = NULL_POINTER;
+    void** cns = NULL_POINTER;
+    void** ca = NULL_POINTER;
+    void** cac = NULL_POINTER;
+    void** cas = NULL_POINTER;
+    void** cm = NULL_POINTER;
+    void** cmc = NULL_POINTER;
+    void** cms = NULL_POINTER;
+    void** cd = NULL_POINTER;
+    void** cdc = NULL_POINTER;
+    void** cds = NULL_POINTER;
+    // The left side name, abstraction, model, details.
+    void** lsn = NULL_POINTER;
+    void** lsnc = NULL_POINTER;
+    void** lsns = NULL_POINTER;
+    void** lsa = NULL_POINTER;
+    void** lsac = NULL_POINTER;
+    void** lsas = NULL_POINTER;
+    void** lsm = NULL_POINTER;
+    void** lsmc = NULL_POINTER;
+    void** lsms = NULL_POINTER;
+    void** lsd = NULL_POINTER;
+    void** lsdc = NULL_POINTER;
+    void** lsds = NULL_POINTER;
+    // The right side name, abstraction, model, details.
+    void** rsn = NULL_POINTER;
+    void** rsnc = NULL_POINTER;
+    void** rsns = NULL_POINTER;
+    void** rsa = NULL_POINTER;
+    void** rsac = NULL_POINTER;
+    void** rsas = NULL_POINTER;
+    void** rsm = NULL_POINTER;
+    void** rsmc = NULL_POINTER;
+    void** rsms = NULL_POINTER;
+    void** rsd = NULL_POINTER;
+    void** rsdc = NULL_POINTER;
+    void** rsds = NULL_POINTER;
+    // The result name, abstraction, model, details.
+    void** rn = NULL_POINTER;
+    void** rnc = NULL_POINTER;
+    void** rns = NULL_POINTER;
+    void** ra = NULL_POINTER;
+    void** rac = NULL_POINTER;
+    void** ras = NULL_POINTER;
+    void** rm = NULL_POINTER;
+    void** rmc = NULL_POINTER;
+    void** rms = NULL_POINTER;
+    void** rd = NULL_POINTER;
+    void** rdc = NULL_POINTER;
+    void** rds = NULL_POINTER;
 
     // Get comparison.
     get_universal_compound_element_by_name(p0, p1,
         (void*) COMPARISON_NAME, (void*) COMPARISON_NAME_COUNT,
+        (void*) &cn, (void*) &cnc, (void*) &cns,
         (void*) &ca, (void*) &cac, (void*) &cas,
         (void*) &cm, (void*) &cmc, (void*) &cms,
         (void*) &cd, (void*) &cdc, (void*) &cds,
@@ -122,6 +125,7 @@ void compare(void* p0, void* p1, void* p2, void* p3, void* p4) {
     // Get left side.
     get_universal_compound_element_by_name(p0, p1,
         (void*) LEFT_SIDE_NAME, (void*) LEFT_SIDE_NAME_COUNT,
+        (void*) &lsn, (void*) &lsnc, (void*) &lsns,
         (void*) &lsa, (void*) &lsac, (void*) &lsas,
         (void*) &lsm, (void*) &lsmc, (void*) &lsms,
         (void*) &lsd, (void*) &lsdc, (void*) &lsds,
@@ -130,6 +134,7 @@ void compare(void* p0, void* p1, void* p2, void* p3, void* p4) {
     // Get right side.
     get_universal_compound_element_by_name(p0, p1,
         (void*) RIGHT_SIDE_NAME, (void*) RIGHT_SIDE_NAME_COUNT,
+        (void*) &rsn, (void*) &rsnc, (void*) &rsns,
         (void*) &rsa, (void*) &rsac, (void*) &rsas,
         (void*) &rsm, (void*) &rsmc, (void*) &rsms,
         (void*) &rsd, (void*) &rsdc, (void*) &rsds,
@@ -138,6 +143,7 @@ void compare(void* p0, void* p1, void* p2, void* p3, void* p4) {
     // Get result.
     get_universal_compound_element_by_name(p0, p1,
         (void*) RESULT_NAME, (void*) RESULT_NAME_COUNT,
+        (void*) &rn, (void*) &rnc, (void*) &rns,
         (void*) &ra, (void*) &rac, (void*) &ras,
         (void*) &rm, (void*) &rmc, (void*) &rms,
         (void*) &rd, (void*) &rdc, (void*) &rds,
