@@ -1,7 +1,7 @@
 /*
  * $RCSfile: compare_equal.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,17 +20,18 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.6 $ $Date: 2006/04/20 22:36:09 $ $Author: christian $
+ * @version $Revision: 1.10 $ $Date: 2007/05/26 21:19:57 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef COMPARE_EQUAL_SOURCE
 #define COMPARE_EQUAL_SOURCE
 
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/boolean_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/boolean/boolean_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/array.c"
 
@@ -82,13 +83,13 @@ void compare_equal(void* p0, void* p1, void* p2,
     void* p21, void* p22, void* p23,
     void* p24, void* p25, void* p26) {
 
-    if (p21 != NULL_POINTER) {
+    if (p21 != *NULL_POINTER) {
 
         int* rm = (int*) p21;
 
-        if (p12 != NULL_POINTER) {
+        if (p12 != *NULL_POINTER) {
 
-            if (p3 != NULL_POINTER) {
+            if (p3 != *NULL_POINTER) {
 
                 log_message_debug("Compare if parameters are equal.");
 
