@@ -1,7 +1,7 @@
 /*
  * $RCSfile: copy.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.19 $ $Date: 2006/06/18 14:57:34 $ $Author: christian $
+ * @version $Revision: 1.24 $ $Date: 2007/05/26 21:19:57 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -29,9 +29,10 @@
 
 #include "../applicator/copy/copy_character_vector.c"
 #include "../applicator/copy/copy_integer_vector.c"
-#include "../globals/constants/abstraction_constants.c"
-#include "../globals/constants/log_constants.c"
-#include "../globals/constants/name_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../globals/constants/log/log_message_constants.c"
+#include "../globals/constants/cybol/cybol_name_constants.c"
+#include "../globals/constants/pointer/pointer_constants.c"
 #include "../globals/logger/logger.c"
 #include "../memoriser/accessor/compound_accessor.c"
 #include "../memoriser/array.c"
@@ -49,48 +50,50 @@ void copy(void* p0, int* p1, void* p2, void* p3, void* p4) {
 
     log_message_debug("Copy primitive model.");
 
-    // The source abstraction.
-    void** sa = &NULL_POINTER;
-    void** sac = &NULL_POINTER;
-    void** sas = &NULL_POINTER;
-    // The source model.
-    void** sm = &NULL_POINTER;
-    void** smc = &NULL_POINTER;
-    void** sms = &NULL_POINTER;
-    // The source details.
-    void** sd = &NULL_POINTER;
-    void** sdc = &NULL_POINTER;
-    void** sds = &NULL_POINTER;
-
-    // The destination abstraction.
-    void** da = &NULL_POINTER;
-    void** dac = &NULL_POINTER;
-    void** das = &NULL_POINTER;
-    // The destination model.
-    void** dm = &NULL_POINTER;
-    void** dmc = &NULL_POINTER;
-    void** dms = &NULL_POINTER;
-    // The destination details.
-    void** dd = &NULL_POINTER;
-    void** ddc = &NULL_POINTER;
-    void** dds = &NULL_POINTER;
-
-    // The abstraction abstraction.
-    void** aa = &NULL_POINTER;
-    void** aac = &NULL_POINTER;
-    void** aas = &NULL_POINTER;
-    // The abstraction model.
-    void** am = &NULL_POINTER;
-    void** amc = &NULL_POINTER;
-    void** ams = &NULL_POINTER;
-    // The abstraction details.
-    void** ad = &NULL_POINTER;
-    void** adc = &NULL_POINTER;
-    void** ads = &NULL_POINTER;
+    // The source name, abstraction, model, details.
+    void** sn = NULL_POINTER;
+    void** snc = NULL_POINTER;
+    void** sns = NULL_POINTER;
+    void** sa = NULL_POINTER;
+    void** sac = NULL_POINTER;
+    void** sas = NULL_POINTER;
+    void** sm = NULL_POINTER;
+    void** smc = NULL_POINTER;
+    void** sms = NULL_POINTER;
+    void** sd = NULL_POINTER;
+    void** sdc = NULL_POINTER;
+    void** sds = NULL_POINTER;
+    // The destination name, abstraction, model, details.
+    void** dn = NULL_POINTER;
+    void** dnc = NULL_POINTER;
+    void** dns = NULL_POINTER;
+    void** da = NULL_POINTER;
+    void** dac = NULL_POINTER;
+    void** das = NULL_POINTER;
+    void** dm = NULL_POINTER;
+    void** dmc = NULL_POINTER;
+    void** dms = NULL_POINTER;
+    void** dd = NULL_POINTER;
+    void** ddc = NULL_POINTER;
+    void** dds = NULL_POINTER;
+    // The abstraction name, abstraction, model, details.
+    void** an = NULL_POINTER;
+    void** anc = NULL_POINTER;
+    void** ans = NULL_POINTER;
+    void** aa = NULL_POINTER;
+    void** aac = NULL_POINTER;
+    void** aas = NULL_POINTER;
+    void** am = NULL_POINTER;
+    void** amc = NULL_POINTER;
+    void** ams = NULL_POINTER;
+    void** ad = NULL_POINTER;
+    void** adc = NULL_POINTER;
+    void** ads = NULL_POINTER;
 
     // Get source.
     get_universal_compound_element_by_name(p0, p1,
         (void*) COPY_SOURCE_NAME, (void*) COPY_SOURCE_NAME_COUNT,
+        (void*) &sn, (void*) &snc, (void*) &sns,
         (void*) &sa, (void*) &sac, (void*) &sas,
         (void*) &sm, (void*) &smc, (void*) &sms,
         (void*) &sd, (void*) &sdc, (void*) &sds,
@@ -99,6 +102,7 @@ void copy(void* p0, int* p1, void* p2, void* p3, void* p4) {
     // Get destination.
     get_universal_compound_element_by_name(p0, p1,
         (void*) COPY_DESTINATION_NAME, (void*) COPY_DESTINATION_NAME_COUNT,
+        (void*) &dn, (void*) &dnc, (void*) &dns,
         (void*) &da, (void*) &dac, (void*) &das,
         (void*) &dm, (void*) &dmc, (void*) &dms,
         (void*) &dd, (void*) &ddc, (void*) &dds,
@@ -107,6 +111,7 @@ void copy(void* p0, int* p1, void* p2, void* p3, void* p4) {
     // Get abstraction.
     get_universal_compound_element_by_name(p0, p1,
         (void*) COPY_ABSTRACTION_NAME, (void*) COPY_ABSTRACTION_NAME_COUNT,
+        (void*) &an, (void*) &anc, (void*) &ans,
         (void*) &aa, (void*) &aac, (void*) &aas,
         (void*) &am, (void*) &amc, (void*) &ams,
         (void*) &ad, (void*) &adc, (void*) &ads,
