@@ -1,7 +1,7 @@
 /*
  * $RCSfile: destroy.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,16 +22,17 @@
  *
  * This file destroys a transient model to a persistent model.
  *
- * @version $Revision: 1.18 $ $Date: 2006/06/20 16:16:29 $ $Author: christian $
+ * @version $Revision: 1.24 $ $Date: 2007/05/26 21:19:57 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef DESTROY_SOURCE
 #define DESTROY_SOURCE
 
-#include "../globals/constants/abstraction_constants.c"
-#include "../globals/constants/log_constants.c"
-#include "../globals/constants/name_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../globals/constants/log/log_message_constants.c"
+#include "../globals/constants/cybol/cybol_name_constants.c"
+#include "../globals/constants/pointer/pointer_constants.c"
 #include "../globals/logger/logger.c"
 #include "../memoriser/accessor/compound_accessor.c"
 #include "../memoriser/array.c"
@@ -74,7 +75,7 @@ void destroy_model(void** model, void* model_count, void* model_size,
  */
 void check_compound_model(void* p0, void* p1, void* p2) {
 
-    if (p0 != NULL_POINTER) {
+    if (p0 != *NULL_POINTER) {
 
         int* p = (int*) p0;
 
@@ -117,30 +118,30 @@ void destroy_compound_model(void** model, void* model_count, void* model_size,
 
     //das gesamte Compound durchgehen und f?r jedes Element im Compound wieder
     //destroy model aufrufen
-    if ((model != NULL_POINTER)
-        && (model_count != NULL_POINTER)
-        && (model_size != NULL_POINTER)
-        && (model_abstr != NULL_POINTER)
-        && (model_abstr_count != NULL_POINTER)) {
+    if ((model != *NULL_POINTER)
+        && (model_count != *NULL_POINTER)
+        && (model_size != *NULL_POINTER)
+        && (model_abstr != *NULL_POINTER)
+        && (model_abstr_count != *NULL_POINTER)) {
 
         int compound_counter = 0;
 
         // The element name.
-        void** en = &NULL_POINTER;
-        void** enc = &NULL_POINTER;
-        void** ens = &NULL_POINTER;
+        void** en = NULL_POINTER;
+        void** enc = NULL_POINTER;
+        void** ens = NULL_POINTER;
         // The element abstraction.
-        void** ea = &NULL_POINTER;
-        void** eac = &NULL_POINTER;
-        void** eas = &NULL_POINTER;
+        void** ea = NULL_POINTER;
+        void** eac = NULL_POINTER;
+        void** eas = NULL_POINTER;
         // The element model.
-        void** em = &NULL_POINTER;
-        void** emc = &NULL_POINTER;
-        void** ems = &NULL_POINTER;
+        void** em = NULL_POINTER;
+        void** emc = NULL_POINTER;
+        void** ems = NULL_POINTER;
         // The element details.
-        void** ed = &NULL_POINTER;
-        void** edc = &NULL_POINTER;
-        void** eds = &NULL_POINTER;
+        void** ed = NULL_POINTER;
+        void** edc = NULL_POINTER;
+        void** eds = NULL_POINTER;
 
         while (1) {
 
@@ -149,14 +150,9 @@ void destroy_compound_model(void** model, void* model_count, void* model_size,
                 break;
             }
 
-            // Get element name.
-            get_compound_element_name_by_index(*model, model_count,
-                (void*) &compound_counter,
-                (void*) &en, (void*) &enc, (void*) &ens);
-
             // Get element.
-            get_compound_element_by_index(*model, model_count,
-                (void*) &compound_counter,
+            get_compound_element_by_index(*model, model_count, (void*) &compound_counter,
+                (void*) &en, (void*) &enc, (void*) &ens,
                 (void*) &ea, (void*) &eac, (void*) &eas,
                 (void*) &em, (void*) &emc, (void*) &ems,
                 (void*) &ed, (void*) &edc, (void*) &eds);
@@ -228,43 +224,47 @@ void destroy(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
     log_message_debug("Destroy knowledge model.");
 
-    // The knowledge model name abstraction.
-    void** na = &NULL_POINTER;
-    void** nac = &NULL_POINTER;
-    void** nas = &NULL_POINTER;
-    // The knowledge model name model.
-    void** nm = &NULL_POINTER;
-    void** nmc = &NULL_POINTER;
-    void** nms = &NULL_POINTER;
-    // The knowledge model name details.
-    void** nd = &NULL_POINTER;
-    void** ndc = &NULL_POINTER;
-    void** nds = &NULL_POINTER;
+    // The knowledge model name name, abstraction, model, details.
+    void** nn = NULL_POINTER;
+    void** nnc = NULL_POINTER;
+    void** nns = NULL_POINTER;
+    void** na = NULL_POINTER;
+    void** nac = NULL_POINTER;
+    void** nas = NULL_POINTER;
+    void** nm = NULL_POINTER;
+    void** nmc = NULL_POINTER;
+    void** nms = NULL_POINTER;
+    void** nd = NULL_POINTER;
+    void** ndc = NULL_POINTER;
+    void** nds = NULL_POINTER;
 
     // Get knowledge model name.
     get_universal_compound_element_by_name(p0, p1,
         (void*) DESTROY_MODEL_NAME, (void*) DESTROY_MODEL_NAME_COUNT,
+        (void*) &nn, (void*) &nnc, (void*) &nns,
         (void*) &na, (void*) &nac, (void*) &nas,
         (void*) &nm, (void*) &nmc, (void*) &nms,
         (void*) &nd, (void*) &ndc, (void*) &nds,
         p2, p3);
 
-    // The knowledge model abstraction.
-    void** ea = &NULL_POINTER;
-    void** eac = &NULL_POINTER;
-    void** eas = &NULL_POINTER;
-    // The knowledge model model.
-    void** em = &NULL_POINTER;
-    void** emc = &NULL_POINTER;
-    void** ems = &NULL_POINTER;
-    // The knowledge model details.
-    void** ed = &NULL_POINTER;
-    void** edc = &NULL_POINTER;
-    void** eds = &NULL_POINTER;
+    // The knowledge model name, abstraction, model, details.
+    void** en = NULL_POINTER;
+    void** enc = NULL_POINTER;
+    void** ens = NULL_POINTER;
+    void** ea = NULL_POINTER;
+    void** eac = NULL_POINTER;
+    void** eas = NULL_POINTER;
+    void** em = NULL_POINTER;
+    void** emc = NULL_POINTER;
+    void** ems = NULL_POINTER;
+    void** ed = NULL_POINTER;
+    void** edc = NULL_POINTER;
+    void** eds = NULL_POINTER;
 
     // Get knowledge model.
     get_universal_compound_element_by_name(p2, p3,
         (void*) *nm, (void*) *nmc,
+        (void*) &en, (void*) &enc, (void*) &ens,
         (void*) &ea, (void*) &eac, (void*) &eas,
         (void*) &em, (void*) &emc, (void*) &ems,
         (void*) &ed, (void*) &edc, (void*) &eds,
@@ -274,7 +274,7 @@ void destroy(void* p0, void* p1, void* p2, void* p3, void* p4) {
     destroy_model(em, *emc, *ems , *ea, *eac);
 
     // Remove knowledge model from given whole model.
-    remove_compound_element_by_name(p2, p3, p4, NULL_POINTER, NULL_POINTER, NULL_POINTER, (void*) *nm, (void*) *nmc);
+    remove_compound_element_by_name(p2, p3, p4, *NULL_POINTER, *NULL_POINTER, *NULL_POINTER, (void*) *nm, (void*) *nmc);
 }
 
 /* DESTROY_SOURCE */
