@@ -1,7 +1,7 @@
 /*
  * $RCSfile: loop.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -22,18 +22,19 @@
  *
  * this handel a loop
  *
- * @version $Revision: 1.14 $ $Date: 2006/04/23 09:56:12 $ $Author: christian $
+ * @version $Revision: 1.20 $ $Date: 2007/05/26 21:19:57 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef LOOP_SOURCE
 #define LOOP_SOURCE
 
-#include "../globals/constants/abstraction_constants.c"
-#include "../globals/constants/boolean_constants.c"
-#include "../globals/constants/log_constants.c"
-#include "../globals/constants/name_constants.c"
-#include "../globals/constants/structure_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../globals/constants/boolean/boolean_constants.c"
+#include "../globals/constants/log/log_message_constants.c"
+#include "../globals/constants/cybol/cybol_name_constants.c"
+#include "../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../globals/constants/pointer/pointer_constants.c"
 #include "../globals/logger/logger.c"
 #include "../memoriser/accessor/compound_accessor.c"
 #include "../memoriser/array.c"
@@ -60,8 +61,8 @@ void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
  * @param p4 the signal memory
  * @param p5 the signal memory count
  * @param p6 the signal memory size
- * @param p7 the signal memory blocked flag
- * @param p8 the interrupt request flag
+ * @param p7 the interrupt request flag
+ * @param p8 the signal memory mutex
  * @param p9 the shutdown flag
  * @param p10 the parameters
  * @param p11 the parameters count
@@ -74,35 +75,37 @@ void loop(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6,
     log_message_debug("\n\n");
     log_message_debug("Loop program flow.");
 
-    // The break flag abstraction.
-    void** bfa = &NULL_POINTER;
-    void** bfac = &NULL_POINTER;
-    void** bfas = &NULL_POINTER;
-    // The break flag model.
-    void** bfm = &NULL_POINTER;
-    void** bfmc = &NULL_POINTER;
-    void** bfms = &NULL_POINTER;
-    // The break flag details.
-    void** bfd = &NULL_POINTER;
-    void** bfdc = &NULL_POINTER;
-    void** bfds = &NULL_POINTER;
-
-    // The model abstraction.
-    void** ma = &NULL_POINTER;
-    void** mac = &NULL_POINTER;
-    void** mas = &NULL_POINTER;
-    // The model model.
-    void** mm = &NULL_POINTER;
-    void** mmc = &NULL_POINTER;
-    void** mms = &NULL_POINTER;
-    // The model details.
-    void** md = &NULL_POINTER;
-    void** mdc = &NULL_POINTER;
-    void** mds = &NULL_POINTER;
+    // The break flag name, abstraction, model, details.
+    void** bfn = NULL_POINTER;
+    void** bfnc = NULL_POINTER;
+    void** bfns = NULL_POINTER;
+    void** bfa = NULL_POINTER;
+    void** bfac = NULL_POINTER;
+    void** bfas = NULL_POINTER;
+    void** bfm = NULL_POINTER;
+    void** bfmc = NULL_POINTER;
+    void** bfms = NULL_POINTER;
+    void** bfd = NULL_POINTER;
+    void** bfdc = NULL_POINTER;
+    void** bfds = NULL_POINTER;
+    // The model name, abstraction, model, details.
+    void** mn = NULL_POINTER;
+    void** mnc = NULL_POINTER;
+    void** mns = NULL_POINTER;
+    void** ma = NULL_POINTER;
+    void** mac = NULL_POINTER;
+    void** mas = NULL_POINTER;
+    void** mm = NULL_POINTER;
+    void** mmc = NULL_POINTER;
+    void** mms = NULL_POINTER;
+    void** md = NULL_POINTER;
+    void** mdc = NULL_POINTER;
+    void** mds = NULL_POINTER;
 
     // Get break flag.
     get_universal_compound_element_by_name(p10, p11,
         (void*) BREAK_FLAG_NAME, (void*) BREAK_FLAG_NAME_COUNT,
+        (void*) &bfn, (void*) &bfnc, (void*) &bfns,
         (void*) &bfa, (void*) &bfac, (void*) &bfas,
         (void*) &bfm, (void*) &bfmc, (void*) &bfms,
         (void*) &bfd, (void*) &bfdc, (void*) &bfds,
@@ -111,31 +114,32 @@ void loop(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6,
     // Get model.
     get_universal_compound_element_by_name(p10, p11,
         (void*) LOOP_MODEL_NAME, (void*) LOOP_MODEL_NAME_COUNT,
+        (void*) &mn, (void*) &mnc, (void*) &mns,
         (void*) &ma, (void*) &mac, (void*) &mas,
         (void*) &mm, (void*) &mmc, (void*) &mms,
         (void*) &md, (void*) &mdc, (void*) &mds,
         p1, p2);
 
     // Check break flag.
-    if ((*bfa != NULL_POINTER)
-        && (*bfac != NULL_POINTER)
-        && (*bfas != NULL_POINTER)
-        && (*bfm != NULL_POINTER)
-        && (*bfmc != NULL_POINTER)
-        && (*bfms != NULL_POINTER)
-        && (*bfd != NULL_POINTER)
-        && (*bfdc != NULL_POINTER)
-        && (*bfds != NULL_POINTER)
+    if ((*bfa != *NULL_POINTER)
+        && (*bfac != *NULL_POINTER)
+        && (*bfas != *NULL_POINTER)
+        && (*bfm != *NULL_POINTER)
+        && (*bfmc != *NULL_POINTER)
+        && (*bfms != *NULL_POINTER)
+        && (*bfd != *NULL_POINTER)
+        && (*bfdc != *NULL_POINTER)
+        && (*bfds != *NULL_POINTER)
         // Check model.
-        && (*ma != NULL_POINTER)
-        && (*mac != NULL_POINTER)
-        && (*mas != NULL_POINTER)
-        && (*mm != NULL_POINTER)
-        && (*mmc != NULL_POINTER)
-        && (*mms != NULL_POINTER)
-        && (*md != NULL_POINTER)
-        && (*mdc != NULL_POINTER)
-        && (*mds != NULL_POINTER)) {
+        && (*ma != *NULL_POINTER)
+        && (*mac != *NULL_POINTER)
+        && (*mas != *NULL_POINTER)
+        && (*mm != *NULL_POINTER)
+        && (*mmc != *NULL_POINTER)
+        && (*mms != *NULL_POINTER)
+        && (*md != *NULL_POINTER)
+        && (*mdc != *NULL_POINTER)
+        && (*mds != *NULL_POINTER)) {
 
         // The comparison result.
         int r = 0;
@@ -147,7 +151,7 @@ void loop(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6,
             while (1) {
 
                 // The break flag.
-                void* b = NULL_POINTER;
+                void* b = *NULL_POINTER;
 
                 // Get break flag.
                 get_array_elements(*bfm, (void*) PRIMITIVE_VALUE_INDEX, (void*) &b, (void*) INTEGER_ARRAY);
