@@ -1,7 +1,7 @@
 /*
  * $RCSfile: receive.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.18 $ $Date: 2006/06/20 16:16:29 $ $Author: christian $
+ * @version $Revision: 1.29 $ $Date: 2007/05/16 19:29:01 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -30,14 +30,14 @@
 #include "../applicator/receive/receive_file_system.c"
 #include "../applicator/receive/receive_latex.c"
 #include "../applicator/receive/receive_linux_console.c"
-#include "../applicator/receive/receive_tcp_socket.c"
-#include "../applicator/receive/receive_unix_socket.c"
+#include "../applicator/receive/receive_socket.c"
 #include "../applicator/receive/receive_x_window_system.c"
-#include "../globals/constants/abstraction_constants.c"
-#include "../globals/constants/channel_constants.c"
-#include "../globals/constants/model_constants.c"
-#include "../globals/constants/name_constants.c"
-#include "../globals/constants/structure_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../globals/constants/cybol/cybol_channel_constants.c"
+#include "../globals/constants/cybol/cybol_model_constants.c"
+#include "../globals/constants/cybol/cybol_name_constants.c"
+#include "../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../globals/constants/pointer/pointer_constants.c"
 #include "../globals/logger/logger.c"
 #include "../memoriser/accessor/compound_accessor.c"
 
@@ -52,9 +52,8 @@
  * special mechanisms for signal reception have to be started.
  * To the mechanisms belong:
  * - linux console
- * - tcp socket
- * - unix socket
  * - x window system
+ * - socket
  *
  * These have their own internal signal/ action/ event/ interrupt waiting loops
  * which get activated here, running as parallel services in separate threads.
@@ -86,126 +85,141 @@ void receive_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
 
     log_message_debug("Receive message.");
 
-    // The name abstraction.
-    void** na = &NULL_POINTER;
-    void** nac = &NULL_POINTER;
-    void** nas = &NULL_POINTER;
-    // The name model.
-    void** nm = &NULL_POINTER;
-    void** nmc = &NULL_POINTER;
-    void** nms = &NULL_POINTER;
-    // The name details.
-    void** nd = &NULL_POINTER;
-    void** ndc = &NULL_POINTER;
-    void** nds = &NULL_POINTER;
-
-    // The channel abstraction.
-    void** ca = &NULL_POINTER;
-    void** cac = &NULL_POINTER;
-    void** cas = &NULL_POINTER;
-    // The channel model.
-    void** cm = &NULL_POINTER;
-    void** cmc = &NULL_POINTER;
-    void** cms = &NULL_POINTER;
-    // The channel details.
-    void** cd = &NULL_POINTER;
-    void** cdc = &NULL_POINTER;
-    void** cds = &NULL_POINTER;
-
-    // The abstraction abstraction.
-    void** aa = &NULL_POINTER;
-    void** aac = &NULL_POINTER;
-    void** aas = &NULL_POINTER;
-    // The abstraction model.
-    void** am = &NULL_POINTER;
-    void** amc = &NULL_POINTER;
-    void** ams = &NULL_POINTER;
-    // The abstraction details.
-    void** ad = &NULL_POINTER;
-    void** adc = &NULL_POINTER;
-    void** ads = &NULL_POINTER;
-
-    // The model abstraction.
-    void** ma = &NULL_POINTER;
-    void** mac = &NULL_POINTER;
-    void** mas = &NULL_POINTER;
-    // The model model.
-    void** mm = &NULL_POINTER;
-    void** mmc = &NULL_POINTER;
-    void** mms = &NULL_POINTER;
-    // The model details.
-    void** md = &NULL_POINTER;
-    void** mdc = &NULL_POINTER;
-    void** mds = &NULL_POINTER;
-
-    // The element abstraction.
-    void** ea = &NULL_POINTER;
-    void** eac = &NULL_POINTER;
-    void** eas = &NULL_POINTER;
-    // The element model.
-    void** em = &NULL_POINTER;
-    void** emc = &NULL_POINTER;
-    void** ems = &NULL_POINTER;
-    // The element details.
-    void** ed = &NULL_POINTER;
-    void** edc = &NULL_POINTER;
-    void** eds = &NULL_POINTER;
-
-    // The whole abstraction.
-    void** wa = &NULL_POINTER;
-    void** wac = &NULL_POINTER;
-    void** was = &NULL_POINTER;
-    // The whole model.
-    void** wm = &NULL_POINTER;
-    void** wmc = &NULL_POINTER;
-    void** wms = &NULL_POINTER;
-    // The whole details.
-    void** wd = &NULL_POINTER;
-    void** wdc = &NULL_POINTER;
-    void** wds = &NULL_POINTER;
-
-    // The root abstraction.
-    void** ra = &NULL_POINTER;
-    void** rac = &NULL_POINTER;
-    void** ras = &NULL_POINTER;
-    // The root model.
-    void** rm = &NULL_POINTER;
-    void** rmc = &NULL_POINTER;
-    void** rms = &NULL_POINTER;
-    // The root details.
-    void** rd = &NULL_POINTER;
-    void** rdc = &NULL_POINTER;
-    void** rds = &NULL_POINTER;
-
-    // The commands abstraction.
-    void** coa = &NULL_POINTER;
-    void** coac = &NULL_POINTER;
-    void** coas = &NULL_POINTER;
-    // The commands model.
-    void** com = &NULL_POINTER;
-    void** comc = &NULL_POINTER;
-    void** coms = &NULL_POINTER;
-    // The commands details.
-    void** cod = &NULL_POINTER;
-    void** codc = &NULL_POINTER;
-    void** cods = &NULL_POINTER;
-
-    // The blocking abstraction.
-    void** ba = &NULL_POINTER;
-    void** bac = &NULL_POINTER;
-    void** bas = &NULL_POINTER;
-    // The blocking model.
-    void** bm = &NULL_POINTER;
-    void** bmc = &NULL_POINTER;
-    void** bms = &NULL_POINTER;
-    // The blocking details.
-    void** bd = &NULL_POINTER;
-    void** bdc = &NULL_POINTER;
-    void** bds = &NULL_POINTER;
+    // The name name, abstraction, model, details.
+    void** nn = NULL_POINTER;
+    void** nnc = NULL_POINTER;
+    void** nns = NULL_POINTER;
+    void** na = NULL_POINTER;
+    void** nac = NULL_POINTER;
+    void** nas = NULL_POINTER;
+    void** nm = NULL_POINTER;
+    void** nmc = NULL_POINTER;
+    void** nms = NULL_POINTER;
+    void** nd = NULL_POINTER;
+    void** ndc = NULL_POINTER;
+    void** nds = NULL_POINTER;
+    // The channel name, abstraction, model, details.
+    void** cn = NULL_POINTER;
+    void** cnc = NULL_POINTER;
+    void** cns = NULL_POINTER;
+    void** ca = NULL_POINTER;
+    void** cac = NULL_POINTER;
+    void** cas = NULL_POINTER;
+    void** cm = NULL_POINTER;
+    void** cmc = NULL_POINTER;
+    void** cms = NULL_POINTER;
+    void** cd = NULL_POINTER;
+    void** cdc = NULL_POINTER;
+    void** cds = NULL_POINTER;
+    // The abstraction name, abstraction, model, details.
+    void** an = NULL_POINTER;
+    void** anc = NULL_POINTER;
+    void** ans = NULL_POINTER;
+    void** aa = NULL_POINTER;
+    void** aac = NULL_POINTER;
+    void** aas = NULL_POINTER;
+    void** am = NULL_POINTER;
+    void** amc = NULL_POINTER;
+    void** ams = NULL_POINTER;
+    void** ad = NULL_POINTER;
+    void** adc = NULL_POINTER;
+    void** ads = NULL_POINTER;
+    // The model name, abstraction, model, details.
+    void** mn = NULL_POINTER;
+    void** mnc = NULL_POINTER;
+    void** mns = NULL_POINTER;
+    void** ma = NULL_POINTER;
+    void** mac = NULL_POINTER;
+    void** mas = NULL_POINTER;
+    void** mm = NULL_POINTER;
+    void** mmc = NULL_POINTER;
+    void** mms = NULL_POINTER;
+    void** md = NULL_POINTER;
+    void** mdc = NULL_POINTER;
+    void** mds = NULL_POINTER;
+    // The element name, abstraction, model, details.
+    void** en = NULL_POINTER;
+    void** enc = NULL_POINTER;
+    void** ens = NULL_POINTER;
+    void** ea = NULL_POINTER;
+    void** eac = NULL_POINTER;
+    void** eas = NULL_POINTER;
+    void** em = NULL_POINTER;
+    void** emc = NULL_POINTER;
+    void** ems = NULL_POINTER;
+    void** ed = NULL_POINTER;
+    void** edc = NULL_POINTER;
+    void** eds = NULL_POINTER;
+    // The whole name, abstraction, model, details.
+    void** wn = NULL_POINTER;
+    void** wnc = NULL_POINTER;
+    void** wns = NULL_POINTER;
+    void** wa = NULL_POINTER;
+    void** wac = NULL_POINTER;
+    void** was = NULL_POINTER;
+    void** wm = NULL_POINTER;
+    void** wmc = NULL_POINTER;
+    void** wms = NULL_POINTER;
+    void** wd = NULL_POINTER;
+    void** wdc = NULL_POINTER;
+    void** wds = NULL_POINTER;
+    // The root name, abstraction, model, details.
+    void** rn = NULL_POINTER;
+    void** rnc = NULL_POINTER;
+    void** rns = NULL_POINTER;
+    void** ra = NULL_POINTER;
+    void** rac = NULL_POINTER;
+    void** ras = NULL_POINTER;
+    void** rm = NULL_POINTER;
+    void** rmc = NULL_POINTER;
+    void** rms = NULL_POINTER;
+    void** rd = NULL_POINTER;
+    void** rdc = NULL_POINTER;
+    void** rds = NULL_POINTER;
+    // The socket communication style name, abstraction, model, details.
+    void** stn = NULL_POINTER;
+    void** stnc = NULL_POINTER;
+    void** stns = NULL_POINTER;
+    void** sta = NULL_POINTER;
+    void** stac = NULL_POINTER;
+    void** stas = NULL_POINTER;
+    void** stm = NULL_POINTER;
+    void** stmc = NULL_POINTER;
+    void** stms = NULL_POINTER;
+    void** std = NULL_POINTER;
+    void** stdc = NULL_POINTER;
+    void** stds = NULL_POINTER;
+    // The commands name, abstraction, model, details.
+    void** con = NULL_POINTER;
+    void** conc = NULL_POINTER;
+    void** cons = NULL_POINTER;
+    void** coa = NULL_POINTER;
+    void** coac = NULL_POINTER;
+    void** coas = NULL_POINTER;
+    void** com = NULL_POINTER;
+    void** comc = NULL_POINTER;
+    void** coms = NULL_POINTER;
+    void** cod = NULL_POINTER;
+    void** codc = NULL_POINTER;
+    void** cods = NULL_POINTER;
+    // The blocking name, abstraction, model, details.
+    void** bn = NULL_POINTER;
+    void** bnc = NULL_POINTER;
+    void** bns = NULL_POINTER;
+    void** ba = NULL_POINTER;
+    void** bac = NULL_POINTER;
+    void** bas = NULL_POINTER;
+    void** bm = NULL_POINTER;
+    void** bmc = NULL_POINTER;
+    void** bms = NULL_POINTER;
+    void** bd = NULL_POINTER;
+    void** bdc = NULL_POINTER;
+    void** bds = NULL_POINTER;
 
     // Get name.
     get_universal_compound_element_by_name(p0, p1,
         (void*) CREATE_NAME_NAME, (void*) CREATE_NAME_NAME_COUNT,
+        (void*) &nn, (void*) &nnc, (void*) &nns,
         (void*) &na, (void*) &nac, (void*) &nas,
         (void*) &nm, (void*) &nmc, (void*) &nms,
         (void*) &nd, (void*) &ndc, (void*) &nds,
@@ -214,6 +228,7 @@ void receive_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     // Get channel.
     get_universal_compound_element_by_name(p0, p1,
         (void*) CREATE_CHANNEL_NAME, (void*) CREATE_CHANNEL_NAME_COUNT,
+        (void*) &cn, (void*) &cnc, (void*) &cns,
         (void*) &ca, (void*) &cac, (void*) &cas,
         (void*) &cm, (void*) &cmc, (void*) &cms,
         (void*) &cd, (void*) &cdc, (void*) &cds,
@@ -222,6 +237,7 @@ void receive_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     // Get abstraction.
     get_universal_compound_element_by_name(p0, p1,
         (void*) CREATE_ABSTRACTION_NAME, (void*) CREATE_ABSTRACTION_NAME_COUNT,
+        (void*) &an, (void*) &anc, (void*) &ans,
         (void*) &aa, (void*) &aac, (void*) &aas,
         (void*) &am, (void*) &amc, (void*) &ams,
         (void*) &ad, (void*) &adc, (void*) &ads,
@@ -230,6 +246,7 @@ void receive_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     // Get model.
     get_universal_compound_element_by_name(p0, p1,
         (void*) CREATE_MODEL_NAME, (void*) CREATE_MODEL_NAME_COUNT,
+        (void*) &mn, (void*) &mnc, (void*) &mns,
         (void*) &ma, (void*) &mac, (void*) &mas,
         (void*) &mm, (void*) &mmc, (void*) &mms,
         (void*) &md, (void*) &mdc, (void*) &mds,
@@ -238,6 +255,7 @@ void receive_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     // Get element.
     get_universal_compound_element_by_name(p0, p1,
         (void*) CREATE_ELEMENT_NAME, (void*) CREATE_ELEMENT_NAME_COUNT,
+        (void*) &en, (void*) &enc, (void*) &ens,
         (void*) &ea, (void*) &eac, (void*) &eas,
         (void*) &em, (void*) &emc, (void*) &ems,
         (void*) &ed, (void*) &edc, (void*) &eds,
@@ -246,6 +264,7 @@ void receive_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     // Get whole.
     get_universal_compound_element_by_name(p0, p1,
         (void*) CREATE_WHOLE_NAME, (void*) CREATE_WHOLE_NAME_COUNT,
+        (void*) &wn, (void*) &wnc, (void*) &wns,
         (void*) &wa, (void*) &wac, (void*) &was,
         (void*) &wm, (void*) &wmc, (void*) &wms,
         (void*) &wd, (void*) &wdc, (void*) &wds,
@@ -254,14 +273,25 @@ void receive_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     // Get root.
     get_universal_compound_element_by_name(p0, p1,
         (void*) RECEIVE_ROOT_NAME, (void*) RECEIVE_ROOT_NAME_COUNT,
+        (void*) &rn, (void*) &rnc, (void*) &rns,
         (void*) &ra, (void*) &rac, (void*) &ras,
         (void*) &rm, (void*) &rmc, (void*) &rms,
         (void*) &rd, (void*) &rdc, (void*) &rds,
         p3, p4);
 
+    // Get socket communication style.
+    get_universal_compound_element_by_name(p0, p1,
+        (void*) RECEIVE_STYLE_NAME, (void*) RECEIVE_STYLE_NAME_COUNT,
+        (void*) &stn, (void*) &stnc, (void*) &stns,
+        (void*) &sta, (void*) &stac, (void*) &stas,
+        (void*) &stm, (void*) &stmc, (void*) &stms,
+        (void*) &std, (void*) &stdc, (void*) &stds,
+        p3, p4);
+
     // Get commands.
     get_universal_compound_element_by_name(p0, p1,
         (void*) RECEIVE_COMMANDS_NAME, (void*) RECEIVE_COMMANDS_NAME_COUNT,
+        (void*) &con, (void*) &conc, (void*) &cons,
         (void*) &coa, (void*) &coac, (void*) &coas,
         (void*) &com, (void*) &comc, (void*) &coms,
         (void*) &cod, (void*) &codc, (void*) &cods,
@@ -270,6 +300,7 @@ void receive_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     // Get blocking.
     get_universal_compound_element_by_name(p0, p1,
         (void*) RECEIVE_BLOCKING_NAME, (void*) RECEIVE_BLOCKING_NAME_COUNT,
+        (void*) &bn, (void*) &bnc, (void*) &bns,
         (void*) &ba, (void*) &bac, (void*) &bas,
         (void*) &bm, (void*) &bmc, (void*) &bms,
         (void*) &bd, (void*) &bdc, (void*) &bds,
@@ -289,16 +320,6 @@ void receive_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
         }
     }
 
-    if (r == 0) {
-
-        compare_arrays((void*) *cm, (void*) *cmc, (void*) LATEX_MODEL, (void*) LATEX_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
-
-        if (r != 0) {
-
-//??            receive_latex(p2, *mm, *mmc);
-        }
-    }
-
     if (r == 0) {
 
         compare_arrays((void*) *cm, (void*) *cmc, (void*) LINUX_CONSOLE_MODEL, (void*) LINUX_CONSOLE_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
@@ -309,26 +330,6 @@ void receive_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
         }
     }
 
-    if (r == 0) {
-
-        compare_arrays((void*) *cm, (void*) *cmc, (void*) TCP_SOCKET_MODEL, (void*) TCP_SOCKET_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
-
-        if (r != 0) {
-
-            receive_tcp_socket(p2, p3, p4, p5, *ba, *bac, *bm, *bmc);
-        }
-    }
-
-    if (r == 0) {
-
-        compare_arrays((void*) *cm, (void*) *cmc, (void*) UNIX_SOCKET_MODEL, (void*) UNIX_SOCKET_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
-
-        if (r != 0) {
-
-            receive_unix_socket(p2, p3, p4);
-        }
-    }
-
     if (r == 0) {
 
         compare_arrays((void*) *cm, (void*) *cmc, (void*) X_WINDOW_SYSTEM_MODEL, (void*) X_WINDOW_SYSTEM_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
@@ -338,6 +339,36 @@ void receive_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
             receive_x_window_system(p2, *rm, *rmc, *rms, *com, *comc, *coms);
         }
     }
+
+    if (r == 0) {
+
+        compare_arrays((void*) *cm, (void*) *cmc, (void*) WWW_SERVICE_MODEL, (void*) WWW_SERVICE_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+
+        if (r != 0) {
+
+            receive_socket(p2, *com, *comc, *stm, *stmc, (void*) WWW_BASE_INTERNAL, (void*) &receive_socket_thread_www, (void*) WWW_SERVICE_THREAD);
+        }
+    }
+
+    if (r == 0) {
+
+        compare_arrays((void*) *cm, (void*) *cmc, (void*) CYBOI_SERVICE_MODEL, (void*) CYBOI_SERVICE_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+
+        if (r != 0) {
+
+            receive_socket(p2, *com, *comc, *stm, *stmc, (void*) CYBOI_BASE_INTERNAL, (void*) &receive_socket_thread_cyboi, (void*) CYBOI_SERVICE_THREAD);
+        }
+    }
+
+    if (r == 0) {
+
+        compare_arrays((void*) *cm, (void*) *cmc, (void*) LATEX_MODEL, (void*) LATEX_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+
+        if (r != 0) {
+
+//??            receive_latex(p2, *mm, *mmc);
+        }
+    }
 }
 
 /* RECEIVE_SOURCE */
