@@ -1,7 +1,7 @@
 /*
  * $RCSfile: receive_x_window_system.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.20 $ $Date: 2006/08/19 02:04:48 $ $Author: christian $
+ * @version $Revision: 1.25 $ $Date: 2007/05/16 19:29:01 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @description
  */
@@ -34,11 +34,12 @@
 //?? #include <X11/Xutil.h>
 #include <pthread.h>
 #include <signal.h>
-#include "../../globals/constants/abstraction_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
 #include "../../globals/constants/cyboi_constants.c"
-#include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/name_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/cybol/cybol_name_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/constants/system_constants.c"
 #include "../../globals/variables/variables.c"
 #include "../../memoriser/accessor.c"
@@ -51,48 +52,52 @@
  * Afterwards, the event type is identified.
  * Finally, the corresponding mouse command is returned as result.
  *
- * @param p0 the command abstraction (Hand over as reference!)
- * @param p1 the command abstraction count (Hand over as reference!)
- * @param p2 the command abstraction size (Hand over as reference!)
- * @param p3 the command model (Hand over as reference!)
- * @param p4 the command model count (Hand over as reference!)
- * @param p5 the command model size (Hand over as reference!)
- * @param p6 the command details (Hand over as reference!)
- * @param p7 the command details count (Hand over as reference!)
- * @param p8 the command details size (Hand over as reference!)
- * @param p9 the whole details
- * @param p10 the whole details count
- * @param p11 the event type
- * @param p12 the mouse button
- * @param p13 the knowledge memory
- * @param p14 the knowledge memory count
+ * @param p0 the command name (Hand over as reference!)
+ * @param p1 the command name count (Hand over as reference!)
+ * @param p2 the command name size (Hand over as reference!)
+ * @param p3 the command abstraction (Hand over as reference!)
+ * @param p4 the command abstraction count (Hand over as reference!)
+ * @param p5 the command abstraction size (Hand over as reference!)
+ * @param p6 the command model (Hand over as reference!)
+ * @param p7 the command model count (Hand over as reference!)
+ * @param p8 the command model size (Hand over as reference!)
+ * @param p9 the command details (Hand over as reference!)
+ * @param p10 the command details count (Hand over as reference!)
+ * @param p11 the command details size (Hand over as reference!)
+ * @param p12 the whole details
+ * @param p13 the whole details count
+ * @param p14 the event type
+ * @param p15 the mouse button
+ * @param p16 the knowledge memory
+ * @param p17 the knowledge memory count
  */
-void receive_x_window_system_mouse_command(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8,
-    void* p9, void* p10, void* p11, void* p12, void* p13, void* p14) {
+void receive_x_window_system_mouse_command(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
+    void* p6, void* p7, void* p8, void* p9, void* p10, void* p11,
+    void* p12, void* p13, void* p14, void* p15, void* p16, void* p17) {
 
-    if (p12 != NULL_POINTER) {
+    if (p15 != *NULL_POINTER) {
 
-        int* b = (int*) p12;
+        int* b = (int*) p15;
 
-        if (p11 != NULL_POINTER) {
+        if (p14 != *NULL_POINTER) {
 
-            int* t = (int*) p11;
+            int* t = (int*) p14;
 
             if (*b == Button1) {
 
                 if (*t == ButtonPress) {
 
                     // Get actual command belonging to the button and event.
-                    get_universal_compound_element_by_name(p9, p10,
+                    get_universal_compound_element_by_name(p12, p13,
                         (void*) GUI_LEFT_PRESS_COMMAND_NAME, (void*) GUI_LEFT_PRESS_COMMAND_NAME_COUNT,
-                        p0, p1, p2, p3, p4, p5, p6, p7, p8, p13, p14);
+                        p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p16, p17);
 
                 } else if (*t == ButtonRelease) {
 
                     // Get actual command belonging to the button and event.
-                    get_universal_compound_element_by_name(p9, p10,
+                    get_universal_compound_element_by_name(p12, p13,
                         (void*) GUI_LEFT_RELEASE_COMMAND_NAME, (void*) GUI_LEFT_RELEASE_COMMAND_NAME_COUNT,
-                        p0, p1, p2, p3, p4, p5, p6, p7, p8, p13, p14);
+                        p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p16, p17);
                 }
 
             } else if (*b == Button2) {
@@ -118,32 +123,36 @@ void receive_x_window_system_mouse_command(void* p0, void* p1, void* p2, void* p
  * The event type gets identified, in order to call the corresponding procedure.
  * Mouse press or -release events have to be handled differently than drag'n'drop.
  *
- * @param p0 the command abstraction (Hand over as reference!)
- * @param p1 the command abstraction count (Hand over as reference!)
- * @param p2 the command abstraction size (Hand over as reference!)
- * @param p3 the command model (Hand over as reference!)
- * @param p4 the command model count (Hand over as reference!)
- * @param p5 the command model size (Hand over as reference!)
- * @param p6 the command details (Hand over as reference!)
- * @param p7 the command details count (Hand over as reference!)
- * @param p8 the command details size (Hand over as reference!)
- * @param p9 the whole details
- * @param p10 the whole details count
- * @param p11 the event type
- * @param p12 the mouse button
- * @param p13 the knowledge memory
- * @param p14 the knowledge memory count
+ * @param p0 the command name (Hand over as reference!)
+ * @param p1 the command name count (Hand over as reference!)
+ * @param p2 the command name size (Hand over as reference!)
+ * @param p3 the command abstraction (Hand over as reference!)
+ * @param p4 the command abstraction count (Hand over as reference!)
+ * @param p5 the command abstraction size (Hand over as reference!)
+ * @param p6 the command model (Hand over as reference!)
+ * @param p7 the command model count (Hand over as reference!)
+ * @param p8 the command model size (Hand over as reference!)
+ * @param p9 the command details (Hand over as reference!)
+ * @param p10 the command details count (Hand over as reference!)
+ * @param p11 the command details size (Hand over as reference!)
+ * @param p12 the whole details
+ * @param p13 the whole details count
+ * @param p14 the event type
+ * @param p15 the mouse button
+ * @param p16 the knowledge memory
+ * @param p17 the knowledge memory count
  */
-void receive_x_window_system_command(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8,
-    void* p9, void* p10, void* p11, void* p12, void* p13, void* p14) {
+void receive_x_window_system_command(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
+    void* p6, void* p7, void* p8, void* p9, void* p10, void* p11,
+    void* p12, void* p13, void* p14, void* p15, void* p16, void* p17) {
 
-    if (p11 != NULL_POINTER) {
+    if (p14 != *NULL_POINTER) {
 
-        int* t = (int*) p11;
+        int* t = (int*) p14;
 
         if ((*t == ButtonPress) || (*t == ButtonRelease)) {
 
-            receive_x_window_system_mouse_command(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12, p13, p14);
+            receive_x_window_system_mouse_command(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, p12, p13, p14, p15, p16, p17);
 
 /*??
         } else if (*t == MouseMove) {
@@ -172,84 +181,97 @@ void receive_x_window_system_command(void* p0, void* p1, void* p2, void* p3, voi
  * any previously stored commands of their wholes. Finally, the mouse command
  * is returned as result of this procedure.
  *
- * @param p0 the command abstraction (Hand over as reference!)
- * @param p1 the command abstraction count (Hand over as reference!)
- * @param p2 the command abstraction size (Hand over as reference!)
- * @param p3 the command model (Hand over as reference!)
- * @param p4 the command model count (Hand over as reference!)
- * @param p5 the command model size (Hand over as reference!)
- * @param p6 the command details (Hand over as reference!)
- * @param p7 the command details count (Hand over as reference!)
- * @param p8 the command details size (Hand over as reference!)
- * @param p9 the whole model
- * @param p10 the whole model count
- * @param p11 the mouse x coordinate within the graphical whole
- * @param p12 the mouse y coordinate within the graphical whole
- * @param p13 the mouse z coordinate within the graphical whole
- * @param p14 the event type
- * @param p15 the mouse button
- * @param p16 the knowledge memory
- * @param p17 the knowledge memory count
+ * @param p0 the command name (Hand over as reference!)
+ * @param p1 the command name count (Hand over as reference!)
+ * @param p2 the command name size (Hand over as reference!)
+ * @param p3 the command abstraction (Hand over as reference!)
+ * @param p4 the command abstraction count (Hand over as reference!)
+ * @param p5 the command abstraction size (Hand over as reference!)
+ * @param p6 the command model (Hand over as reference!)
+ * @param p7 the command model count (Hand over as reference!)
+ * @param p8 the command model size (Hand over as reference!)
+ * @param p9 the command details (Hand over as reference!)
+ * @param p10 the command details count (Hand over as reference!)
+ * @param p11 the command details size (Hand over as reference!)
+ * @param p12 the whole model
+ * @param p13 the whole model count
+ * @param p14 the mouse x coordinate within the graphical whole
+ * @param p15 the mouse y coordinate within the graphical whole
+ * @param p16 the mouse z coordinate within the graphical whole
+ * @param p17 the event type
+ * @param p18 the mouse button
+ * @param p19 the knowledge memory
+ * @param p20 the knowledge memory count
  */
-void receive_x_window_system_part(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8,
-    void* p9, void* p10, void* p11, void* p12, void* p13, void* p14, void* p15, void* p16, void* p17) {
+void receive_x_window_system_part(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
+    void* p6, void* p7, void* p8, void* p9, void* p10, void* p11,
+    void* p12, void* p13, void* p14, void* p15, void* p16,
+    void* p17, void* p18, void* p19, void* p20) {
 
-    if (p13 != NULL_POINTER) {
+    if (p16 != *NULL_POINTER) {
 
-        int* mz = (int*) p13;
+        int* mz = (int*) p16;
 
-        if (p12 != NULL_POINTER) {
+        if (p15 != *NULL_POINTER) {
 
-            int* my = (int*) p12;
+            int* my = (int*) p15;
 
-            if (p11 != NULL_POINTER) {
+            if (p14 != *NULL_POINTER) {
 
-                int* mx = (int*) p11;
+                int* mx = (int*) p14;
 
-                if (p10 != NULL_POINTER) {
+                if (p13 != *NULL_POINTER) {
 
-                    int* wmc = (int*) p10;
+                    int* wmc = (int*) p13;
 
-                    // The graphical part abstraction, model, details.
-                    void** a = &NULL_POINTER;
-                    void** ac = &NULL_POINTER;
-                    void** as = &NULL_POINTER;
-                    void** m = &NULL_POINTER;
-                    void** mc = &NULL_POINTER;
-                    void** ms = &NULL_POINTER;
-                    void** d = &NULL_POINTER;
-                    void** dc = &NULL_POINTER;
-                    void** ds = &NULL_POINTER;
-
-                    // The graphical part position.
-                    void** pa = &NULL_POINTER;
-                    void** pac = &NULL_POINTER;
-                    void** pas = &NULL_POINTER;
-                    void** pm = &NULL_POINTER;
-                    void** pmc = &NULL_POINTER;
-                    void** pms = &NULL_POINTER;
-                    void** pd = &NULL_POINTER;
-                    void** pdc = &NULL_POINTER;
-                    void** pds = &NULL_POINTER;
-                    // The graphical part size.
-                    void** sa = &NULL_POINTER;
-                    void** sac = &NULL_POINTER;
-                    void** sas = &NULL_POINTER;
-                    void** sm = &NULL_POINTER;
-                    void** smc = &NULL_POINTER;
-                    void** sms = &NULL_POINTER;
-                    void** sd = &NULL_POINTER;
-                    void** sdc = &NULL_POINTER;
-                    void** sds = &NULL_POINTER;
+                    // The graphical part name, abstraction, model, details.
+                    void** n = NULL_POINTER;
+                    void** nc = NULL_POINTER;
+                    void** ns = NULL_POINTER;
+                    void** a = NULL_POINTER;
+                    void** ac = NULL_POINTER;
+                    void** as = NULL_POINTER;
+                    void** m = NULL_POINTER;
+                    void** mc = NULL_POINTER;
+                    void** ms = NULL_POINTER;
+                    void** d = NULL_POINTER;
+                    void** dc = NULL_POINTER;
+                    void** ds = NULL_POINTER;
+                    // The graphical part position name, abstraction, model, details.
+                    void** pn = NULL_POINTER;
+                    void** pnc = NULL_POINTER;
+                    void** pns = NULL_POINTER;
+                    void** pa = NULL_POINTER;
+                    void** pac = NULL_POINTER;
+                    void** pas = NULL_POINTER;
+                    void** pm = NULL_POINTER;
+                    void** pmc = NULL_POINTER;
+                    void** pms = NULL_POINTER;
+                    void** pd = NULL_POINTER;
+                    void** pdc = NULL_POINTER;
+                    void** pds = NULL_POINTER;
+                    // The graphical part size name, abstraction, model, details.
+                    void** sn = NULL_POINTER;
+                    void** snc = NULL_POINTER;
+                    void** sns = NULL_POINTER;
+                    void** sa = NULL_POINTER;
+                    void** sac = NULL_POINTER;
+                    void** sas = NULL_POINTER;
+                    void** sm = NULL_POINTER;
+                    void** smc = NULL_POINTER;
+                    void** sms = NULL_POINTER;
+                    void** sd = NULL_POINTER;
+                    void** sdc = NULL_POINTER;
+                    void** sds = NULL_POINTER;
 
                     // The graphical part position coordinates.
-                    int** pmx = (int**) &NULL_POINTER;
-                    int** pmy = (int**) &NULL_POINTER;
-                    int** pmz = (int**) &NULL_POINTER;
+                    int** pmx = (int**) NULL_POINTER;
+                    int** pmy = (int**) NULL_POINTER;
+                    int** pmz = (int**) NULL_POINTER;
                     // The graphical part size coordinates.
-                    int** smx = (int**) &NULL_POINTER;
-                    int** smy = (int**) &NULL_POINTER;
-                    int** smz = (int**) &NULL_POINTER;
+                    int** smx = (int**) NULL_POINTER;
+                    int** smy = (int**) NULL_POINTER;
+                    int** smz = (int**) NULL_POINTER;
 
                     // The new mouse coordinates.
                     int nx = *NUMBER_0_INTEGER;
@@ -257,11 +279,11 @@ void receive_x_window_system_part(void* p0, void* p1, void* p2, void* p3, void*
                     int nz = *NUMBER_0_INTEGER;
 
                     // The loop count.
-                    int j = 0;
+                    int j = *NUMBER_0_INTEGER;
                     // The comparison result.
-                    int r = 0;
+                    int r = *NUMBER_0_INTEGER;
 
-                    while (1) {
+                    while (*NUMBER_1_INTEGER) {
 
                         if (j >= *wmc) {
 
@@ -269,7 +291,8 @@ void receive_x_window_system_part(void* p0, void* p1, void* p2, void* p3, void*
                         }
 
                         // Get graphical part at index j.
-                        get_compound_element_by_index(p9, p10, (void*) &j,
+                        get_compound_element_by_index(p12, p13, (void*) &j,
+                            (void*) &n, (void*) &nc, (void*) &ns,
                             (void*) &a, (void*) &ac, (void*) &as,
                             (void*) &m, (void*) &mc, (void*) &ms,
                             (void*) &d, (void*) &dc, (void*) &ds);
@@ -277,17 +300,19 @@ void receive_x_window_system_part(void* p0, void* p1, void* p2, void* p3, void*
                         // Get graphical part position from details.
                         get_universal_compound_element_by_name(*d, *dc,
                             (void*) UI_POSITION_NAME, (void*) UI_POSITION_NAME_COUNT,
+                            (void*) &pn, (void*) &pnc, (void*) &pns,
                             (void*) &pa, (void*) &pac, (void*) &pas,
                             (void*) &pm, (void*) &pmc, (void*) &pms,
                             (void*) &pd, (void*) &pdc, (void*) &pds,
-                            p16, p17);
+                            p19, p20);
                         // Get graphical part size from details.
                         get_universal_compound_element_by_name(*d, *dc,
                             (void*) UI_SIZE_NAME, (void*) UI_SIZE_NAME_COUNT,
+                            (void*) &sn, (void*) &snc, (void*) &sns,
                             (void*) &sa, (void*) &sac, (void*) &sas,
                             (void*) &sm, (void*) &smc, (void*) &sms,
                             (void*) &sd, (void*) &sdc, (void*) &sds,
-                            p16, p17);
+                            p19, p20);
 
                         // Determine graphical part position coordinates.
                         get(*pm, (void*) NUMBER_0_INTEGER, (void*) &pmx, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
@@ -304,11 +329,11 @@ void receive_x_window_system_part(void* p0, void* p1, void* p2, void* p3, void*
                             // The event happened within the graphical part's area.
 
                             // Receive the graphical part's command.
-                            receive_x_window_system_command(p0, p1, p2, p3, p4, p5, p6, p7, p8, *d, *dc, p14, p15, p16, p17);
+                            receive_x_window_system_command(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, *d, *dc, p17, p18, p19, p20);
 
                             compare_arrays(*a, *ac, (void*) COMPOUND_ABSTRACTION, (void*) COMPOUND_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-                            if (r != 0) {
+                            if (r != *NUMBER_0_INTEGER) {
 
                                 // The graphical part model is a compound.
 
@@ -318,51 +343,58 @@ void receive_x_window_system_part(void* p0, void* p1, void* p2, void* p3, void*
                                 nz = *mz - **pmz;
 
                                 // Recursively call this procedure for compound part model.
-                                receive_x_window_system_part(p0, p1, p2, p3, p4, p5, p6, p7, p8,
-                                    *m, *mc, &nx, &ny, &nz, p14, p15, p16, p17);
+                                receive_x_window_system_part(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p10, p11, *m, *mc, &nx, &ny, &nz, p17, p18, p19, p20);
                             }
                         }
 
-                        // Reset graphical part.
-                        a = &NULL_POINTER;
-                        ac = &NULL_POINTER;
-                        as = &NULL_POINTER;
-                        m = &NULL_POINTER;
-                        mc = &NULL_POINTER;
-                        ms = &NULL_POINTER;
-                        d = &NULL_POINTER;
-                        dc = &NULL_POINTER;
-                        ds = &NULL_POINTER;
-
-                        // Reset graphical part position.
-                        pa = &NULL_POINTER;
-                        pac = &NULL_POINTER;
-                        pas = &NULL_POINTER;
-                        pm = &NULL_POINTER;
-                        pmc = &NULL_POINTER;
-                        pms = &NULL_POINTER;
-                        pd = &NULL_POINTER;
-                        pdc = &NULL_POINTER;
-                        pds = &NULL_POINTER;
-                        // Reset graphical part size.
-                        sa = &NULL_POINTER;
-                        sac = &NULL_POINTER;
-                        sas = &NULL_POINTER;
-                        sm = &NULL_POINTER;
-                        smc = &NULL_POINTER;
-                        sms = &NULL_POINTER;
-                        sd = &NULL_POINTER;
-                        sdc = &NULL_POINTER;
-                        sds = &NULL_POINTER;
+                        // Reset graphical part name, abstraction, model, details.
+                        n = NULL_POINTER;
+                        nc = NULL_POINTER;
+                        ns = NULL_POINTER;
+                        a = NULL_POINTER;
+                        ac = NULL_POINTER;
+                        as = NULL_POINTER;
+                        m = NULL_POINTER;
+                        mc = NULL_POINTER;
+                        ms = NULL_POINTER;
+                        d = NULL_POINTER;
+                        dc = NULL_POINTER;
+                        ds = NULL_POINTER;
+                        // Reset graphical part position name, abstraction, model, details.
+                        pn = NULL_POINTER;
+                        pnc = NULL_POINTER;
+                        pns = NULL_POINTER;
+                        pa = NULL_POINTER;
+                        pac = NULL_POINTER;
+                        pas = NULL_POINTER;
+                        pm = NULL_POINTER;
+                        pmc = NULL_POINTER;
+                        pms = NULL_POINTER;
+                        pd = NULL_POINTER;
+                        pdc = NULL_POINTER;
+                        pds = NULL_POINTER;
+                        // Reset graphical part size name, abstraction, model, details.
+                        sn = NULL_POINTER;
+                        snc = NULL_POINTER;
+                        sns = NULL_POINTER;
+                        sa = NULL_POINTER;
+                        sac = NULL_POINTER;
+                        sas = NULL_POINTER;
+                        sm = NULL_POINTER;
+                        smc = NULL_POINTER;
+                        sms = NULL_POINTER;
+                        sd = NULL_POINTER;
+                        sdc = NULL_POINTER;
+                        sds = NULL_POINTER;
 
                         // Reset graphical part position coordinates.
-                        pmx = (int**) &NULL_POINTER;
-                        pmy = (int**) &NULL_POINTER;
-                        pmz = (int**) &NULL_POINTER;
+                        pmx = (int**) NULL_POINTER;
+                        pmy = (int**) NULL_POINTER;
+                        pmz = (int**) NULL_POINTER;
                         // Reset graphical part size coordinates.
-                        smx = (int**) &NULL_POINTER;
-                        smy = (int**) &NULL_POINTER;
-                        smz = (int**) &NULL_POINTER;
+                        smx = (int**) NULL_POINTER;
+                        smy = (int**) NULL_POINTER;
+                        smz = (int**) NULL_POINTER;
 
                         // Reset new mouse coordinates.
                         nx = *NUMBER_0_INTEGER;
@@ -370,7 +402,7 @@ void receive_x_window_system_part(void* p0, void* p1, void* p2, void* p3, void*
                         nz = *NUMBER_0_INTEGER;
 
                         // Reset comparison result.
-                        r = 0;
+                        r = *NUMBER_0_INTEGER;
 
                         // Increment loop count.
                         j++;
@@ -414,7 +446,7 @@ void receive_x_window_system_part(void* p0, void* p1, void* p2, void* p3, void*
 int receive_x_window_system_check_events(struct _XDisplay* d, pthread_mutex_t* xmt) {
 
     // The number of events.
-    int n = 0;
+    int n = *NUMBER_0_INTEGER;
 
     pthread_mutex_lock(xmt);
 
@@ -433,32 +465,32 @@ int receive_x_window_system_check_events(struct _XDisplay* d, pthread_mutex_t* x
 void receive_x_window_system_thread(void* p0) {
 
     // The knowledge memory.
-    void** k = &NULL_POINTER;
-    void** kc = &NULL_POINTER;
-    void** ks = &NULL_POINTER;
+    void** k = NULL_POINTER;
+    void** kc = NULL_POINTER;
+    void** ks = NULL_POINTER;
     // The signal memory.
-    void** s = &NULL_POINTER;
-    void** sc = &NULL_POINTER;
-    void** ss = &NULL_POINTER;
+    void** s = NULL_POINTER;
+    void** sc = NULL_POINTER;
+    void** ss = NULL_POINTER;
     // The signal memory mutex.
-    pthread_mutex_t** smt = (pthread_mutex_t**) &NULL_POINTER;
+    pthread_mutex_t** smt = (pthread_mutex_t**) NULL_POINTER;
     // The x window system mutex.
-    pthread_mutex_t** xmt = (pthread_mutex_t**) &NULL_POINTER;
+    pthread_mutex_t** xmt = (pthread_mutex_t**) NULL_POINTER;
     // The signal memory interrupt request flag.
-    sig_atomic_t** sirq = (sig_atomic_t**) &NULL_POINTER;
+    sig_atomic_t** sirq = (sig_atomic_t**) NULL_POINTER;
     // The user interface root.
-    void** r = &NULL_POINTER;
-    void** rc = &NULL_POINTER;
-    void** rs = &NULL_POINTER;
+    void** r = NULL_POINTER;
+    void** rc = NULL_POINTER;
+    void** rs = NULL_POINTER;
     // The user interface commands.
-    void** c = &NULL_POINTER;
-    void** cc = &NULL_POINTER;
-    void** cs = &NULL_POINTER;
+    void** c = NULL_POINTER;
+    void** cc = NULL_POINTER;
+    void** cs = NULL_POINTER;
     // The display, which is a subsumption of
     // xserver, screens, hardware (input devices etc.).
-    struct _XDisplay** d = (struct _XDisplay**) &NULL_POINTER;
+    struct _XDisplay** d = (struct _XDisplay**) NULL_POINTER;
     // The window.
-    int** w = (int**) &NULL_POINTER;
+    int** w = (int**) NULL_POINTER;
 
     // Get knowledge memory internal.
     get(p0, (void*) KNOWLEDGE_MEMORY_INTERNAL, (void*) &k, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
@@ -486,38 +518,42 @@ void receive_x_window_system_thread(void* p0) {
     get(p0, (void*) X_WINDOW_SYSTEM_DISPLAY_INTERNAL, (void*) &d, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
     get(p0, (void*) X_WINDOW_SYSTEM_WINDOW_INTERNAL, (void*) &w, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
 
-    // The command abstraction.
-    void** ca = &NULL_POINTER;
-    void** cac = &NULL_POINTER;
-    void** cas = &NULL_POINTER;
-    // The command model.
-    void** cm = &NULL_POINTER;
-    void** cmc = &NULL_POINTER;
-    void** cms = &NULL_POINTER;
-    // The command details.
-    void** cd = &NULL_POINTER;
-    void** cdc = &NULL_POINTER;
-    void** cds = &NULL_POINTER;
+    // The command name, abstraction, model, details.
+    void** cn = NULL_POINTER;
+    void** cnc = NULL_POINTER;
+    void** cns = NULL_POINTER;
+    void** ca = NULL_POINTER;
+    void** cac = NULL_POINTER;
+    void** cas = NULL_POINTER;
+    void** cm = NULL_POINTER;
+    void** cmc = NULL_POINTER;
+    void** cms = NULL_POINTER;
+    void** cd = NULL_POINTER;
+    void** cdc = NULL_POINTER;
+    void** cds = NULL_POINTER;
 
-    //?? TODO: The temporary graphical part abstraction, model, details.
-    void** tmpa = &NULL_POINTER;
-    void** tmpac = &NULL_POINTER;
-    void** tmpas = &NULL_POINTER;
-    void** tmpm = &NULL_POINTER;
-    void** tmpmc = &NULL_POINTER;
-    void** tmpms = &NULL_POINTER;
-    void** tmpd = &NULL_POINTER;
-    void** tmpdc = &NULL_POINTER;
-    void** tmpds = &NULL_POINTER;
+    //?? TODO: The temporary graphical part name, abstraction, model, details.
+    void** tmpn = NULL_POINTER;
+    void** tmpnc = NULL_POINTER;
+    void** tmpns = NULL_POINTER;
+    void** tmpa = NULL_POINTER;
+    void** tmpac = NULL_POINTER;
+    void** tmpas = NULL_POINTER;
+    void** tmpm = NULL_POINTER;
+    void** tmpmc = NULL_POINTER;
+    void** tmpms = NULL_POINTER;
+    void** tmpd = NULL_POINTER;
+    void** tmpdc = NULL_POINTER;
+    void** tmpds = NULL_POINTER;
 
     // The event.
     XEvent e;
     // The event type.
-    int t = -1;
+    int t = *NUMBER_MINUS_1_INTEGER;
     // The signal id.
-    int* id = NULL_POINTER;
+    int* id = (int*) *NULL_POINTER;
 
-    while (1) {
+    while (*NUMBER_1_INTEGER) {
 
         // A break condition does not exist here because the loop
         // is blocking neverendingly while waiting for signals.
@@ -597,11 +633,12 @@ void receive_x_window_system_thread(void* p0) {
             // when being displayed after having been covered before.
 
             // Consider only the last in a row of multiple expose events.
-            if (e.xexpose.count == 0) {
+            if (e.xexpose.count == *NUMBER_0_INTEGER) {
 
                 // Get actual command belonging to the x window system expose event.
                 get_universal_compound_element_by_name(*c, *cc,
                     (void*) GUI_EXPOSE_COMMAND_NAME, (void*) GUI_EXPOSE_COMMAND_NAME_COUNT,
+                    (void*) &cn, (void*) &cnc, (void*) &cns,
                     (void*) &ca, (void*) &cac, (void*) &cas,
                     (void*) &cm, (void*) &cmc, (void*) &cms,
                     (void*) &cd, (void*) &cdc, (void*) &cds,
@@ -614,7 +651,7 @@ void receive_x_window_system_thread(void* p0) {
 
                 // Allocate signal id.
                 allocate((void*) &id, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-                *id = 0;
+                *id = *NUMBER_0_INTEGER;
                 get_new_signal_id(*s, *sc, (void*) id);
 
                 // Add signal to signal memory.
@@ -739,13 +776,14 @@ void receive_x_window_system_thread(void* p0) {
             //?? only part element is determined here and handed over to
             //?? further procedures.
             get_compound_element_by_index(*r, *rc, (void*) NUMBER_0_INTEGER,
+                (void*) &tmpn, (void*) &tmpnc, (void*) &tmpns,
                 (void*) &tmpa, (void*) &tmpac, (void*) &tmpas,
                 (void*) &tmpm, (void*) &tmpmc, (void*) &tmpms,
                 (void*) &tmpd, (void*) &tmpdc, (void*) &tmpds);
 
             // Determine command, depending on mouse button and event type.
             // CAUTION! Hand over command abstraction, model, details as reference!
-            receive_x_window_system_part(&ca, &cac, &cas, &cm, &cmc, &cms, &cd, &cdc, &cds,
+            receive_x_window_system_part(&cn, &cnc, &cns, &ca, &cac, &cas, &cm, &cmc, &cms, &cd, &cdc, &cds,
                 *tmpm, *tmpmc, &(e.xbutton.x), &(e.xbutton.y), (void*) NUMBER_0_INTEGER,
                 &t, &(e.xbutton.button), *k, *kc);
 
@@ -754,7 +792,7 @@ void receive_x_window_system_thread(void* p0) {
 
             // Allocate signal id.
             allocate((void*) &id, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-            *id = 0;
+            *id = *NUMBER_0_INTEGER;
             get_new_signal_id(*s, *sc, (void*) id);
 
             // Add signal to signal memory.
@@ -801,33 +839,36 @@ void receive_x_window_system_thread(void* p0) {
         }
 
         // Reset command abstraction.
-        ca = &NULL_POINTER;
-        cac = &NULL_POINTER;
-        cas = &NULL_POINTER;
+        ca = NULL_POINTER;
+        cac = NULL_POINTER;
+        cas = NULL_POINTER;
         // Reset command model.
-        cm = &NULL_POINTER;
-        cmc = &NULL_POINTER;
-        cms = &NULL_POINTER;
+        cm = NULL_POINTER;
+        cmc = NULL_POINTER;
+        cms = NULL_POINTER;
         // Reset command details.
-        cd = &NULL_POINTER;
-        cdc = &NULL_POINTER;
-        cds = &NULL_POINTER;
+        cd = NULL_POINTER;
+        cdc = NULL_POINTER;
+        cds = NULL_POINTER;
 
-        //?? Reset temporary graphical part abstraction, model, details.
-        tmpa = &NULL_POINTER;
-        tmpac = &NULL_POINTER;
-        tmpas = &NULL_POINTER;
-        tmpm = &NULL_POINTER;
-        tmpmc = &NULL_POINTER;
-        tmpms = &NULL_POINTER;
-        tmpd = &NULL_POINTER;
-        tmpdc = &NULL_POINTER;
-        tmpds = &NULL_POINTER;
+        //?? Reset temporary graphical part name, abstraction, model, details.
+        tmpn = NULL_POINTER;
+        tmpnc = NULL_POINTER;
+        tmpns = NULL_POINTER;
+        tmpa = NULL_POINTER;
+        tmpac = NULL_POINTER;
+        tmpas = NULL_POINTER;
+        tmpm = NULL_POINTER;
+        tmpmc = NULL_POINTER;
+        tmpms = NULL_POINTER;
+        tmpd = NULL_POINTER;
+        tmpdc = NULL_POINTER;
+        tmpds = NULL_POINTER;
 
         // Reset event type.
-        t = -1;
+        t = *NUMBER_MINUS_1_INTEGER;
         // Reset signal id.
-        id = NULL_POINTER;
+        id = (int*) *NULL_POINTER;
     }
 
     // An implicit call to pthread_exit() is made when this thread
@@ -890,7 +931,7 @@ void receive_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4, v
         // - added to the internal memory
         // - handed over to the thread procedure HERE
         // - deallocated at service shutdown
-        pthread_create(X_WINDOW_SYSTEM_THREAD, NULL_POINTER, (void*) &receive_x_window_system_thread, p0);
+        pthread_create(X_WINDOW_SYSTEM_THREAD, *NULL_POINTER, (void*) &receive_x_window_system_thread, p0);
     }
 }
 
