@@ -1,7 +1,7 @@
 /*
  * $RCSfile: run_archive.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.6 $ $Date: 2006/06/20 16:16:29 $ $Author: christian $
+ * @version $Revision: 1.12 $ $Date: 2007/05/26 21:19:57 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -30,13 +30,14 @@
 #include <unistd.h>
 #include "../../applicator/run/run_execute.c"
 #include "../../globals/constants/shell_command/unix_shell_command_constants.c"
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/ascii_character_constants.c"
-#include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/model_constants.c"
-#include "../../globals/constants/name_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/character/character_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/cybol/cybol_model_constants.c"
+#include "../../globals/constants/cybol/cybol_name_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/constants/system_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../globals/variables/variables.c"
@@ -56,48 +57,50 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
 
     log_message_debug("Run archive command.");
 
-    // The create abstraction.
-    void** createa = &NULL_POINTER;
-    void** createac = &NULL_POINTER;
-    void** createas = &NULL_POINTER;
-    // The create model.
-    int** createm = (int**) &NULL_POINTER;
-    void** createmc = &NULL_POINTER;
-    void** createms = &NULL_POINTER;
-    // The create details.
-    void** created = &NULL_POINTER;
-    void** createdc = &NULL_POINTER;
-    void** createds = &NULL_POINTER;
-
-    // The update abstraction.
-    void** updatea = &NULL_POINTER;
-    void** updateac = &NULL_POINTER;
-    void** updateas = &NULL_POINTER;
-    // The update model.
-    int** updatem = (int**) &NULL_POINTER;
-    void** updatemc = &NULL_POINTER;
-    void** updatems = &NULL_POINTER;
-    // The update details.
-    void** updated = &NULL_POINTER;
-    void** updatedc = &NULL_POINTER;
-    void** updateds = &NULL_POINTER;
-
-    // The bzip2 abstraction.
-    void** bzip2a = &NULL_POINTER;
-    void** bzip2ac = &NULL_POINTER;
-    void** bzip2as = &NULL_POINTER;
-    // The bzip2 model.
-    int** bzip2m = (int**) &NULL_POINTER;
-    void** bzip2mc = &NULL_POINTER;
-    void** bzip2ms = &NULL_POINTER;
-    // The bzip2 details.
-    void** bzip2d = &NULL_POINTER;
-    void** bzip2dc = &NULL_POINTER;
-    void** bzip2ds = &NULL_POINTER;
+    // The create name, abstraction, model, details.
+    void** createn = NULL_POINTER;
+    void** createnc = NULL_POINTER;
+    void** createns = NULL_POINTER;
+    void** createa = NULL_POINTER;
+    void** createac = NULL_POINTER;
+    void** createas = NULL_POINTER;
+    int** createm = (int**) NULL_POINTER;
+    void** createmc = NULL_POINTER;
+    void** createms = NULL_POINTER;
+    void** created = NULL_POINTER;
+    void** createdc = NULL_POINTER;
+    void** createds = NULL_POINTER;
+    // The update name, abstraction, model, details.
+    void** updaten = NULL_POINTER;
+    void** updatenc = NULL_POINTER;
+    void** updatens = NULL_POINTER;
+    void** updatea = NULL_POINTER;
+    void** updateac = NULL_POINTER;
+    void** updateas = NULL_POINTER;
+    int** updatem = (int**) NULL_POINTER;
+    void** updatemc = NULL_POINTER;
+    void** updatems = NULL_POINTER;
+    void** updated = NULL_POINTER;
+    void** updatedc = NULL_POINTER;
+    void** updateds = NULL_POINTER;
+    // The bzip2 name, abstraction, model, details.
+    void** bzip2n = NULL_POINTER;
+    void** bzip2nc = NULL_POINTER;
+    void** bzip2ns = NULL_POINTER;
+    void** bzip2a = NULL_POINTER;
+    void** bzip2ac = NULL_POINTER;
+    void** bzip2as = NULL_POINTER;
+    int** bzip2m = (int**) NULL_POINTER;
+    void** bzip2mc = NULL_POINTER;
+    void** bzip2ms = NULL_POINTER;
+    void** bzip2d = NULL_POINTER;
+    void** bzip2dc = NULL_POINTER;
+    void** bzip2ds = NULL_POINTER;
 
     // Get create option.
     get_universal_compound_element_by_name(p0, p1,
         (void*) RUN_ARCHIVE_CREATE_NAME, (void*) RUN_ARCHIVE_CREATE_NAME_COUNT,
+        (void*) &createn, (void*) &createnc, (void*) &createns,
         (void*) &createa, (void*) &createac, (void*) &createas,
         (void*) &createm, (void*) &createmc, (void*) &createms,
         (void*) &created, (void*) &createdc, (void*) &createds,
@@ -106,6 +109,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     // Get update option.
     get_universal_compound_element_by_name(p0, p1,
         (void*) RUN_ARCHIVE_UPDATE_NAME, (void*) RUN_ARCHIVE_UPDATE_NAME_COUNT,
+        (void*) &updaten, (void*) &updatenc, (void*) &updatens,
         (void*) &updatea, (void*) &updateac, (void*) &updateas,
         (void*) &updatem, (void*) &updatemc, (void*) &updatems,
         (void*) &updated, (void*) &updatedc, (void*) &updateds,
@@ -114,13 +118,14 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     // Get bzip2 option.
     get_universal_compound_element_by_name(p0, p1,
         (void*) RUN_ARCHIVE_BZIP2_NAME, (void*) RUN_ARCHIVE_BZIP2_NAME_COUNT,
+        (void*) &bzip2n, (void*) &bzip2nc, (void*) &bzip2ns,
         (void*) &bzip2a, (void*) &bzip2ac, (void*) &bzip2as,
         (void*) &bzip2m, (void*) &bzip2mc, (void*) &bzip2ms,
         (void*) &bzip2d, (void*) &bzip2dc, (void*) &bzip2ds,
         p2, p3);
 
     // The arguments vector.
-    void* arg = NULL_POINTER;
+    void* arg = *NULL_POINTER;
     int argc = *NUMBER_0_INTEGER;
     int args = *NUMBER_0_INTEGER;
 
@@ -139,7 +144,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     // Create option.
     //
 
-    if (*createm != NULL_POINTER) {
+    if (*createm != *NULL_POINTER) {
 
         if (**createm == 1) {
 
@@ -155,7 +160,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(arg, (void*) &argc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(arg, (void*) &argc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *PRIMITIVE_COUNT;
             set_array_elements(arg, (void*) &argc, (void*) ARCHIVE_UNIX_SHELL_COMMAND_CREATE, (void*) ARCHIVE_UNIX_SHELL_COMMAND_CREATE_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *ARCHIVE_UNIX_SHELL_COMMAND_CREATE_COUNT;
@@ -166,7 +171,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     // Update option.
     //
 
-    if (*updatem != NULL_POINTER) {
+    if (*updatem != *NULL_POINTER) {
 
         if (**updatem == 1) {
 
@@ -182,7 +187,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(arg, (void*) &argc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(arg, (void*) &argc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *PRIMITIVE_COUNT;
             set_array_elements(arg, (void*) &argc, (void*) ARCHIVE_UNIX_SHELL_COMMAND_UPDATE, (void*) ARCHIVE_UNIX_SHELL_COMMAND_UPDATE_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *ARCHIVE_UNIX_SHELL_COMMAND_UPDATE_COUNT;
@@ -193,7 +198,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     // Bzip2 option.
     //
 
-    if (*bzip2m != NULL_POINTER) {
+    if (*bzip2m != *NULL_POINTER) {
 
         if (**bzip2m == 1) {
 
@@ -209,7 +214,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(arg, (void*) &argc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(arg, (void*) &argc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *PRIMITIVE_COUNT;
             set_array_elements(arg, (void*) &argc, (void*) ARCHIVE_UNIX_SHELL_COMMAND_BZIP2, (void*) ARCHIVE_UNIX_SHELL_COMMAND_BZIP2_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *ARCHIVE_UNIX_SHELL_COMMAND_BZIP2_COUNT;
@@ -231,7 +236,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     }
 
     // Assemble arguments by adding the null termination character.
-    set_array_elements(arg, (void*) &argc, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+    set_array_elements(arg, (void*) &argc, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
     argc = argc + *PRIMITIVE_COUNT;
 
     // Execute arguments as process.
@@ -248,19 +253,19 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     //?? in "run_execute.c" or deleted later.
 
     // The arguments vector.
-    void* arg = NULL_POINTER;
+    void* arg = *NULL_POINTER;
     int argc = *NUMBER_0_INTEGER;
     int args = *NUMBER_0_INTEGER;
     // The system shell as null terminated string.
-    void* shell = NULL_POINTER;
+    void* shell = *NULL_POINTER;
     int shellc = *NUMBER_0_INTEGER;
     int shells = *NUMBER_0_INTEGER;
     // The character argument as null terminated string.
-    void* character = NULL_POINTER;
+    void* character = *NULL_POINTER;
     int characterc = *NUMBER_0_INTEGER;
     int characters = *NUMBER_0_INTEGER;
     // The command as null terminated string.
-    void* command = NULL_POINTER;
+    void* command = *NULL_POINTER;
     int commandc = *NUMBER_0_INTEGER;
     int commands = *NUMBER_0_INTEGER;
 
@@ -281,7 +286,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     // and then adding the null termination character.
     set_array_elements(shell, (void*) &shellc, (void*) SYSTEM_SHELL, (void*) SYSTEM_SHELL_COUNT, (void*) CHARACTER_ARRAY);
     shellc = shellc + *SYSTEM_SHELL_COUNT;
-    set_array_elements(shell, (void*) &shellc, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+    set_array_elements(shell, (void*) &shellc, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
     shellc = shellc + *PRIMITIVE_COUNT;
 
     // Increase arguments vector size for shell argument.
@@ -301,7 +306,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     // and then adding the null termination character.
     set_array_elements(character, (void*) &characterc, (void*) SYSTEM_SHELL_CHARACTER_ARGUMENT, (void*) SYSTEM_SHELL_CHARACTER_ARGUMENT_COUNT, (void*) CHARACTER_ARRAY);
     characterc = characterc + *SYSTEM_SHELL_CHARACTER_ARGUMENT_COUNT;
-    set_array_elements(character, (void*) &characterc, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+    set_array_elements(character, (void*) &characterc, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
     characterc = characterc + *PRIMITIVE_COUNT;
 
     // Increase arguments vector size for shell character argument.
@@ -329,7 +334,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     // Create option.
     //
 
-    if (*createm != NULL_POINTER) {
+    if (*createm != *NULL_POINTER) {
 
         if (**createm == 1) {
 
@@ -345,7 +350,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(command, (void*) &commandc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(command, (void*) &commandc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *PRIMITIVE_COUNT;
             set_array_elements(command, (void*) &commandc, (void*) ARCHIVE_UNIX_SHELL_COMMAND_CREATE, (void*) ARCHIVE_UNIX_SHELL_COMMAND_CREATE_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *ARCHIVE_UNIX_SHELL_COMMAND_CREATE_COUNT;
@@ -356,7 +361,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     // Update option.
     //
 
-    if (*updatem != NULL_POINTER) {
+    if (*updatem != *NULL_POINTER) {
 
         if (**updatem == 1) {
 
@@ -372,7 +377,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(command, (void*) &commandc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(command, (void*) &commandc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *PRIMITIVE_COUNT;
             set_array_elements(command, (void*) &commandc, (void*) ARCHIVE_UNIX_SHELL_COMMAND_UPDATE, (void*) ARCHIVE_UNIX_SHELL_COMMAND_UPDATE_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *ARCHIVE_UNIX_SHELL_COMMAND_UPDATE_COUNT;
@@ -383,7 +388,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     // Bzip2 option.
     //
 
-    if (*bzip2m != NULL_POINTER) {
+    if (*bzip2m != *NULL_POINTER) {
 
         if (**bzip2m == 1) {
 
@@ -399,7 +404,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(command, (void*) &commandc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(command, (void*) &commandc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *PRIMITIVE_COUNT;
             set_array_elements(command, (void*) &commandc, (void*) ARCHIVE_UNIX_SHELL_COMMAND_BZIP2, (void*) ARCHIVE_UNIX_SHELL_COMMAND_BZIP2_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *ARCHIVE_UNIX_SHELL_COMMAND_BZIP2_COUNT;
@@ -421,7 +426,7 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
     }
 
     // Assemble command by adding the null termination character.
-    set_array_elements(command, (void*) &commandc, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+    set_array_elements(command, (void*) &commandc, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
     commandc = commandc + *PRIMITIVE_COUNT;
 
     //
@@ -453,25 +458,25 @@ void run_archive(void* p0, void* p1, void* p2, void* p3) {
 
     // Set null pointer argument.
     // CAUTION! The null pointer always has to be the last argument.
-    set(arg, (void*) &argc, (void*) &NULL_POINTER, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+    set(arg, (void*) &argc, NULL_POINTER, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
     argc++;
 
     // Execute command as process.
     run_execute(arg);
 
-    if (shell != NULL_POINTER) {
+    if (shell != *NULL_POINTER) {
 
         // Deallocate shell argument.
         deallocate_array((void*) &shell, (void*) &shells, (void*) CHARACTER_ARRAY);
     }
 
-    if (character != NULL_POINTER) {
+    if (character != *NULL_POINTER) {
 
         // Deallocate character argument.
         deallocate_array((void*) &character, (void*) &characters, (void*) CHARACTER_ARRAY);
     }
 
-    if (command != NULL_POINTER) {
+    if (command != *NULL_POINTER) {
 
         // Deallocate command argument.
         deallocate_array((void*) &command, (void*) &commands, (void*) CHARACTER_ARRAY);
