@@ -1,7 +1,7 @@
 /*
  * $RCSfile: run_copy.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.5 $ $Date: 2006/06/20 16:16:29 $ $Author: christian $
+ * @version $Revision: 1.11 $ $Date: 2007/05/26 21:19:57 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -30,13 +30,14 @@
 #include <unistd.h>
 #include "../../applicator/run/run_execute.c"
 #include "../../globals/constants/shell_command/unix_shell_command_constants.c"
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/ascii_character_constants.c"
-#include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/model_constants.c"
-#include "../../globals/constants/name_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/character/character_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/cybol/cybol_model_constants.c"
+#include "../../globals/constants/cybol/cybol_name_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/constants/system_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../globals/variables/variables.c"
@@ -54,48 +55,50 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
 
     log_message_debug("Run copy command.");
 
-    // The recursive abstraction.
-    void** recursivea = &NULL_POINTER;
-    void** recursiveac = &NULL_POINTER;
-    void** recursiveas = &NULL_POINTER;
-    // The recursive model.
-    int** recursivem = (int**) &NULL_POINTER;
-    void** recursivemc = &NULL_POINTER;
-    void** recursivems = &NULL_POINTER;
-    // The recursive details.
-    void** recursived = &NULL_POINTER;
-    void** recursivedc = &NULL_POINTER;
-    void** recursiveds = &NULL_POINTER;
-
-    // The source abstraction.
-    void** sourcea = &NULL_POINTER;
-    void** sourceac = &NULL_POINTER;
-    void** sourceas = &NULL_POINTER;
-    // The source model.
-    int** sourcem = (int**) &NULL_POINTER;
-    void** sourcemc = &NULL_POINTER;
-    void** sourcems = &NULL_POINTER;
-    // The source details.
-    void** sourced = &NULL_POINTER;
-    void** sourcedc = &NULL_POINTER;
-    void** sourceds = &NULL_POINTER;
-
-    // The destination abstraction.
-    void** destinationa = &NULL_POINTER;
-    void** destinationac = &NULL_POINTER;
-    void** destinationas = &NULL_POINTER;
-    // The destination model.
-    int** destinationm = (int**) &NULL_POINTER;
-    void** destinationmc = &NULL_POINTER;
-    void** destinationms = &NULL_POINTER;
-    // The destination details.
-    void** destinationd = &NULL_POINTER;
-    void** destinationdc = &NULL_POINTER;
-    void** destinationds = &NULL_POINTER;
+    // The recursive name, abstraction, model, details.
+    void** recursiven = NULL_POINTER;
+    void** recursivenc = NULL_POINTER;
+    void** recursivens = NULL_POINTER;
+    void** recursivea = NULL_POINTER;
+    void** recursiveac = NULL_POINTER;
+    void** recursiveas = NULL_POINTER;
+    int** recursivem = (int**) NULL_POINTER;
+    void** recursivemc = NULL_POINTER;
+    void** recursivems = NULL_POINTER;
+    void** recursived = NULL_POINTER;
+    void** recursivedc = NULL_POINTER;
+    void** recursiveds = NULL_POINTER;
+    // The source name, abstraction, model, details.
+    void** sourcen = NULL_POINTER;
+    void** sourcenc = NULL_POINTER;
+    void** sourcens = NULL_POINTER;
+    void** sourcea = NULL_POINTER;
+    void** sourceac = NULL_POINTER;
+    void** sourceas = NULL_POINTER;
+    int** sourcem = (int**) NULL_POINTER;
+    void** sourcemc = NULL_POINTER;
+    void** sourcems = NULL_POINTER;
+    void** sourced = NULL_POINTER;
+    void** sourcedc = NULL_POINTER;
+    void** sourceds = NULL_POINTER;
+    // The destination name, abstraction, model, details.
+    void** destinationn = NULL_POINTER;
+    void** destinationnc = NULL_POINTER;
+    void** destinationns = NULL_POINTER;
+    void** destinationa = NULL_POINTER;
+    void** destinationac = NULL_POINTER;
+    void** destinationas = NULL_POINTER;
+    int** destinationm = (int**) NULL_POINTER;
+    void** destinationmc = NULL_POINTER;
+    void** destinationms = NULL_POINTER;
+    void** destinationd = NULL_POINTER;
+    void** destinationdc = NULL_POINTER;
+    void** destinationds = NULL_POINTER;
 
     // Get recursive option.
     get_universal_compound_element_by_name(p0, p1,
         (void*) RUN_COPY_RECURSIVE_NAME, (void*) RUN_COPY_RECURSIVE_NAME_COUNT,
+        (void*) &recursiven, (void*) &recursivenc, (void*) &recursivens,
         (void*) &recursivea, (void*) &recursiveac, (void*) &recursiveas,
         (void*) &recursivem, (void*) &recursivemc, (void*) &recursivems,
         (void*) &recursived, (void*) &recursivedc, (void*) &recursiveds,
@@ -104,6 +107,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     // Get source option.
     get_universal_compound_element_by_name(p0, p1,
         (void*) RUN_COPY_SOURCE_NAME, (void*) RUN_COPY_SOURCE_NAME_COUNT,
+        (void*) &sourcen, (void*) &sourcenc, (void*) &sourcens,
         (void*) &sourcea, (void*) &sourceac, (void*) &sourceas,
         (void*) &sourcem, (void*) &sourcemc, (void*) &sourcems,
         (void*) &sourced, (void*) &sourcedc, (void*) &sourceds,
@@ -112,13 +116,14 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     // Get destination option.
     get_universal_compound_element_by_name(p0, p1,
         (void*) RUN_COPY_DESTINATION_NAME, (void*) RUN_COPY_DESTINATION_NAME_COUNT,
+        (void*) &destinationn, (void*) &destinationnc, (void*) &destinationns,
         (void*) &destinationa, (void*) &destinationac, (void*) &destinationas,
         (void*) &destinationm, (void*) &destinationmc, (void*) &destinationms,
         (void*) &destinationd, (void*) &destinationdc, (void*) &destinationds,
         p2, p3);
 
     // The arguments vector.
-    void* arg = NULL_POINTER;
+    void* arg = *NULL_POINTER;
     int argc = *NUMBER_0_INTEGER;
     int args = *NUMBER_0_INTEGER;
 
@@ -137,7 +142,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     // Recursive option.
     //
 
-    if (*recursivem != NULL_POINTER) {
+    if (*recursivem != *NULL_POINTER) {
 
         if (**recursivem == 1) {
 
@@ -153,7 +158,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(arg, (void*) &argc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(arg, (void*) &argc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *PRIMITIVE_COUNT;
             set_array_elements(arg, (void*) &argc, (void*) COPY_UNIX_SHELL_COMMAND_RECURSIVE, (void*) COPY_UNIX_SHELL_COMMAND_RECURSIVE_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *COPY_UNIX_SHELL_COMMAND_RECURSIVE_COUNT;
@@ -164,7 +169,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     // Source option.
     //
 
-    if (*sourcem != NULL_POINTER) {
+    if (*sourcem != *NULL_POINTER) {
 
         if (**sourcem == 1) {
 
@@ -180,7 +185,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(arg, (void*) &argc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(arg, (void*) &argc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *PRIMITIVE_COUNT;
             set_array_elements(arg, (void*) &argc, (void*) COPY_UNIX_SHELL_COMMAND_SOURCE, (void*) COPY_UNIX_SHELL_COMMAND_SOURCE_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *COPY_UNIX_SHELL_COMMAND_SOURCE_COUNT;
@@ -191,7 +196,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     // Destination option.
     //
 
-    if (*destinationm != NULL_POINTER) {
+    if (*destinationm != *NULL_POINTER) {
 
         if (**destinationm == 1) {
 
@@ -207,7 +212,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(arg, (void*) &argc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(arg, (void*) &argc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *PRIMITIVE_COUNT;
             set_array_elements(arg, (void*) &argc, (void*) COPY_UNIX_SHELL_COMMAND_DESTINATION, (void*) COPY_UNIX_SHELL_COMMAND_DESTINATION_COUNT, (void*) CHARACTER_ARRAY);
             argc = argc + *COPY_UNIX_SHELL_COMMAND_DESTINATION_COUNT;
@@ -229,7 +234,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     }
 
     // Assemble arguments by adding the null termination character.
-    set_array_elements(arg, (void*) &argc, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+    set_array_elements(arg, (void*) &argc, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
     argc = argc + *PRIMITIVE_COUNT;
 
     // Execute arguments as process.
@@ -246,20 +251,20 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     //?? in "run_execute.c" or deleted later.
 
     // The arguments vector.
-    void* arg = NULL_POINTER;
+    void* arg = *NULL_POINTER;
     int argc = *NUMBER_0_INTEGER;
     int args = *NUMBER_0_INTEGER;
 
     // The system shell as null terminated string.
-    void* shell = NULL_POINTER;
+    void* shell = *NULL_POINTER;
     int shellc = *NUMBER_0_INTEGER;
     int shells = *NUMBER_0_INTEGER;
     // The character argument as null terminated string.
-    void* character = NULL_POINTER;
+    void* character = *NULL_POINTER;
     int characterc = *NUMBER_0_INTEGER;
     int characters = *NUMBER_0_INTEGER;
     // The command as null terminated string.
-    void* command = NULL_POINTER;
+    void* command = *NULL_POINTER;
     int commandc = *NUMBER_0_INTEGER;
     int commands = *NUMBER_0_INTEGER;
 
@@ -280,7 +285,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     // and then adding the null termination character.
     set_array_elements(shell, (void*) &shellc, (void*) SYSTEM_SHELL, (void*) SYSTEM_SHELL_COUNT, (void*) CHARACTER_ARRAY);
     shellc = shellc + *SYSTEM_SHELL_COUNT;
-    set_array_elements(shell, (void*) &shellc, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+    set_array_elements(shell, (void*) &shellc, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
     shellc = shellc + *PRIMITIVE_COUNT;
 
     // Increase arguments vector size for shell argument.
@@ -300,7 +305,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     // and then adding the null termination character.
     set_array_elements(character, (void*) &characterc, (void*) SYSTEM_SHELL_CHARACTER_ARGUMENT, (void*) SYSTEM_SHELL_CHARACTER_ARGUMENT_COUNT, (void*) CHARACTER_ARRAY);
     characterc = characterc + *SYSTEM_SHELL_CHARACTER_ARGUMENT_COUNT;
-    set_array_elements(character, (void*) &characterc, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+    set_array_elements(character, (void*) &characterc, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
     characterc = characterc + *PRIMITIVE_COUNT;
 
     // Increase arguments vector size for shell character argument.
@@ -328,7 +333,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     // Recursive option.
     //
 
-    if (*recursivem != NULL_POINTER) {
+    if (*recursivem != *NULL_POINTER) {
 
         if (**recursivem == 1) {
 
@@ -344,7 +349,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(command, (void*) &commandc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(command, (void*) &commandc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *PRIMITIVE_COUNT;
             set_array_elements(command, (void*) &commandc, (void*) COPY_UNIX_SHELL_COMMAND_RECURSIVE, (void*) COPY_UNIX_SHELL_COMMAND_RECURSIVE_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *COPY_UNIX_SHELL_COMMAND_RECURSIVE_COUNT;
@@ -355,7 +360,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     // Source option.
     //
 
-    if (*sourcem != NULL_POINTER) {
+    if (*sourcem != *NULL_POINTER) {
 
         if (**sourcem == 1) {
 
@@ -371,7 +376,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(command, (void*) &commandc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(command, (void*) &commandc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *PRIMITIVE_COUNT;
             set_array_elements(command, (void*) &commandc, (void*) COPY_UNIX_SHELL_COMMAND_SOURCE, (void*) COPY_UNIX_SHELL_COMMAND_SOURCE_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *COPY_UNIX_SHELL_COMMAND_SOURCE_COUNT;
@@ -382,7 +387,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     // Destination option.
     //
 
-    if (*destinationm != NULL_POINTER) {
+    if (*destinationm != *NULL_POINTER) {
 
         if (**destinationm == 1) {
 
@@ -398,7 +403,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
 
             // Assemble option by copying the actual argument.
             // A null termination character is added behind the last argument, see below!
-            set_array_elements(command, (void*) &commandc, (void*) SPACE_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+            set_array_elements(command, (void*) &commandc, (void*) SPACE_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *PRIMITIVE_COUNT;
             set_array_elements(command, (void*) &commandc, (void*) COPY_UNIX_SHELL_COMMAND_DESTINATION, (void*) COPY_UNIX_SHELL_COMMAND_DESTINATION_COUNT, (void*) CHARACTER_ARRAY);
             commandc = commandc + *COPY_UNIX_SHELL_COMMAND_DESTINATION_COUNT;
@@ -420,7 +425,7 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
     }
 
     // Assemble command by adding the null termination character.
-    set_array_elements(command, (void*) &commandc, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+    set_array_elements(command, (void*) &commandc, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
     commandc = commandc + *PRIMITIVE_COUNT;
 
     //
@@ -452,25 +457,25 @@ void run_copy(void* p0, void* p1, void* p2, void* p3) {
 
     // Set null pointer argument.
     // CAUTION! The null pointer always has to be the last argument.
-    set(arg, (void*) &argc, (void*) &NULL_POINTER, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+    set(arg, (void*) &argc, NULL_POINTER, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
     argc++;
 
     // Execute command as process.
     run_execute(arg);
 
-    if (shell != NULL_POINTER) {
+    if (shell != *NULL_POINTER) {
 
         // Deallocate shell argument.
         deallocate_array((void*) &shell, (void*) &shells, (void*) CHARACTER_ARRAY);
     }
 
-    if (character != NULL_POINTER) {
+    if (character != *NULL_POINTER) {
 
         // Deallocate character argument.
         deallocate_array((void*) &character, (void*) &characters, (void*) CHARACTER_ARRAY);
     }
 
-    if (command != NULL_POINTER) {
+    if (command != *NULL_POINTER) {
 
         // Deallocate command argument.
         deallocate_array((void*) &command, (void*) &commands, (void*) CHARACTER_ARRAY);
