@@ -1,7 +1,7 @@
 /*
  * $RCSfile: send.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.34 $ $Date: 2006/08/19 02:04:47 $ $Author: christian $
+ * @version $Revision: 1.50 $ $Date: 2007/05/16 19:29:01 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @author Rolf Holzmueller <rolf.holzmueller@gmx.de>
  */
@@ -28,24 +28,132 @@
 #ifndef SEND_SOURCE
 #define SEND_SOURCE
 
-#include <signal.h>
+#include "../applicator/send/send_cyboi_system.c"
+#include "../applicator/send/send_file_system.c"
 #include "../applicator/send/send_latex.c"
 #include "../applicator/send/send_linux_console.c"
-#include "../applicator/send/send_tcp_socket.c"
-#include "../applicator/send/send_unix_socket.c"
+#include "../applicator/send/send_shell.c"
+#include "../applicator/send/send_socket.c"
 #include "../applicator/send/send_x_window_system.c"
-#include "../globals/constants/abstraction_constants.c"
-#include "../globals/constants/channel_constants.c"
-#include "../globals/constants/model_constants.c"
-#include "../globals/constants/name_constants.c"
-#include "../globals/constants/structure_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../globals/constants/cybol/cybol_channel_constants.c"
+#include "../globals/constants/integer/integer_constants.c"
+#include "../globals/constants/cybol/cybol_model_constants.c"
+#include "../globals/constants/cybol/cybol_name_constants.c"
+#include "../globals/constants/service_port_constants.c"
+#include "../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../globals/constants/pointer/pointer_constants.c"
 #include "../globals/logger/logger.c"
 #include "../memoriser/accessor/compound_accessor.c"
 #include "../memoriser/accessor/internal_memory_accessor.c"
 #include "../memoriser/allocator.c"
-#include "../memoriser/communicator/tcp_socket_communicator.c"
 #include "../memoriser/translator.c"
 
+/**
+ * Refreshes the url.
+ *
+ * @param p0 the parameters
+ * @param p1 the parameters count
+ * @param p2 the internal memory
+ * @param p3 the knowledge memory
+ * @param p4 the knowledge memory count
+ * @param p5 the knowledge memory size
+ * @param p6 the signal id
+ */
+void refresh_url(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6) {
+
+    log_message_debug("Refresh url.");
+
+/*??
+    // The message abstraction.
+    void** urla = &NULL_POINTER;
+    void** urlac = &NULL_POINTER;
+    void** urlas = &NULL_POINTER;
+    // The message model.
+    void** urlm = &NULL_POINTER;
+    void** urlmc = &NULL_POINTER;
+    void** urlms = &NULL_POINTER;
+    // The message details.
+    void** urld = &NULL_POINTER;
+    void** urldc = &NULL_POINTER;
+    void** urlds = &NULL_POINTER;
+
+    // Get language.
+    get_universal_compound_element_by_name(p0, p1,
+        (void*) SEND_URL_NAME, (void*) SEND_URL_NAME_COUNT,
+        (void*) &urla, (void*) &urlac, (void*) &urlas,
+        (void*) &urlm, (void*) &urlmc, (void*) &urlms,
+        (void*) &urld, (void*) &urldc, (void*) &urlds,
+        p3, p4);
+
+    if ((*urla != NULL_POINTER)
+         && (*urlac != NULL_POINTER)
+         && (*urlas != NULL_POINTER)
+         && (*urlm != NULL_POINTER)
+         && (*urlmc != NULL_POINTER)
+         && (*urlms != NULL_POINTER)
+         && (*urld != NULL_POINTER)
+         && (*urldc != NULL_POINTER)
+         && (*urlds != NULL_POINTER)) {
+
+        // The socket number for the signal id.
+        // The index for the signal id in the array is the same index
+        // in the client socket number array.
+        int i = -1;
+
+        get_index_for_signal_id(p2, p6, (void*) &i);
+
+        if (i >= *NUMBER_0_INTEGER) {
+
+            // The client socket.
+            int* cs = NULL_POINTER;
+
+            get_client_socket_number_for_index(p2, (void*) &i, (void*) &cs);
+
+            if (*cs >= *NUMBER_0_INTEGER) {
+
+                char msg_refresh_part_1[] = "<head> <meta http-equiv='expires' content='0'>  <meta http-equiv='refresh' content='0; URL=";
+                char msg_refresh_part_3[] = "'></head><body></body>";
+                int msg_part_1_count = strlen( msg_refresh_part_1 );
+                int msg_part_3_count = strlen( msg_refresh_part_3 );
+
+                //create the destination for the send model
+                void* dest = NULL_POINTER;
+                int* dest_count = NULL_POINTER;
+                int* dest_size = NULL_POINTER;
+
+                allocate(&dest_count, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
+                allocate(&dest_size, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
+                *dest_count = *NUMBER_0_INTEGER;
+                *dest_size  = *NUMBER_0_INTEGER;
+                allocate(&dest, dest_size, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
+
+                parse(&dest, dest_count, dest_size, &msg_refresh_part_1[*NUMBER_0_INTEGER], &msg_part_1_count, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
+                parse(&dest, dest_count, dest_size, *urlm, *urlmc, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
+                parse(&dest, dest_count, dest_size, &msg_refresh_part_3[*NUMBER_0_INTEGER], &msg_part_3_count, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
+
+                // The temporary count, size.
+                int tc = *NUMBER_0_INTEGER;
+                int ts = *NUMBER_0_INTEGER;
+
+                send_tcp_socket((void*) &cs, (void*) &tc, (void*) &ts, (void*) dest, (void*) dest_count);
+
+                // Remove client socket number and main signal id from internal memory.
+                remove_relation_clientsocketnumber_mainsignalid(p2, (void*) &i);
+
+                // Close socket.
+                close(*cs);
+
+                // Destroy destination.
+                deallocate(&dest, dest_size, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
+                deallocate(&dest_count, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
+                deallocate(&dest_size, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
+            }
+        }
+    }
+*/
+}
+
 /**
  * Sends a message in a special language.
  *
@@ -75,105 +183,186 @@ void send_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
 
     log_message_debug("Send message.");
 
-    // The signal memory mutex.
-    pthread_mutex_t** mt = (pthread_mutex_t**) &NULL_POINTER;
-    // The interrupt request flag.
-    sig_atomic_t** irq = (sig_atomic_t**) &NULL_POINTER;
-
-    // The channel abstraction.
-    void** ca = &NULL_POINTER;
-    void** cac = &NULL_POINTER;
-    void** cas = &NULL_POINTER;
-    // The channel model.
-    void** cm = &NULL_POINTER;
-    void** cmc = &NULL_POINTER;
-    void** cms = &NULL_POINTER;
-    // The channel details.
-    void** cd = &NULL_POINTER;
-    void** cdc = &NULL_POINTER;
-    void** cds = &NULL_POINTER;
-
-    // The sender abstraction.
-    void** sa = &NULL_POINTER;
-    void** sac = &NULL_POINTER;
-    void** sas = &NULL_POINTER;
-    // The sender model.
-    void** sm = &NULL_POINTER;
-    void** smc = &NULL_POINTER;
-    void** sms = &NULL_POINTER;
-    // The sender details.
-    void** sd = &NULL_POINTER;
-    void** sdc = &NULL_POINTER;
-    void** sds = &NULL_POINTER;
-
-    // The receiver abstraction.
-    void** ra = &NULL_POINTER;
-    void** rac = &NULL_POINTER;
-    void** ras = &NULL_POINTER;
-    // The receiver model.
-    void** rm = &NULL_POINTER;
-    void** rmc = &NULL_POINTER;
-    void** rms = &NULL_POINTER;
-    // The receiver details.
-    void** rd = &NULL_POINTER;
-    void** rdc = &NULL_POINTER;
-    void** rds = &NULL_POINTER;
-
-    // The message abstraction.
-    void** ma = &NULL_POINTER;
-    void** mac = &NULL_POINTER;
-    void** mas = &NULL_POINTER;
-    // The message model.
-    void** mm = &NULL_POINTER;
-    void** mmc = &NULL_POINTER;
-    void** mms = &NULL_POINTER;
-    // The message details.
-    void** md = &NULL_POINTER;
-    void** mdc = &NULL_POINTER;
-    void** mds = &NULL_POINTER;
-
-    // The area abstraction.
-    void** aa = &NULL_POINTER;
-    void** aac = &NULL_POINTER;
-    void** aas = &NULL_POINTER;
-    // The area model.
-    void** am = &NULL_POINTER;
-    void** amc = &NULL_POINTER;
-    void** ams = &NULL_POINTER;
-    // The area details.
-    void** ad = &NULL_POINTER;
-    void** adc = &NULL_POINTER;
-    void** ads = &NULL_POINTER;
-
-    // The clean abstraction.
-    void** cla = &NULL_POINTER;
-    void** clac = &NULL_POINTER;
-    void** clas = &NULL_POINTER;
-    // The clean model.
-    void** clm = &NULL_POINTER;
-    void** clmc = &NULL_POINTER;
-    void** clms = &NULL_POINTER;
-    // The clean details.
-    void** cld = &NULL_POINTER;
-    void** cldc = &NULL_POINTER;
-    void** clds = &NULL_POINTER;
-
-    // Get signal memory mutex.
-    get(p2, (void*) SIGNAL_MEMORY_MUTEX_INTERNAL, (void*) &mt, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
-    // Get interrupt request internal.
-    get(p2, (void*) INTERRUPT_REQUEST_INTERNAL, (void*) &irq, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+    // The channel name, abstraction, model, details.
+    void** cn = NULL_POINTER;
+    void** cnc = NULL_POINTER;
+    void** cns = NULL_POINTER;
+    void** ca = NULL_POINTER;
+    void** cac = NULL_POINTER;
+    void** cas = NULL_POINTER;
+    void** cm = NULL_POINTER;
+    void** cmc = NULL_POINTER;
+    void** cms = NULL_POINTER;
+    void** cd = NULL_POINTER;
+    void** cdc = NULL_POINTER;
+    void** cds = NULL_POINTER;
+    // The language name, abstraction, model, details.
+    void** ln = NULL_POINTER;
+    void** lnc = NULL_POINTER;
+    void** lns = NULL_POINTER;
+    void** la = NULL_POINTER;
+    void** lac = NULL_POINTER;
+    void** las = NULL_POINTER;
+    void** lm = NULL_POINTER;
+    void** lmc = NULL_POINTER;
+    void** lms = NULL_POINTER;
+    void** ld = NULL_POINTER;
+    void** ldc = NULL_POINTER;
+    void** lds = NULL_POINTER;
+    // The communication mode name, abstraction, model, details.
+    void** mon = NULL_POINTER;
+    void** monc = NULL_POINTER;
+    void** mons = NULL_POINTER;
+    void** moa = NULL_POINTER;
+    void** moac = NULL_POINTER;
+    void** moas = NULL_POINTER;
+    void** mom = NULL_POINTER;
+    void** momc = NULL_POINTER;
+    void** moms = NULL_POINTER;
+    void** mod = NULL_POINTER;
+    void** modc = NULL_POINTER;
+    void** mods = NULL_POINTER;
+    // The socket namespace name, abstraction, model, details.
+    void** nn = NULL_POINTER;
+    void** nnc = NULL_POINTER;
+    void** nns = NULL_POINTER;
+    void** na = NULL_POINTER;
+    void** nac = NULL_POINTER;
+    void** nas = NULL_POINTER;
+    void** nm = NULL_POINTER;
+    void** nmc = NULL_POINTER;
+    void** nms = NULL_POINTER;
+    void** nd = NULL_POINTER;
+    void** ndc = NULL_POINTER;
+    void** nds = NULL_POINTER;
+    // The communication style name, abstraction, model, details.
+    void** stn = NULL_POINTER;
+    void** stnc = NULL_POINTER;
+    void** stns = NULL_POINTER;
+    void** sta = NULL_POINTER;
+    void** stac = NULL_POINTER;
+    void** stas = NULL_POINTER;
+    void** stm = NULL_POINTER;
+    void** stmc = NULL_POINTER;
+    void** stms = NULL_POINTER;
+    void** std = NULL_POINTER;
+    void** stdc = NULL_POINTER;
+    void** stds = NULL_POINTER;
+    // The sender name, abstraction, model, details.
+    void** sn = NULL_POINTER;
+    void** snc = NULL_POINTER;
+    void** sns = NULL_POINTER;
+    void** sa = NULL_POINTER;
+    void** sac = NULL_POINTER;
+    void** sas = NULL_POINTER;
+    void** sm = NULL_POINTER;
+    void** smc = NULL_POINTER;
+    void** sms = NULL_POINTER;
+    void** sd = NULL_POINTER;
+    void** sdc = NULL_POINTER;
+    void** sds = NULL_POINTER;
+    // The receiver name, abstraction, model, details.
+    void** rn = NULL_POINTER;
+    void** rnc = NULL_POINTER;
+    void** rns = NULL_POINTER;
+    void** ra = NULL_POINTER;
+    void** rac = NULL_POINTER;
+    void** ras = NULL_POINTER;
+    void** rm = NULL_POINTER;
+    void** rmc = NULL_POINTER;
+    void** rms = NULL_POINTER;
+    void** rd = NULL_POINTER;
+    void** rdc = NULL_POINTER;
+    void** rds = NULL_POINTER;
+    // The message name, abstraction, model, details.
+    void** mn = NULL_POINTER;
+    void** mnc = NULL_POINTER;
+    void** mns = NULL_POINTER;
+    void** ma = NULL_POINTER;
+    void** mac = NULL_POINTER;
+    void** mas = NULL_POINTER;
+    void** mm = NULL_POINTER;
+    void** mmc = NULL_POINTER;
+    void** mms = NULL_POINTER;
+    void** md = NULL_POINTER;
+    void** mdc = NULL_POINTER;
+    void** mds = NULL_POINTER;
+    // The area name, abstraction, model, details.
+    void** an = NULL_POINTER;
+    void** anc = NULL_POINTER;
+    void** ans = NULL_POINTER;
+    void** aa = NULL_POINTER;
+    void** aac = NULL_POINTER;
+    void** aas = NULL_POINTER;
+    void** am = NULL_POINTER;
+    void** amc = NULL_POINTER;
+    void** ams = NULL_POINTER;
+    void** ad = NULL_POINTER;
+    void** adc = NULL_POINTER;
+    void** ads = NULL_POINTER;
+    // The clean name, abstraction, model, details.
+    void** cln = NULL_POINTER;
+    void** clnc = NULL_POINTER;
+    void** clns = NULL_POINTER;
+    void** cla = NULL_POINTER;
+    void** clac = NULL_POINTER;
+    void** clas = NULL_POINTER;
+    void** clm = NULL_POINTER;
+    void** clmc = NULL_POINTER;
+    void** clms = NULL_POINTER;
+    void** cld = NULL_POINTER;
+    void** cldc = NULL_POINTER;
+    void** clds = NULL_POINTER;
 
     // Get channel.
     get_universal_compound_element_by_name(p0, p1,
         (void*) SEND_CHANNEL_NAME, (void*) SEND_CHANNEL_NAME_COUNT,
+        (void*) &cn, (void*) &cnc, (void*) &cns,
         (void*) &ca, (void*) &cac, (void*) &cas,
         (void*) &cm, (void*) &cmc, (void*) &cms,
         (void*) &cd, (void*) &cdc, (void*) &cds,
         p3, p4);
 
+    // Get language.
+    get_universal_compound_element_by_name(p0, p1,
+        (void*) SEND_LANGUAGE_NAME, (void*) SEND_LANGUAGE_NAME_COUNT,
+        (void*) &ln, (void*) &lnc, (void*) &lns,
+        (void*) &la, (void*) &lac, (void*) &las,
+        (void*) &lm, (void*) &lmc, (void*) &lms,
+        (void*) &ld, (void*) &ldc, (void*) &lds,
+        p3, p4);
+
+    // Get communication mode.
+    get_universal_compound_element_by_name(p0, p1,
+        (void*) SEND_COMMUNICATION_MODE_NAME, (void*) SEND_COMMUNICATION_MODE_NAME_COUNT,
+        (void*) &mon, (void*) &monc, (void*) &mons,
+        (void*) &moa, (void*) &moac, (void*) &moas,
+        (void*) &mom, (void*) &momc, (void*) &moms,
+        (void*) &mod, (void*) &modc, (void*) &mods,
+        p3, p4);
+
+    // Get socket namespace.
+    get_universal_compound_element_by_name(p0, p1,
+        (void*) SEND_NAMESPACE_NAME, (void*) SEND_NAMESPACE_NAME_COUNT,
+        (void*) &nn, (void*) &nnc, (void*) &nns,
+        (void*) &na, (void*) &nac, (void*) &nas,
+        (void*) &nm, (void*) &nmc, (void*) &nms,
+        (void*) &nd, (void*) &ndc, (void*) &nds,
+        p3, p4);
+
+    // Get communication style.
+    get_universal_compound_element_by_name(p0, p1,
+        (void*) SEND_STYLE_NAME, (void*) SEND_STYLE_NAME_COUNT,
+        (void*) &stn, (void*) &stnc, (void*) &stns,
+        (void*) &sta, (void*) &stac, (void*) &stas,
+        (void*) &stm, (void*) &stmc, (void*) &stms,
+        (void*) &std, (void*) &stdc, (void*) &stds,
+        p3, p4);
+
     // Get sender.
     get_universal_compound_element_by_name(p0, p1,
         (void*) SEND_SENDER_NAME, (void*) SEND_SENDER_NAME_COUNT,
+        (void*) &sn, (void*) &snc, (void*) &sns,
         (void*) &sa, (void*) &sac, (void*) &sas,
         (void*) &sm, (void*) &smc, (void*) &sms,
         (void*) &sd, (void*) &sdc, (void*) &sds,
@@ -182,6 +371,7 @@ void send_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     // Get receiver.
     get_universal_compound_element_by_name(p0, p1,
         (void*) SEND_RECEIVER_NAME, (void*) SEND_RECEIVER_NAME_COUNT,
+        (void*) &rn, (void*) &rnc, (void*) &rns,
         (void*) &ra, (void*) &rac, (void*) &ras,
         (void*) &rm, (void*) &rmc, (void*) &rms,
         (void*) &rd, (void*) &rdc, (void*) &rds,
@@ -190,6 +380,7 @@ void send_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     // Get message.
     get_universal_compound_element_by_name(p0, p1,
         (void*) SEND_MESSAGE_NAME, (void*) SEND_MESSAGE_NAME_COUNT,
+        (void*) &mn, (void*) &mnc, (void*) &mns,
         (void*) &ma, (void*) &mac, (void*) &mas,
         (void*) &mm, (void*) &mmc, (void*) &mms,
         (void*) &md, (void*) &mdc, (void*) &mds,
@@ -198,6 +389,7 @@ void send_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     // Get area.
     get_universal_compound_element_by_name(p0, p1,
         (void*) SEND_AREA_NAME, (void*) SEND_AREA_NAME_COUNT,
+        (void*) &an, (void*) &anc, (void*) &ans,
         (void*) &aa, (void*) &aac, (void*) &aas,
         (void*) &am, (void*) &amc, (void*) &ams,
         (void*) &ad, (void*) &adc, (void*) &ads,
@@ -206,254 +398,94 @@ void send_message(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     // Get clean flag.
     get_universal_compound_element_by_name(p0, p1,
         (void*) SEND_CLEAN_NAME, (void*) SEND_CLEAN_NAME_COUNT,
+        (void*) &cln, (void*) &clnc, (void*) &clns,
         (void*) &cla, (void*) &clac, (void*) &clas,
         (void*) &clm, (void*) &clmc, (void*) &clms,
         (void*) &cld, (void*) &cldc, (void*) &clds,
         p3, p4);
 
     // The comparison result.
-    int r = 0;
+    int r = *NUMBER_0_INTEGER;
 
-    if (r == 0) {
+    if (r == *NUMBER_0_INTEGER) {
 
-        compare_arrays((void*) *cm, (void*) *cmc, (void*) LATEX_MODEL, (void*) LATEX_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+        compare_arrays((void*) *cm, (void*) *cmc, (void*) SIGNAL_MODEL, (void*) SIGNAL_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-        if (r != 0) {
+        if (r != *NUMBER_0_INTEGER) {
 
-            send_latex(p2, *mm, *mmc, p3, p4);
+            send_cyboi_system(p2, p6, p7, p8, *ma, *mac, *mm, *mmc, *md, *mdc, (void*) NORMAL_PRIORITY, p9);
         }
     }
 
-    if (r == 0) {
+    if (r == *NUMBER_0_INTEGER) {
+
+        compare_arrays((void*) *cm, (void*) *cmc, (void*) FILE_SYSTEM_MODEL, (void*) FILE_SYSTEM_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+
+        if (r != *NUMBER_0_INTEGER) {
+
+            send_file_system(p2, *mn, *mnc, *ma, *mac, *mm, *mmc, *md, *mdc, p3, p4, *lm, *lmc, *clm, *clmc, *rm, *rmc);
+        }
+    }
+
+    if (r == *NUMBER_0_INTEGER) {
+
+        compare_arrays((void*) *cm, (void*) *cmc, (void*) SHELL_MODEL, (void*) SHELL_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+
+        if (r != *NUMBER_0_INTEGER) {
+
+            send_shell(p2, *ma, *mac, *mm, *mmc, *md, *mdc, p3, p4, *lm, *lmc, *clm, *clmc);
+        }
+    }
+
+    if (r == *NUMBER_0_INTEGER) {
 
         compare_arrays((void*) *cm, (void*) *cmc, (void*) LINUX_CONSOLE_MODEL, (void*) LINUX_CONSOLE_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-        if (r != 0) {
+        if (r != *NUMBER_0_INTEGER) {
 
             send_linux_console(p2, *ma, *mac, *mm, *mmc, *md, *mdc, *am, *amc, *clm, *clmc, p3, p4);
         }
     }
 
-    if (r == 0) {
-
-        compare_arrays((void*) *cm, (void*) *cmc, (void*) SIGNAL_MODEL, (void*) SIGNAL_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
-
-        if (r != 0) {
-
-            // Lock signal memory mutex.
-            pthread_mutex_lock(*mt);
-
-            set_signal(p6, p7, p8, (void*) *ma, (void*) *mac, (void*) *mm, (void*) *mmc, (void*) *md, (void*) *mdc, (void*) NORMAL_PRIORITY, p9);
-
-            // Set interrupt request flag, in order to notify the signal checker
-            // that a new signal has been placed in the signal memory.
-            **irq = *NUMBER_1_INTEGER;
-
-            // Unlock signal memory mutex.
-            pthread_mutex_unlock(*mt);
-        }
-    }
-
-    if (r == 0) {
-
-        compare_arrays((void*) *cm, (void*) *cmc, (void*) TCP_SOCKET_MODEL, (void*) TCP_SOCKET_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
-
-        if (r != 0) {
-
-/*??
-            // The socket number for the signal id.
-            // The index for the signal id in the array is the same index
-            // in the client socket number array.
-            int i = -1;
-
-            get_index_for_signal_id(p2, p9, (void*) &i);
-
-            if (i >= 0) {
-
-                // The client socket.
-                int* cs = NULL_POINTER;
-
-                get_client_socket_number_for_index(p2, (void*) &i, (void*) &cs);
-
-                if (*cs >= 0) {
-
-                    //in abh?ngigkeit vom empf?nger
-                    //m?ssen die Daten verschieden aufbereitet werden
-                    //zur Zeit nur TCP socket f?r webanwednung
-                    //darum z.Z. immer html-Aufbereitung
-                    //--> das bedeuet, das ermittelte Modell
-                    //muss noch f?r die Ausgabe aufbereuitet (tranlate) werden.
-
-                    //create the destination for the send model
-                    void* dest = NULL_POINTER;
-                    int* dest_count = NULL_POINTER;
-                    int* dest_size = NULL_POINTER;
-
-                    allocate(&dest_count, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
-                    allocate(&dest_size, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
-                    *dest_count = 0;
-                    *dest_size  = 0;
-                    allocate(&dest, dest_size, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
-
-                    encode_model(&dest, dest_count, dest_size,
-                        *ma, *mac, *mm, *mmc, *md, *mdc,
-                        (void*) HTML_ABSTRACTION, (void*) HTML_ABSTRACTION_COUNT,
-                        p3, p4);
-
-                    // The temporary count, size.
-                    int tc = 0;
-                    int ts = 0;
-
-                    send_tcp_socket((void*) &cs, (void*) &tc, (void*) &ts, (void*) dest, (void*) dest_count);
-
-                    // Remove client socket number and main signal id from internal memory.
-                    remove_relation_clientsocketnumber_mainsignalid(p2, (void*) &i);
-
-                    // Close socket.
-                    close(*cs);
-
-                    // Destroy destination.
-                    deallocate(&dest, dest_size, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
-                    deallocate(&dest_count, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
-                    deallocate(&dest_size, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
-
-                } else {
-
-                    log_message_debug("Could not send tcp socket message. The client socket number was not found.");
-                }
-
-            } else {
-
-                log_message_debug("Could not send tcp socket message. The signal id index is invalid.");
-            }
-*/
-        }
-    }
-
-    if (r == 0) {
-
-        compare_arrays((void*) *cm, (void*) *cmc, (void*) UNIX_SOCKET_MODEL, (void*) UNIX_SOCKET_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
-
-        if (r != 0) {
-
-            send_unix_socket(p2, *mm, *mmc, p3, p4);
-        }
-    }
-
-    if (r == 0) {
+    if (r == *NUMBER_0_INTEGER) {
 
         compare_arrays((void*) *cm, (void*) *cmc, (void*) X_WINDOW_SYSTEM_MODEL, (void*) X_WINDOW_SYSTEM_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-        if (r != 0) {
+        if (r != *NUMBER_0_INTEGER) {
 
             send_x_window_system(p2, *mm, *mmc, p3, p4);
         }
     }
-}
 
-/**
- * Refreshes the url.
- *
- * @param p0 the parameters
- * @param p1 the parameters count
- * @param p2 the internal memory
- * @param p3 the knowledge memory
- * @param p4 the knowledge memory count
- * @param p5 the knowledge memory size
- * @param p6 the signal id
- */
-void refresh_url(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6) {
+    if (r == *NUMBER_0_INTEGER) {
 
-    log_message_debug("Refresh url.");
+        compare_arrays((void*) *cm, (void*) *cmc, (void*) WWW_SERVICE_MODEL, (void*) WWW_SERVICE_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-    // The message abstraction.
-    void** urla = &NULL_POINTER;
-    void** urlac = &NULL_POINTER;
-    void** urlas = &NULL_POINTER;
-    // The message model.
-    void** urlm = &NULL_POINTER;
-    void** urlmc = &NULL_POINTER;
-    void** urlms = &NULL_POINTER;
-    // The message details.
-    void** urld = &NULL_POINTER;
-    void** urldc = &NULL_POINTER;
-    void** urlds = &NULL_POINTER;
+        if (r != *NUMBER_0_INTEGER) {
 
-    // Get language.
-    get_universal_compound_element_by_name(p0, p1,
-        (void*) SEND_URL_NAME, (void*) SEND_URL_NAME_COUNT,
-        (void*) &urla, (void*) &urlac, (void*) &urlas,
-        (void*) &urlm, (void*) &urlmc, (void*) &urlms,
-        (void*) &urld, (void*) &urldc, (void*) &urlds,
-        p3, p4);
+            send_socket(p2, (void*) WWW_BASE_INTERNAL, *rm, *rmc, (void*) WWW_PORT, *nm, *nmc, *stm, *stmc, *mom, *momc, *ma, *mac, *mm, *mmc, *md, *mdc, p3, p4);
+        }
+    }
 
-/*??
-    if ((*urla != NULL_POINTER)
-         && (*urlac != NULL_POINTER)
-         && (*urlas != NULL_POINTER)
-         && (*urlm != NULL_POINTER)
-         && (*urlmc != NULL_POINTER)
-         && (*urlms != NULL_POINTER)
-         && (*urld != NULL_POINTER)
-         && (*urldc != NULL_POINTER)
-         && (*urlds != NULL_POINTER)) {
+    if (r == *NUMBER_0_INTEGER) {
 
-        // The socket number for the signal id.
-        // The index for the signal id in the array is the same index
-        // in the client socket number array.
-        int i = -1;
+        compare_arrays((void*) *cm, (void*) *cmc, (void*) CYBOI_SERVICE_MODEL, (void*) CYBOI_SERVICE_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-        get_index_for_signal_id(p2, p6, (void*) &i);
+        if (r != *NUMBER_0_INTEGER) {
 
-        if (i >= 0) {
+            send_socket(p2, (void*) CYBOI_BASE_INTERNAL, *rm, *rmc, (void*) CYBOI_PORT, *nm, *nmc, *stm, *stmc, *mom, *momc, *ma, *mac, *mm, *mmc, *md, *mdc, p3, p4);
+        }
+    }
 
-            // The client socket.
-            int* cs = NULL_POINTER;
+    if (r == *NUMBER_0_INTEGER) {
 
-            get_client_socket_number_for_index(p2, (void*) &i, (void*) &cs);
+        compare_arrays((void*) *cm, (void*) *cmc, (void*) LATEX_MODEL, (void*) LATEX_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-            if (*cs >= 0) {
+        if (r != *NUMBER_0_INTEGER) {
 
-                char msg_refresh_part_1[] = "<head> <meta http-equiv='expires' content='0'>  <meta http-equiv='refresh' content='0; URL=";
-                char msg_refresh_part_3[] = "'></head><body></body>";
-                int msg_part_1_count = strlen( msg_refresh_part_1 );
-                int msg_part_3_count = strlen( msg_refresh_part_3 );
-
-                //create the destination for the send model
-                void* dest = NULL_POINTER;
-                int* dest_count = NULL_POINTER;
-                int* dest_size = NULL_POINTER;
-
-                allocate(&dest_count, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
-                allocate(&dest_size, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
-                *dest_count = 0;
-                *dest_size  = 0;
-                allocate(&dest, dest_size, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
-
-                parse(&dest, dest_count, dest_size, &msg_refresh_part_1[0], &msg_part_1_count, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
-                parse(&dest, dest_count, dest_size, *urlm, *urlmc, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
-                parse(&dest, dest_count, dest_size, &msg_refresh_part_3[0], &msg_part_3_count, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
-
-                // The temporary count, size.
-                int tc = 0;
-                int ts = 0;
-
-                send_tcp_socket((void*) &cs, (void*) &tc, (void*) &ts, (void*) dest, (void*) dest_count);
-
-                // Remove client socket number and main signal id from internal memory.
-                remove_relation_clientsocketnumber_mainsignalid(p2, (void*) &i);
-
-                // Close socket.
-                close(*cs);
-
-                // Destroy destination.
-                deallocate(&dest, dest_size, CHARACTER_VECTOR_ABSTRACTION, CHARACTER_VECTOR_ABSTRACTION_COUNT);
-                deallocate(&dest_count, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
-                deallocate(&dest_size, PRIMITIVE_COUNT, INTEGER_VECTOR_ABSTRACTION, INTEGER_VECTOR_ABSTRACTION_COUNT);
-            }
+            send_latex(p2, *mm, *mmc, p3, p4);
         }
     }
-*/
 }
 
 /* SEND_SOURCE */
