@@ -1,7 +1,7 @@
 /*
  * $RCSfile: shutdown_linux_console.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.15 $ $Date: 2006/08/19 02:04:48 $ $Author: christian $
+ * @version $Revision: 1.20 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @description
  */
@@ -31,9 +31,10 @@
 #ifdef LINUX_OPERATING_SYSTEM
 
 #include <termios.h>
-#include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/variables/variables.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/accessor.c"
@@ -51,30 +52,36 @@ void shutdown_linux_console(void* p0, void* p1, void* p2, void* p3) {
 
     log_message_debug("Shutdown linux console.");
 
-    // The linux console (terminal device name) internal.
-    FILE** ti = (FILE**) &NULL_POINTER;
+    // The linux console input- and output stream internal.
+    FILE** ipi = (FILE**) NULL_POINTER;
+    FILE** opi = (FILE**) NULL_POINTER;
 
-    // Get linux console internal.
-    get(p0, (void*) LINUX_CONSOLE_FILE_DESCRIPTOR_INTERNAL, (void*) &ti, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+    // Get linux console internals.
+    get(p0, (void*) LINUX_CONSOLE_INPUT_FILE_DESCRIPTOR_INTERNAL, (void*) &ipi, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+    get(p0, (void*) LINUX_CONSOLE_OUTPUT_FILE_DESCRIPTOR_INTERNAL, (void*) &opi, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
 
-    if (*ti != NULL_POINTER) {
+    // Only deallocate linux console resources if at least one,
+    // the input- OR output stream internal is null.
+    if ((*ipi != *NULL_POINTER) || (opi == *NULL_POINTER)) {
 
         // Interrupt linux console service thread.
         interrupt_linux_console();
 
-        // The linux console (terminal device name).
-        FILE** t = (FILE**) &NULL_POINTER;
+        // The linux console input- and output stream.
+        FILE** ip = (FILE**) NULL_POINTER;
+        FILE** op = (FILE**) NULL_POINTER;
         // The original termios interface.
-        struct termios** to = (struct termios**) &NULL_POINTER;
+        struct termios** to = (struct termios**) NULL_POINTER;
         // The working termios interface.
-        struct termios** tw = (struct termios**) &NULL_POINTER;
+        struct termios** tw = (struct termios**) NULL_POINTER;
         // The character buffer that was used in the thread procedure.
-        void** b = &NULL_POINTER;
-        void** bc = &NULL_POINTER;
-        void** bs = &NULL_POINTER;
+        void** b = NULL_POINTER;
+        void** bc = NULL_POINTER;
+        void** bs = NULL_POINTER;
 
         // Get linux console internals.
-        get(p0, (void*) LINUX_CONSOLE_FILE_DESCRIPTOR_INTERNAL, (void*) &t, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+        get(p0, (void*) LINUX_CONSOLE_INPUT_FILE_DESCRIPTOR_INTERNAL, (void*) &ip, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+        get(p0, (void*) LINUX_CONSOLE_OUTPUT_FILE_DESCRIPTOR_INTERNAL, (void*) &op, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
         get(p0, (void*) LINUX_CONSOLE_ORIGINAL_ATTRIBUTES_INTERNAL, (void*) &to, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
         get(p0, (void*) LINUX_CONSOLE_WORKING_ATTRIBUTES_INTERNAL, (void*) &tw, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
         // Get character buffer.
@@ -82,17 +89,18 @@ void shutdown_linux_console(void* p0, void* p1, void* p2, void* p3) {
         get(p0, (void*) LINUX_CONSOLE_THREAD_CHARACTER_BUFFER_COUNT_INTERNAL, (void*) &bc, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
         get(p0, (void*) LINUX_CONSOLE_THREAD_CHARACTER_BUFFER_SIZE_INTERNAL, (void*) &bs, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
 
-        // Get file descriptor for file stream.
-        int d = fileno(*t);
+        // Get file descriptor for output file stream.
+        int opd = fileno(*op);
         // Reset original linux console attributes.
-        tcsetattr(d, TCSANOW, *to);
+        tcsetattr(opd, TCSANOW, *to);
 
         // Destroy linux console internals.
+        //
         // CAUTION! Use descending order, as opposed to the creation!
         // CAUTION! Do NOT use references &, because variables are **
         // and *&variable equals the variable alone.
-//?? DO NOT deallocate t because it refers to stdout of the system for testing!
-//??        deallocate((void*) t, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
+        //?? DO NOT deallocate t because it refers to stdout of the system for testing!
+        //?? deallocate((void*) t, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
         free(*tw);
         free(*to);
 
