@@ -1,7 +1,7 @@
 /*
  * $RCSfile: checker.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.21 $ $Date: 2006/06/27 21:07:27 $ $Author: christian $
+ * @version $Revision: 1.27 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @author Rolf Holzmueller <rolf.holzmueller@gmx.de>
  */
@@ -29,8 +29,9 @@
 #define CHECKER_SOURCE
 
 #include "../controller/handler.c"
-#include "../globals/constants/integer_constants.c"
-#include "../globals/constants/log_constants.c"
+#include "../globals/constants/integer/integer_constants.c"
+#include "../globals/constants/log/log_message_constants.c"
+#include "../globals/constants/pointer/pointer_constants.c"
 #include "../globals/variables/variables.c"
 #include "../globals/logger/logger.c"
 #include "../memoriser/accessor/signal_memory_accessor.c"
@@ -45,33 +46,33 @@
  * @param p4 the signal memory
  * @param p5 the signal memory count
  * @param p6 the signal memory size
- * @param p7 the signal memory mutex
- * @param p8 the interrupt request flag
+ * @param p7 the interrupt request flag
+ * @param p8 the signal memory mutex
  */
 void check(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6, void* p7, void* p8) {
 
-    if (p8 != NULL_POINTER) {
+    if (p7 != *NULL_POINTER) {
 
-        int* irq = (int*) p8;
+        int* irq = (int*) p7;
 
         log_message_debug("\n\n");
-        log_message((void*) INFO_LOG_LEVEL, (void*) CHECK_FOR_SIGNALS_MESSAGE, (void*) CHECK_FOR_SIGNALS_MESSAGE_COUNT);
+        log_message((void*) INFORMATION_LOG_LEVEL, (void*) CHECK_FOR_SIGNALS_MESSAGE, (void*) CHECK_FOR_SIGNALS_MESSAGE_COUNT);
 
         // The shutdown flag.
         int f = *NUMBER_0_INTEGER;
         // The abstraction.
-        void** a = &NULL_POINTER;
-        void** ac = &NULL_POINTER;
+        void** a = NULL_POINTER;
+        void** ac = NULL_POINTER;
         // The model (signal operation).
-        void** m = &NULL_POINTER;
-        void** mc = &NULL_POINTER;
+        void** m = NULL_POINTER;
+        void** mc = NULL_POINTER;
         // The details (parameters).
-        void** d = &NULL_POINTER;
-        void** dc = &NULL_POINTER;
+        void** d = NULL_POINTER;
+        void** dc = NULL_POINTER;
         // The priority.
-        void** p = &NULL_POINTER;
+        void** p = NULL_POINTER;
         // The signal id.
-        void** id = &NULL_POINTER;
+        void** id = NULL_POINTER;
         // The direct execution flag.
         int x = *NUMBER_0_INTEGER;
         // The highest priority index.
@@ -115,13 +116,13 @@ void check(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6,
 //??    test_knowledge_memory(p1, p2, 5);
 
                 // Lock signal memory mutex.
-                pthread_mutex_lock((pthread_mutex_t*) p7);
+                pthread_mutex_lock((pthread_mutex_t*) p8);
 
                 // Remove signal from signal memory.
                 remove_signal(p4, p5, p6, (void*) &i);
 
                 // Unlock signal memory mutex.
-                pthread_mutex_unlock((pthread_mutex_t*) p7);
+                pthread_mutex_unlock((pthread_mutex_t*) p8);
 
                 //?? CAUTION! TODO? UNCERTAIN!
                 //?? The handle procedure possibly needs to stand
@@ -155,18 +156,18 @@ void check(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6,
 */
 
                 // Reset abstraction.
-                a = &NULL_POINTER;
-                ac = &NULL_POINTER;
+                a = NULL_POINTER;
+                ac = NULL_POINTER;
                 // Reset model (signal operation).
-                m = &NULL_POINTER;
-                mc = &NULL_POINTER;
+                m = NULL_POINTER;
+                mc = NULL_POINTER;
                 // Reset details (parameters).
-                d = &NULL_POINTER;
-                dc = &NULL_POINTER;
+                d = NULL_POINTER;
+                dc = NULL_POINTER;
                 // Reset priority.
-                p = &NULL_POINTER;
+                p = NULL_POINTER;
                 // Reset main signal id.
-                id = &NULL_POINTER;
+                id = NULL_POINTER;
                 // Reset direct execution flag.
                 x = *NUMBER_0_INTEGER;
                 // Reset highest priority index.
@@ -257,10 +258,11 @@ void check(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6,
                 while (*irq == *NUMBER_0_INTEGER) {
 
                     sleep(0.1);
+//??                    sleep(1.0);
                 }
 
                 // Lock signal memory mutex.
-                pthread_mutex_lock((pthread_mutex_t*) p7);
+                pthread_mutex_lock((pthread_mutex_t*) p8);
 
                 // Reset interrupt request flag.
                 // The interrupt is reset to zero here because its purpose of
@@ -271,7 +273,7 @@ void check(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6,
                 *irq = *NUMBER_0_INTEGER;
 
                 // Unlock signal memory mutex.
-                pthread_mutex_unlock((pthread_mutex_t*) p7);
+                pthread_mutex_unlock((pthread_mutex_t*) p8);
             }
         }
 
