@@ -1,7 +1,7 @@
 /*
  * $RCSfile: handler.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.11 $ $Date: 2006/08/19 02:04:48 $ $Author: christian $
+ * @version $Revision: 1.18 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @author Rolf Holzmueller <rolf.holzmueller@gmx.de>
  */
@@ -30,8 +30,10 @@
 
 #include "../controller/handler/compound_handler.c"
 #include "../controller/handler/operation_handler.c"
-#include "../globals/constants/abstraction_constants.c"
-#include "../globals/constants/log_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../globals/constants/integer/integer_constants.c"
+#include "../globals/constants/log/log_message_constants.c"
+#include "../globals/constants/pointer/pointer_constants.c"
 #include "../globals/logger/logger.c"
 #include "../memoriser/array.c"
 
@@ -48,8 +50,8 @@
  * @param p4 the signal memory
  * @param p5 the signal memory count
  * @param p6 the signal memory size
- * @param p7 the signal memory blocked flag
- * @param p8 the interrupt request flag
+ * @param p7 the interrupt request flag
+ * @param p8 the signal memory mutex
  * @param p9 the shutdown flag
  * @param p10 the abctraction
  * @param p11 the abstraction count
@@ -65,36 +67,39 @@ void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
     void* p7, void* p8, void* p9, void* p10, void* p11,
     void* p12, void* p13,  void* p14, void* p15, void* p16, void* p17, void* p18) {
 
-    // The logic abstraction.
-    void** a = &NULL_POINTER;
-    void** ac = &NULL_POINTER;
-    void** as = &NULL_POINTER;
-    // The logic model.
-    void** m = &NULL_POINTER;
-    void** mc = &NULL_POINTER;
-    void** ms = &NULL_POINTER;
-    // The logic details.
-    void** d = &NULL_POINTER;
-    void** dc = &NULL_POINTER;
-    void** ds = &NULL_POINTER;
+    log_message_debug("Information: Handle signal.");
 
-    // The encapsulated logic abstraction.
-    void** ea = &NULL_POINTER;
-    void** eac = &NULL_POINTER;
-    void** eas = &NULL_POINTER;
-    // The encapsulated logic model.
-    void** em = &NULL_POINTER;
-    void** emc = &NULL_POINTER;
-    void** ems = &NULL_POINTER;
-    // The encapsulated logic details.
-    void** ed = &NULL_POINTER;
-    void** edc = &NULL_POINTER;
-    void** eds = &NULL_POINTER;
+    // The logic name, abstraction, model, details.
+    void** n = NULL_POINTER;
+    void** nc = NULL_POINTER;
+    void** ns = NULL_POINTER;
+    void** a = NULL_POINTER;
+    void** ac = NULL_POINTER;
+    void** as = NULL_POINTER;
+    void** m = NULL_POINTER;
+    void** mc = NULL_POINTER;
+    void** ms = NULL_POINTER;
+    void** d = NULL_POINTER;
+    void** dc = NULL_POINTER;
+    void** ds = NULL_POINTER;
+    // The encapsulated logic name, abstraction, model, details.
+    void** en = NULL_POINTER;
+    void** enc = NULL_POINTER;
+    void** ens = NULL_POINTER;
+    void** ea = NULL_POINTER;
+    void** eac = NULL_POINTER;
+    void** eas = NULL_POINTER;
+    void** em = NULL_POINTER;
+    void** emc = NULL_POINTER;
+    void** ems = NULL_POINTER;
+    void** ed = NULL_POINTER;
+    void** edc = NULL_POINTER;
+    void** eds = NULL_POINTER;
 
     // The comparison result.
-    int r = 0;
+    int r = *NUMBER_0_INTEGER;
 
-    if (r == 0) {
+    if (r == *NUMBER_0_INTEGER) {
 
         // CAUTION! Do NOT remove this section with "COMPOUND_ABSTRACTION"!
         // It is needed for at least initial startup logic residing in CYBOL
@@ -102,18 +107,18 @@ void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
         // knowledge models in the knowledge memory.
         compare_arrays(p10, p11, (void*) COMPOUND_ABSTRACTION, (void*) COMPOUND_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-        if (r != 0) {
+        if (r != *NUMBER_0_INTEGER) {
 
             // Handle compound logic.
             handle_compound(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p12, p13, p16, p17, p18);
         }
     }
 
-    if (r == 0) {
+    if (r == *NUMBER_0_INTEGER) {
 
         compare_arrays(p10, p11, (void*) ENCAPSULATED_KNOWLEDGE_ABSTRACTION, (void*) ENCAPSULATED_KNOWLEDGE_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-        if (r != 0) {
+        if (r != *NUMBER_0_INTEGER) {
 
             // Get compound logic element as double-encapsulated model.
             //
@@ -131,27 +136,28 @@ void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
             //
             // Compare also with procedure "get_universal_compound_element_by_name"
             // in source file "memoriser/accessor/compound_accessor.c"!
-            get_compound_element_by_name(p1, p2, NULL_POINTER, NULL_POINTER,
+            get_compound_element_by_name(p1, p2, *NULL_POINTER, *NULL_POINTER,
                 p12, p13,
+                (void*) &en, (void*) &enc, (void*) &ens,
                 (void*) &ea, (void*) &eac, (void*) &eas,
                 (void*) &em, (void*) &emc, (void*) &ems,
                 (void*) &ed, (void*) &edc, (void*) &eds);
 
             // The knowledge root does not have a details container with meta
             // information, which is why a null pointer is handed over here twice.
-            get_compound_element_by_name(p1, p2, NULL_POINTER, NULL_POINTER,
-                *em, *emc, &a, &ac, &as, &m, &mc, &ms, &d, &dc, &ds);
+            get_compound_element_by_name(p1, p2, *NULL_POINTER, *NULL_POINTER,
+                *em, *emc, &n, &nc, &ns, &a, &ac, &as, &m, &mc, &ms, &d, &dc, &ds);
 
             // Handle compound logic.
             handle_compound(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, *m, *mc, p16, p17, p18);
         }
     }
 
-    if (r == 0) {
+    if (r == *NUMBER_0_INTEGER) {
 
         compare_arrays(p10, p11, (void*) KNOWLEDGE_ABSTRACTION, (void*) KNOWLEDGE_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-        if (r != 0) {
+        if (r != *NUMBER_0_INTEGER) {
 
             // Get compound logic element as encapsulated model.
             //
@@ -169,26 +175,26 @@ void handle(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
             //
             // Compare also with procedure "get_universal_compound_element_by_name"
             // in source file "memoriser/accessor/compound_accessor.c"!
-            get_compound_element_by_name(p1, p2, NULL_POINTER, NULL_POINTER,
-                p12, p13, &a, &ac, &as, &m, &mc, &ms, &d, &dc, &ds);
+            get_compound_element_by_name(p1, p2, *NULL_POINTER, *NULL_POINTER,
+                p12, p13, &n, &nc, &ns, &a, &ac, &as, &m, &mc, &ms, &d, &dc, &ds);
 
             // Handle compound logic.
             handle_compound(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, *m, *mc, p16, p17, p18);
         }
     }
 
-    if (r == 0) {
+    if (r == *NUMBER_0_INTEGER) {
 
         compare_arrays(p10, p11, (void*) OPERATION_ABSTRACTION, (void*) OPERATION_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-        if (r != 0) {
+        if (r != *NUMBER_0_INTEGER) {
 
             // Handle simple operation.
             handle_operation(p0, p1, p2, p3, p4, p5, p6, p7, p8, p9, p12, p13, p14, p15, p16, p17);
         }
     }
 
-    if (r == 0) {
+    if (r == *NUMBER_0_INTEGER) {
 
         log_message((void*) WARNING_LOG_LEVEL, (void*) COULD_NOT_HANDLE_SIGNAL_THE_SIGNAL_ABSTRACTION_IS_UNKNOWN_MESSAGE, (void*) COULD_NOT_HANDLE_SIGNAL_THE_SIGNAL_ABSTRACTION_IS_UNKNOWN_MESSAGE_COUNT);
     }
