@@ -1,7 +1,7 @@
 /*
  * $RCSfile: operation_handler.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.24 $ $Date: 2006/06/20 22:35:09 $ $Author: christian $
+ * @version $Revision: 1.29 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @author Rolf Holzmueller <rolf.holzmueller@gmx.de>
  */
@@ -43,13 +43,11 @@
 #include "../../applicator/send.c"
 #include "../../applicator/shutdown.c"
 #include "../../applicator/startup.c"
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/model_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/cybol/cybol_model_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/array.c"
-//?? TEST only
-#include "../../tester/tester.c"
 
 /**
  * Handles the operation signal.
@@ -61,8 +59,8 @@
  * @param p4 the signal memory
  * @param p5 the signal memory count
  * @param p6 the signal memory size
- * @param p7 the signal memory blocked flag
- * @param p8 the interrupt request flag
+ * @param p7 the interrupt request flag
+ * @param p8 the signal memory mutex
  * @param p9 the shutdown flag
  * @param p10 the signal (operation)
  * @param p11 the signal count
@@ -75,13 +73,7 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
     void* p7, void* p8, void* p9, void* p10, void* p11, void* p12, void* p13, void* p14, void* p15) {
 
     log_message_debug("\n\n");
-    log_message((void*) INFO_LOG_LEVEL, (void*) HANDLE_OPERATION_MESSAGE, (void*) HANDLE_OPERATION_MESSAGE_COUNT);
-
-    //?? TEST
-//??    fprintf(stderr, "TEST: Operation: %s\n", (char*) p10);
-//??    fprintf(stderr, "TEST: Operation count: %i\n", *((int*) p11));
-//??    fprintf(stderr, "TEST handler p1: %i\n", p1);
-//??    test_knowledge_memory(p1, p2, 5);
+    log_message((void*) INFORMATION_LOG_LEVEL, (void*) HANDLE_OPERATION_MESSAGE, (void*) HANDLE_OPERATION_MESSAGE_COUNT);
 
     // The comparison result.
     int r = 0;
@@ -226,7 +218,7 @@ void handle_operation(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5
 
         if (r != 0) {
 
-            log_message((void*) INFO_LOG_LEVEL, (void*) SET_SHUTDOWN_FLAG_MESSAGE, (void*) SET_SHUTDOWN_FLAG_MESSAGE_COUNT);
+            log_message((void*) INFORMATION_LOG_LEVEL, (void*) SET_SHUTDOWN_FLAG_MESSAGE, (void*) SET_SHUTDOWN_FLAG_MESSAGE_COUNT);
 
             int* f = (int*) p9;
             *f = 1;
