@@ -1,7 +1,7 @@
 /*
  * $RCSfile: manager.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.25 $ $Date: 2006/08/19 02:04:48 $ $Author: christian $
+ * @version $Revision: 1.36 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -32,9 +32,11 @@
 #include "../controller/manager/initial_signal_manager.c"
 #include "../controller/manager/internal_memory_manager.c"
 #include "../controller/manager/system_signal_handler_manager.c"
-#include "../globals/constants/abstraction_constants.c"
-#include "../globals/constants/channel_constants.c"
-#include "../globals/constants/log_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../globals/constants/cybol/cybol_channel_constants.c"
+#include "../globals/constants/integer/integer_constants.c"
+#include "../globals/constants/log/log_message_constants.c"
+#include "../globals/constants/pointer/pointer_constants.c"
 #include "../globals/logger/logger.c"
 #include "../globals/variables/variables.c"
 #include "../memoriser/allocator.c"
@@ -67,14 +69,14 @@ void manage(void* p0, void* p1) {
     log_message_debug("Info: Manage system.");
 
     // The internal memory.
-    void* i = NULL_POINTER;
+    void* i = *NULL_POINTER;
     int* ic = INTERNAL_MEMORY_ELEMENTS_COUNT;
     int* is = INTERNAL_MEMORY_ELEMENTS_COUNT;
 
     // The knowledge memory.
-    void* k = NULL_POINTER;
-    int* kc = NULL_POINTER;
-    int* ks = NULL_POINTER;
+    void* k = *NULL_POINTER;
+    int* kc = (int*) *NULL_POINTER;
+    int* ks = (int*) *NULL_POINTER;
 
     // A meta knowledge memory?
     // Theoretically, a meta knowledge memory could be created, too, and be
@@ -90,16 +92,9 @@ void manage(void* p0, void* p1) {
     // #something                               --> meta knowledge about knowledge root = nonsense
 
     // The signal memory.
-    void* s = NULL_POINTER;
-    int* sc = NULL_POINTER;
-    int* ss = NULL_POINTER;
-
-    // The signal memory mutex.
-    pthread_mutex_t* smt = NULL_POINTER;
-    // The linux console mutex.
-    pthread_mutex_t* lmt = NULL_POINTER;
-    // The x window system mutex.
-    pthread_mutex_t* xmt = NULL_POINTER;
+    void* s = *NULL_POINTER;
+    int* sc = (int*) *NULL_POINTER;
+    int* ss = (int*) *NULL_POINTER;
 
     //
     // The signal memory interrupt request flag.
@@ -126,7 +121,18 @@ void manage(void* p0, void* p1) {
     // Both of these assumptions are true on all of the machines that the GNU C
     // library supports and on all known POSIX systems.
     //
-    volatile sig_atomic_t* irq = NULL_POINTER;
+    volatile sig_atomic_t* irq = (volatile sig_atomic_t*) *NULL_POINTER;
+
+    // The signal memory mutex.
+    pthread_mutex_t* signal_memory_mutex = (pthread_mutex_t*) *NULL_POINTER;
+    // The linux console mutex.
+    pthread_mutex_t* linux_console_mutex = (pthread_mutex_t*) *NULL_POINTER;
+    // The x window system mutex.
+    pthread_mutex_t* x_window_system_mutex = (pthread_mutex_t*) *NULL_POINTER;
+    // The www service mutex.
+    pthread_mutex_t* www_service_mutex = (pthread_mutex_t*) *NULL_POINTER;
+    // The cyboi service mutex.
+    pthread_mutex_t* cyboi_service_mutex = (pthread_mutex_t*) *NULL_POINTER;
 
     // Allocate knowledge memory count, size.
     allocate((void*) &kc, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
@@ -134,14 +140,18 @@ void manage(void* p0, void* p1) {
     // Allocate signal memory count, size.
     allocate((void*) &sc, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
     allocate((void*) &ss, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-    // Allocate signal memory mutex.
-    smt = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
-    // Allocate linux console mutex.
-    lmt = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
-    // Allocate x window system mutex.
-    xmt = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
     // Allocate signal memory interrupt request flag.
     irq = (volatile sig_atomic_t*) malloc(sizeof(volatile sig_atomic_t));
+    // Allocate signal memory mutex.
+    signal_memory_mutex = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
+    // Allocate linux console mutex.
+    linux_console_mutex = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
+    // Allocate x window system mutex.
+    x_window_system_mutex = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
+    // Allocate www service mutex.
+    www_service_mutex = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
+    // Allocate cyboi service mutex.
+    cyboi_service_mutex = (pthread_mutex_t*) malloc(sizeof(pthread_mutex_t));
 
     // Initialise knowledge memory count, size.
     *kc = *NUMBER_0_INTEGER;
@@ -149,14 +159,33 @@ void manage(void* p0, void* p1) {
     // Initialise signal memory count, size.
     *sc = *NUMBER_0_INTEGER;
     *ss = *NUMBER_0_INTEGER;
-    // Initialise signal memory mutex.
-    pthread_mutex_init(smt, NULL_POINTER);
-    // Initialise linux console mutex.
-    pthread_mutex_init(lmt, NULL_POINTER);
-    // Initialise x window system mutex.
-    pthread_mutex_init(xmt, NULL_POINTER);
     // Initialise signal memory interrupt request flag.
     *irq = *NUMBER_0_INTEGER;
+    // Initialise signal memory mutex.
+    // The second parameter specifies attributes that are to be used to
+    // initialise the mutex. If the parameter is null, the mutex is
+    // initialised with default attributes.
+    pthread_mutex_init(signal_memory_mutex, *NULL_POINTER);
+    // Initialise linux console mutex.
+    // The second parameter specifies attributes that are to be used to
+    // initialise the mutex. If the parameter is null, the mutex is
+    // initialised with default attributes.
+    pthread_mutex_init(linux_console_mutex, *NULL_POINTER);
+    // Initialise x window system mutex.
+    // The second parameter specifies attributes that are to be used to
+    // initialise the mutex. If the parameter is null, the mutex is
+    // initialised with default attributes.
+    pthread_mutex_init(x_window_system_mutex, *NULL_POINTER);
+    // Initialise www service mutex.
+    // The second parameter specifies attributes that are to be used to
+    // initialise the mutex. If the parameter is null, the mutex is
+    // initialised with default attributes.
+    pthread_mutex_init(www_service_mutex, *NULL_POINTER);
+    // Initialise cyboi service mutex.
+    // The second parameter specifies attributes that are to be used to
+    // initialise the mutex. If the parameter is null, the mutex is
+    // initialised with default attributes.
+    pthread_mutex_init(cyboi_service_mutex, *NULL_POINTER);
 
     // Allocate internal memory.
     allocate((void*) &i, (void*) is, (void*) INTERNAL_MEMORY_ABSTRACTION, (void*) INTERNAL_MEMORY_ABSTRACTION_COUNT);
@@ -171,12 +200,12 @@ void manage(void* p0, void* p1) {
     // determined by constants. The items HAVE TO be assigned an
     // initial value, since all source code relies on them.
     //
-    // Most values are compared against the NULL_POINTER constant
+    // Most values are compared against the *NULL_POINTER constant
     // to find out whether they are set or not. If now initial values
     // would be arbitrary pointers, the program would follow a wrong path,
     // because it would guess that an instance was properly allocated,
     // while in reality the value was just an arbitrary initial one.
-    // Therefore, such values are initialised with the well-defined NULL_POINTER.
+    // Therefore, such values are initialised with the well-defined *NULL_POINTER.
     //
     // CAUTION! ONLY ONE parameter can be handed over to threads!
     // For example, the tcp socket is running in an own thread.
@@ -185,8 +214,13 @@ void manage(void* p0, void* p1) {
     startup_internal_memory(i,
         (void*) &k, (void*) &kc, (void*) &ks,
         (void*) &s, (void*) &sc, (void*) &ss,
-        (void*) &smt, (void*) &lmt, (void*) &xmt,
-        (void*) &irq);
+        (void*) &irq,
+        (void*) &signal_memory_mutex,
+        (void*) &linux_console_mutex,
+        (void*) &x_window_system_mutex,
+        (void*) &www_service_mutex,
+        (void*) &cyboi_service_mutex);
+
     // Start up system signal handler.
     startup_system_signal_handler();
     // Start up initial signal.
@@ -197,15 +231,15 @@ void manage(void* p0, void* p1) {
     log_message_debug("Info: Allocate startup model.");
 
     // The startup model abstraction, model, details.
-    void* ma = NULL_POINTER;
-    int* mac = NULL_POINTER;
-    int* mas = NULL_POINTER;
-    void* mm = NULL_POINTER;
-    int* mmc = NULL_POINTER;
-    int* mms = NULL_POINTER;
-    void* md = NULL_POINTER;
-    int* mdc = NULL_POINTER;
-    int* mds = NULL_POINTER;
+    void* ma = *NULL_POINTER;
+    int* mac = (int*) *NULL_POINTER;
+    int* mas = (int*) *NULL_POINTER;
+    void* mm = *NULL_POINTER;
+    int* mmc = (int*) *NULL_POINTER;
+    int* mms = (int*) *NULL_POINTER;
+    void* md = *NULL_POINTER;
+    int* mdc = (int*) *NULL_POINTER;
+    int* mds = (int*) *NULL_POINTER;
 
     // Allocate startup model abstraction, model, details.
     allocate((void*) &mac, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
@@ -216,19 +250,21 @@ void manage(void* p0, void* p1) {
     // It is not needed for the startup signal.
 
     // Initialise startup model abstraction, model, details.
-    *mac = 0;
-    *mas = 0;
-    *mmc = 0;
-    *mms = 0;
+    *mac = *NUMBER_0_INTEGER;
+    *mas = *NUMBER_0_INTEGER;
+    *mmc = *NUMBER_0_INTEGER;
+    *mms = *NUMBER_0_INTEGER;
     // CAUTION! Do not allocate startup model details!
     // It is not needed for the startup signal.
 
     // Create startup model abstraction, model, details.
     receive_file_system_model((void*) &ma, (void*) mac, (void*) mas,
+        *NULL_POINTER, *NULL_POINTER, *NULL_POINTER,
         (void*) COMPOUND_ABSTRACTION, (void*) COMPOUND_ABSTRACTION_COUNT,
         (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
         (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
     receive_file_system_model((void*) &mm, (void*) mmc, (void*) mms,
+        *NULL_POINTER, *NULL_POINTER, *NULL_POINTER,
         p0, p1,
         COMPOUND_ABSTRACTION, COMPOUND_ABSTRACTION_COUNT,
         FILE_CHANNEL, FILE_CHANNEL_COUNT);
@@ -239,9 +275,9 @@ void manage(void* p0, void* p1) {
     log_message_debug("Info: Add startup model as signal to signal memory.");
 
     // The signal id.
-    int* id = NULL_POINTER;
+    int* id = (int*) *NULL_POINTER;
     allocate((void*) &id, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-    *id = 0;
+    *id = *NUMBER_0_INTEGER;
     get_new_signal_id(s, (void*) sc, (void*) id);
 
     // Add startup signal to signal memory.
@@ -252,7 +288,7 @@ void manage(void* p0, void* p1) {
     // can be entered, checking for signals (events/ interrupts)
     // which are stored/ found in the signal memory.
     // The loop is left as soon as its shutdown flag is set.
-    check(i, k, (void*) kc, (void*) ks, s, (void*) sc, (void*) ss, (void*) smt, (void*) irq);
+    check(i, k, (void*) kc, (void*) ks, s, (void*) sc, (void*) ss, (void*) irq, (void*) signal_memory_mutex);
 
     // The following calls of "shutdown" procedures are just to be sure,
     // in case a cybol application developer has forgotten to call the
@@ -261,12 +297,12 @@ void manage(void* p0, void* p1) {
 
     // Shutdown linux console.
     shutdown_linux_console(i, k, (void*) kc, (void*) ks);
-    // Shutdown unix socket.
-    shutdown_unix_socket(i, k, (void*) kc, (void*) ks);
-    // Shutdown tcp socket.
-    shutdown_tcp_socket(i, k, (void*) kc, (void*) ks);
     // Shutdown x window system.
     shutdown_x_window_system(i, k, (void*) kc, (void*) ks);
+    // Shutdown www service.
+    shutdown_socket(i, (void*) WWW_BASE_INTERNAL, k, (void*) kc, (void*) ks);
+    // Shutdown cyboi service.
+    shutdown_socket(i, (void*) CYBOI_BASE_INTERNAL, k, (void*) kc, (void*) ks);
 
     // CAUTION! Do NOT remove any internal memory internals!
     // The internals have a fixed position within the internal memory.
@@ -275,20 +311,29 @@ void manage(void* p0, void* p1) {
     // at their original index anymore.
 
     // Destroy signal memory mutex.
-    pthread_mutex_destroy(smt);
+    pthread_mutex_destroy(signal_memory_mutex);
     // Destroy linux console mutex.
-    pthread_mutex_destroy(lmt);
+    pthread_mutex_destroy(linux_console_mutex);
     // Destroy x window system mutex.
-    pthread_mutex_destroy(xmt);
+    pthread_mutex_destroy(x_window_system_mutex);
+    // Destroy www service mutex.
+    pthread_mutex_destroy(www_service_mutex);
+    // Destroy cyboi service mutex.
+    pthread_mutex_destroy(cyboi_service_mutex);
 
     // Deallocate signal memory interrupt request flag.
     free((void*) irq);
     // Deallocate signal memory mutex.
-    free((void*) smt);
+    free((void*) signal_memory_mutex);
     // Deallocate linux console mutex.
-    free((void*) lmt);
+    free((void*) linux_console_mutex);
     // Deallocate x window system mutex.
-    free((void*) xmt);
+    free((void*) x_window_system_mutex);
+    // Deallocate www service mutex.
+    free((void*) www_service_mutex);
+    // Deallocate cyboi service mutex.
+    free((void*) cyboi_service_mutex);
+
     // Deallocate signal memory.
     deallocate((void*) &s, (void*) ss, (void*) SIGNAL_MEMORY_ABSTRACTION, (void*) SIGNAL_MEMORY_ABSTRACTION_COUNT);
     deallocate((void*) &sc, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
