@@ -1,7 +1,7 @@
 /*
  * $RCSfile: accessor.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,14 +20,14 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.8 $ $Date: 2006/04/20 22:36:10 $ $Author: christian $
+ * @version $Revision: 1.10 $ $Date: 2007/04/16 15:50:29 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef ACCESSOR_SOURCE
 #define ACCESSOR_SOURCE
 
-#include "../globals/constants/abstraction_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
 #include "../memoriser/accessor/character_vector_accessor.c"
 #include "../memoriser/accessor/compound_accessor.c"
 #include "../memoriser/accessor/double_vector_accessor.c"
