@@ -1,7 +1,7 @@
 /*
  * $RCSfile: internal_memory_accessor.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.15 $ $Date: 2006/04/21 23:49:11 $ $Author: christian $
+ * @version $Revision: 1.19 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @author Rolf Holzmueller <rolf.holzmueller@gmx.de>
  */
@@ -28,9 +28,10 @@
 #ifndef INTERNAL_MEMORY_ACCESSOR_SOURCE
 #define INTERNAL_MEMORY_ACCESSOR_SOURCE
 
-#include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/array.c"
 
@@ -69,9 +70,9 @@ void get(void* p0, void* p1, void* p2, void* p3, void* p4);
 void add_client_socket_number(void* p0, void* p1) {
 
     // The client sockets.
-    void** cs = &NULL_POINTER;
-    int** csc = (int**) &NULL_POINTER;
-    int** css = (int**) &NULL_POINTER;
+    void** cs = NULL_POINTER;
+    int** csc = (int**) NULL_POINTER;
+    int** css = (int**) NULL_POINTER;
 
     // Get client sockets.
     get(p0, (void*) TCP_CLIENT_SOCKETS_INTERNAL, (void*) &cs, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
@@ -103,9 +104,9 @@ void add_client_socket_number(void* p0, void* p1) {
 void add_signal_id(void* p0, void* p1) {
 
     // Get main signal id from internal memory.
-    void** id = &NULL_POINTER;
-    int** idc = (int**) &NULL_POINTER;
-    int** ids = (int**) &NULL_POINTER;
+    void** id = NULL_POINTER;
+    int** idc = (int**) NULL_POINTER;
+    int** ids = (int**) NULL_POINTER;
 
     get(p0, (void*) TCP_CLIENT_SOCKET_SIGNAL_IDS_INTERNAL, (void*) &id, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
     get(p0, (void*) TCP_CLIENT_SOCKET_SIGNAL_IDS_COUNT_INTERNAL, (void*) &idc, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
@@ -136,9 +137,9 @@ void add_signal_id(void* p0, void* p1) {
 void remove_relation_clientsocketnumber_mainsignalid(void* p0, void* p1) {
 
     // The signal id.
-    void** id = &NULL_POINTER;
-    int** idc = (int**) &NULL_POINTER;
-    int** ids = (int**) &NULL_POINTER;
+    void** id = NULL_POINTER;
+    int** idc = (int**) NULL_POINTER;
+    int** ids = (int**) NULL_POINTER;
 
     // Get signal id.
     get(p0, (void*) TCP_CLIENT_SOCKET_SIGNAL_IDS_INTERNAL, (void*) &id, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
@@ -151,9 +152,9 @@ void remove_relation_clientsocketnumber_mainsignalid(void* p0, void* p1) {
     (**idc)--;
 
     // Get client socket.
-    void** cs = &NULL_POINTER;
-    int** csc = (int**) &NULL_POINTER;
-    int** css = (int**) &NULL_POINTER;
+    void** cs = NULL_POINTER;
+    int** csc = (int**) NULL_POINTER;
+    int** css = (int**) NULL_POINTER;
 
     get(p0, (void*) TCP_CLIENT_SOCKETS_INTERNAL, (void*) &cs, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
     get(p0, (void*) TCP_CLIENT_SOCKETS_COUNT_INTERNAL, (void*) &csc, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
@@ -175,9 +176,9 @@ void remove_relation_clientsocketnumber_mainsignalid(void* p0, void* p1) {
 void get_index_for_signal_id(void* p0, void* p1, void* p2) {
 
     // The signal id.
-    void** id = &NULL_POINTER;
-    void** idc = &NULL_POINTER;
-    void** ids = &NULL_POINTER;
+    void** id = NULL_POINTER;
+    void** idc = NULL_POINTER;
+    void** ids = NULL_POINTER;
 
     // Get signal id.
     get(p0, (void*) TCP_CLIENT_SOCKET_SIGNAL_IDS_INTERNAL, (void*) &id, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
@@ -198,9 +199,9 @@ void get_index_for_signal_id(void* p0, void* p1, void* p2) {
 void get_client_socket_number_for_index(void* p0, void* p1, void* p2) {
 
     // The client sockets.
-    void** cs = &NULL_POINTER;
-    void** csc = &NULL_POINTER;
-    void** css = &NULL_POINTER;
+    void** cs = NULL_POINTER;
+    void** csc = NULL_POINTER;
+    void** css = NULL_POINTER;
 
     // Get client sockets.
     get(p0, (void*) TCP_CLIENT_SOCKETS_INTERNAL, (void*) &cs, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
