@@ -1,7 +1,7 @@
 /*
  * $RCSfile: signal_memory_accessor.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,16 +20,17 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.13 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.17 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef SIGNAL_MEMORY_ACCESSOR_SOURCE
 #define SIGNAL_MEMORY_ACCESSOR_SOURCE
 
-#include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/allocator.c"
 #include "../../memoriser/array.c"
@@ -52,25 +53,25 @@
 void set_signal(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
     void* p6, void* p7, void* p8, void* p9, void* p10) {
 
-    if (p2 != NULL_POINTER) {
+    if (p2 != *NULL_POINTER) {
 
         int* s = (int*) p2;
 
-        if (p1 != NULL_POINTER) {
+        if (p1 != *NULL_POINTER) {
 
             int* c = (int*) p1;
 
             log_message_debug("Set signal.");
 
             // The abstractions, models, details, priorities, identifications.
-            void** a = &NULL_POINTER;
-            void** ac = &NULL_POINTER;
-            void** m = &NULL_POINTER;
-            void** mc = &NULL_POINTER;
-            void** d = &NULL_POINTER;
-            void** dc = &NULL_POINTER;
-            void** p = &NULL_POINTER;
-            void** id = &NULL_POINTER;
+            void** a = NULL_POINTER;
+            void** ac = NULL_POINTER;
+            void** m = NULL_POINTER;
+            void** mc = NULL_POINTER;
+            void** d = NULL_POINTER;
+            void** dc = NULL_POINTER;
+            void** p = NULL_POINTER;
+            void** id = NULL_POINTER;
 
             // Get abstractions, models, details, priorities, identifications.
             get_array_elements(p0, (void*) SIGNALS_ABSTRACTIONS_INDEX, (void*) &a, (void*) POINTER_ARRAY);
@@ -82,21 +83,21 @@ void set_signal(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
             get_array_elements(p0, (void*) SIGNALS_PRIORITIES_INDEX, (void*) &p, (void*) POINTER_ARRAY);
             get_array_elements(p0, (void*) SIGNALS_IDENTIFICATIONS_INDEX, (void*) &id, (void*) POINTER_ARRAY);
 
-            if (*a != NULL_POINTER) {
+            if (*a != *NULL_POINTER) {
 
-                if (*ac != NULL_POINTER) {
+                if (*ac != *NULL_POINTER) {
 
-                    if (*m != NULL_POINTER) {
+                    if (*m != *NULL_POINTER) {
 
-                        if (*mc != NULL_POINTER) {
+                        if (*mc != *NULL_POINTER) {
 
-                            if (*d != NULL_POINTER) {
+                            if (*d != *NULL_POINTER) {
 
-                                if (*dc != NULL_POINTER) {
+                                if (*dc != *NULL_POINTER) {
 
-                                    if (*p != NULL_POINTER) {
+                                    if (*p != *NULL_POINTER) {
 
-                                        if (*id != NULL_POINTER) {
+                                        if (*id != *NULL_POINTER) {
 
                                             // The index.
                                             int i = *c;
@@ -219,29 +220,29 @@ void set_signal(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
  */
 void remove_signal(void* p0, void* p1, void* p2, void* p3) {
 
-    if (p3 != NULL_POINTER) {
+    if (p3 != *NULL_POINTER) {
 
         int* i = (int*) p3;
 
-        if (p2 != NULL_POINTER) {
+        if (p2 != *NULL_POINTER) {
 
             int* s = (int*) p2;
 
-            if (p1 != NULL_POINTER) {
+            if (p1 != *NULL_POINTER) {
 
                 int* c = (int*) p1;
 
                 log_message_debug("Remove signal.");
 
                 // The abstractions, models, details, priorities, identifications.
-                void** a = &NULL_POINTER;
-                void** ac = &NULL_POINTER;
-                void** m = &NULL_POINTER;
-                void** mc = &NULL_POINTER;
-                void** d = &NULL_POINTER;
-                void** dc = &NULL_POINTER;
-                void** p = &NULL_POINTER;
-                void** id = &NULL_POINTER;
+                void** a = NULL_POINTER;
+                void** ac = NULL_POINTER;
+                void** m = NULL_POINTER;
+                void** mc = NULL_POINTER;
+                void** d = NULL_POINTER;
+                void** dc = NULL_POINTER;
+                void** p = NULL_POINTER;
+                void** id = NULL_POINTER;
 
                 // Get abstractions, models, details, priorities, identifications.
                 get_array_elements(p0, (void*) SIGNALS_ABSTRACTIONS_INDEX, (void*) &a, (void*) POINTER_ARRAY);
@@ -253,21 +254,21 @@ void remove_signal(void* p0, void* p1, void* p2, void* p3) {
                 get_array_elements(p0, (void*) SIGNALS_PRIORITIES_INDEX, (void*) &p, (void*) POINTER_ARRAY);
                 get_array_elements(p0, (void*) SIGNALS_IDENTIFICATIONS_INDEX, (void*) &id, (void*) POINTER_ARRAY);
 
-                if (*a != NULL_POINTER) {
+                if (*a != *NULL_POINTER) {
 
-                    if (*ac != NULL_POINTER) {
+                    if (*ac != *NULL_POINTER) {
 
-                        if (*m != NULL_POINTER) {
+                        if (*m != *NULL_POINTER) {
 
-                            if (*mc != NULL_POINTER) {
+                            if (*mc != *NULL_POINTER) {
 
-                                if (*d != NULL_POINTER) {
+                                if (*d != *NULL_POINTER) {
 
-                                    if (*dc != NULL_POINTER) {
+                                    if (*dc != *NULL_POINTER) {
 
-                                        if (*p != NULL_POINTER) {
+                                        if (*p != *NULL_POINTER) {
 
-                                            if (*id != NULL_POINTER) {
+                                            if (*id != *NULL_POINTER) {
 
                                                 if (*i >= 0) {
 
@@ -370,25 +371,25 @@ void remove_signal(void* p0, void* p1, void* p2, void* p3) {
 void get_signal(void* p0, void* p1, void* p2, void* p3, void* p4,
     void* p5, void* p6, void* p7, void* p8, void* p9, int* p10) {
 
-    if (p2 != NULL_POINTER) {
+    if (p2 != *NULL_POINTER) {
 
         int* i = (int*) p2;
 
-        if (p1 != NULL_POINTER) {
+        if (p1 != *NULL_POINTER) {
 
             int* c = (int*) p1;
 
             log_message_debug("Get signal.");
 
             // The abstractions, models, details, priorities, identifications.
-            void** a = &NULL_POINTER;
-            void** ac = &NULL_POINTER;
-            void** m = &NULL_POINTER;
-            void** mc = &NULL_POINTER;
-            void** d = &NULL_POINTER;
-            void** dc = &NULL_POINTER;
-            void** p = &NULL_POINTER;
-            void** id = &NULL_POINTER;
+            void** a = NULL_POINTER;
+            void** ac = NULL_POINTER;
+            void** m = NULL_POINTER;
+            void** mc = NULL_POINTER;
+            void** d = NULL_POINTER;
+            void** dc = NULL_POINTER;
+            void** p = NULL_POINTER;
+            void** id = NULL_POINTER;
 
             // Get abstractions, models, details, priorities, identifications.
             get_array_elements(p0, (void*) SIGNALS_ABSTRACTIONS_INDEX, (void*) &a, (void*) POINTER_ARRAY);
@@ -400,21 +401,21 @@ void get_signal(void* p0, void* p1, void* p2, void* p3, void* p4,
             get_array_elements(p0, (void*) SIGNALS_PRIORITIES_INDEX, (void*) &p, (void*) POINTER_ARRAY);
             get_array_elements(p0, (void*) SIGNALS_IDENTIFICATIONS_INDEX, (void*) &id, (void*) POINTER_ARRAY);
 
-            if (*a != NULL_POINTER) {
+            if (*a != *NULL_POINTER) {
 
-                if (*ac != NULL_POINTER) {
+                if (*ac != *NULL_POINTER) {
 
-                    if (*m != NULL_POINTER) {
+                    if (*m != *NULL_POINTER) {
 
-                        if (*mc != NULL_POINTER) {
+                        if (*mc != *NULL_POINTER) {
 
-                            if (*d != NULL_POINTER) {
+                            if (*d != *NULL_POINTER) {
 
-                                if (*dc != NULL_POINTER) {
+                                if (*dc != *NULL_POINTER) {
 
-                                    if (*p != NULL_POINTER) {
+                                    if (*p != *NULL_POINTER) {
 
-                                        if (*id != NULL_POINTER) {
+                                        if (*id != *NULL_POINTER) {
 
                                             if (*i >= 0) {
 
@@ -500,26 +501,26 @@ void get_signal(void* p0, void* p1, void* p2, void* p3, void* p4,
  */
 void get_highest_priority_index(void* p0, void* p1, void* p2) {
 
-    if (p2 != NULL_POINTER) {
+    if (p2 != *NULL_POINTER) {
 
         int* i = (int*) p2;
 
-        if (p1 != NULL_POINTER) {
+        if (p1 != *NULL_POINTER) {
 
             int* c = (int*) p1;
 
             // The signal priorities.
-            void** sp = &NULL_POINTER;
+            void** sp = NULL_POINTER;
 
             // Get signal priorities.
             get_array_elements(p0, (void*) SIGNALS_PRIORITIES_INDEX, (void*) &sp, (void*) POINTER_ARRAY);
 
-            if (*sp != NULL_POINTER) {
+            if (*sp != *NULL_POINTER) {
 
                 // The loop variable.
                 int j = 0;
                 // The priority.
-                int** prio = (int**) &NULL_POINTER;
+                int** prio = (int**) NULL_POINTER;
                 // The highest priority.
                 // CAUTION! Do not initialise it with zero, because then the
                 // priority will not be set, due to the comparison: if (prio > h).
@@ -546,7 +547,7 @@ void get_highest_priority_index(void* p0, void* p1, void* p2) {
                     }
 
                     // Reset priority.
-                    prio = (int**) &NULL_POINTER;
+                    prio = (int**) NULL_POINTER;
 
                     j++;
                 }
@@ -578,21 +579,21 @@ void get_highest_priority_index(void* p0, void* p1, void* p2) {
  */
 void get_new_signal_id(void* p0, void* p1, void* p2) {
 
-    if (p2 != NULL_POINTER) {
+    if (p2 != *NULL_POINTER) {
 
         int* i = (int*) p2;
 
-        if (p1 != NULL_POINTER) {
+        if (p1 != *NULL_POINTER) {
 
             int* mc = (int*) p1;
 
             // The signal identifications.
-            void** ids = &NULL_POINTER;
+            void** ids = NULL_POINTER;
 
             // Get signal identifications.
             get_array_elements(p0, (void*) SIGNALS_IDENTIFICATIONS_INDEX, (void*) &ids, (void*) POINTER_ARRAY);
 
-            if (*ids != NULL_POINTER) {
+            if (*ids != *NULL_POINTER) {
 
                 // The loop variable.
                 int j = 0;
@@ -602,7 +603,7 @@ void get_new_signal_id(void* p0, void* p1, void* p2) {
                 // The smallest possible priority is zero and greater than minus one.
                 int max = -1;
                 // The identification.
-                int** id = (int**) &NULL_POINTER;
+                int** id = (int**) NULL_POINTER;
 
                 while (1) {
 
@@ -620,7 +621,7 @@ void get_new_signal_id(void* p0, void* p1, void* p2) {
                     }
 
                     // Reset identification.
-                    id = (int**) &NULL_POINTER;
+                    id = (int**) NULL_POINTER;
 
                     j++;
                 }
