@@ -1,7 +1,7 @@
 /*
  * $RCSfile: compound_allocator.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,17 +23,18 @@
  * This file contains the functionality to:
  * - create a compound model in memory
  *
- * @version $Revision: 1.8 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.12 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef COMPOUND_ALLOCATOR_SOURCE
 #define COMPOUND_ALLOCATOR_SOURCE
 
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/array.c"
 
@@ -45,7 +46,7 @@
  */
 void allocate_compound(void* p0, void* p1) {
 
-    if (p0 != NULL_POINTER) {
+    if (p0 != *NULL_POINTER) {
 
         void** c = (void**) p0;
 
@@ -55,18 +56,18 @@ void allocate_compound(void* p0, void* p1) {
         allocate_array(p0, (void*) COMPOUND_COUNT, (void*) POINTER_ARRAY);
 
         // The names, abstractions, models, details.
-        void* n = NULL_POINTER;
-        void* nc = NULL_POINTER;
-        void* ns = NULL_POINTER;
-        void* a = NULL_POINTER;
-        void* ac = NULL_POINTER;
-        void* as = NULL_POINTER;
-        void* m = NULL_POINTER;
-        void* mc = NULL_POINTER;
-        void* ms = NULL_POINTER;
-        void* d = NULL_POINTER;
-        void* dc = NULL_POINTER;
-        void* ds = NULL_POINTER;
+        void* n = *NULL_POINTER;
+        void* nc = *NULL_POINTER;
+        void* ns = *NULL_POINTER;
+        void* a = *NULL_POINTER;
+        void* ac = *NULL_POINTER;
+        void* as = *NULL_POINTER;
+        void* m = *NULL_POINTER;
+        void* mc = *NULL_POINTER;
+        void* ms = *NULL_POINTER;
+        void* d = *NULL_POINTER;
+        void* dc = *NULL_POINTER;
+        void* ds = *NULL_POINTER;
 
         // Allocate names, abstractions, models, details.
         allocate_array((void*) &n, p1, (void*) POINTER_ARRAY);
@@ -112,25 +113,25 @@ void allocate_compound(void* p0, void* p1) {
  */
 void deallocate_compound(void* p0, void* p1) {
 
-    if (p0 != NULL_POINTER) {
+    if (p0 != *NULL_POINTER) {
 
         void** c = (void**) p0;
 
         log_message_debug("Deallocate compound.");
 
         // The names, abstractions, models, details.
-        void** n = &NULL_POINTER;
-        void** nc = &NULL_POINTER;
-        void** ns = &NULL_POINTER;
-        void** a = &NULL_POINTER;
-        void** ac = &NULL_POINTER;
-        void** as = &NULL_POINTER;
-        void** m = &NULL_POINTER;
-        void** mc = &NULL_POINTER;
-        void** ms = &NULL_POINTER;
-        void** d = &NULL_POINTER;
-        void** dc = &NULL_POINTER;
-        void** ds = &NULL_POINTER;
+        void** n = NULL_POINTER;
+        void** nc = NULL_POINTER;
+        void** ns = NULL_POINTER;
+        void** a = NULL_POINTER;
+        void** ac = NULL_POINTER;
+        void** as = NULL_POINTER;
+        void** m = NULL_POINTER;
+        void** mc = NULL_POINTER;
+        void** ms = NULL_POINTER;
+        void** d = NULL_POINTER;
+        void** dc = NULL_POINTER;
+        void** ds = NULL_POINTER;
 
         // Get names, abstractions, models, details.
         // The p0 parameter (c) needs to be dereferenced since it is handed
