@@ -1,7 +1,7 @@
 /*
  * $RCSfile: fraction_allocator.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,15 +23,15 @@
  * This file contains the functionality to:
  * - create a fraction model in memory
  *
- * @version $Revision: 1.6 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.10 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef FRACTION_ALLOCATOR_SOURCE
 #define FRACTION_ALLOCATOR_SOURCE
 
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/log_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/array.c"
 
@@ -45,7 +45,6 @@ void allocate_fraction(void* p0, void* p1) {
 
     log_message_debug("Allocate fraction.");
 
-    // Create fraction.
     allocate_array(p0, p1, (void*) INTEGER_ARRAY);
 }
 
@@ -59,7 +58,6 @@ void deallocate_fraction(void* p0, void* p1) {
 
     log_message_debug("Deallocate fraction.");
 
-    // Destroy fraction.
     deallocate_array(p0, p1, (void*) INTEGER_ARRAY);
 }
 
