@@ -1,7 +1,7 @@
 /*
  * $RCSfile: internal_memory_allocator.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,17 +20,17 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.9 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.13 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef INTERNAL_MEMORY_ALLOCATOR_SOURCE
 #define INTERNAL_MEMORY_ALLOCATOR_SOURCE
 
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/array.c"
 
@@ -60,7 +60,7 @@ void allocate_internal_memory(void* p0, void* p1) {
  * Configuration parameter allocation/ deallocation is thus clearly in the
  * responsibility of the module developer and no effort is undertaken here
  * to automatically deallocate those configuration parameters which are still
- * existent in internal memory (unequal NULL_POINTER).
+ * existent in internal memory (unequal *NULL_POINTER).
  *
  * @param p0 the internal memory (Hand over as reference!)
  * @param p1 the internal memory size
