@@ -1,7 +1,7 @@
 /*
  * $RCSfile: signal_memory_allocator.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,17 +23,18 @@
  * This file contains the functionality to:
  * - create a signal memory in memory
  *
- * @version $Revision: 1.8 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.12 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef SIGNAL_MEMORY_ALLOCATOR_SOURCE
 #define SIGNAL_MEMORY_ALLOCATOR_SOURCE
 
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/array.c"
 
@@ -45,24 +46,24 @@
  */
 void allocate_signal_memory(void* p0, void* p1) {
 
-    if (p0 != NULL_POINTER) {
+    if (p0 != *NULL_POINTER) {
 
         void** s = (void**) p0;
 
-        log_message((void*) INFO_LOG_LEVEL, (void*) CREATE_SIGNAL_MEMORY_MESSAGE, (void*) CREATE_SIGNAL_MEMORY_MESSAGE_COUNT);
+        log_message((void*) INFORMATION_LOG_LEVEL, (void*) CREATE_SIGNAL_MEMORY_MESSAGE, (void*) CREATE_SIGNAL_MEMORY_MESSAGE_COUNT);
 
         // Allocate signal memory.
         allocate_array(p0, (void*) SIGNAL_MEMORY_COUNT, (void*) POINTER_ARRAY);
 
         // The abstractions, models, details, priorities, identifications.
-        void* a = NULL_POINTER;
-        void* ac = NULL_POINTER;
-        void* m = NULL_POINTER;
-        void* mc = NULL_POINTER;
-        void* d = NULL_POINTER;
-        void* dc = NULL_POINTER;
-        void* p = NULL_POINTER;
-        void* id = NULL_POINTER;
+        void* a = *NULL_POINTER;
+        void* ac = *NULL_POINTER;
+        void* m = *NULL_POINTER;
+        void* mc = *NULL_POINTER;
+        void* d = *NULL_POINTER;
+        void* dc = *NULL_POINTER;
+        void* p = *NULL_POINTER;
+        void* id = *NULL_POINTER;
 
         // Allocate abstractions, models, details, priorities, identifications.
         allocate_array((void*) &a, p1, (void*) POINTER_ARRAY);
@@ -100,30 +101,30 @@ void allocate_signal_memory(void* p0, void* p1) {
  */
 void deallocate_signal_memory(void* p0, void* p1) {
 
-    if (p0 != NULL_POINTER) {
+    if (p0 != *NULL_POINTER) {
 
         void** s = (void**) p0;
 
-        log_message((void*) INFO_LOG_LEVEL, (void*) DESTROY_SIGNAL_MEMORY_MESSAGE, (void*) DESTROY_SIGNAL_MEMORY_MESSAGE_COUNT);
+        log_message((void*) INFORMATION_LOG_LEVEL, (void*) DESTROY_SIGNAL_MEMORY_MESSAGE, (void*) DESTROY_SIGNAL_MEMORY_MESSAGE_COUNT);
 
         // The abstractions, models, details, priorities, identifications.
-        void** a = &NULL_POINTER;
-        void** ac = &NULL_POINTER;
-        void** m = &NULL_POINTER;
-        void** mc = &NULL_POINTER;
-        void** d = &NULL_POINTER;
-        void** dc = &NULL_POINTER;
-        void** p = &NULL_POINTER;
-        void** id = &NULL_POINTER;
+        void** a = NULL_POINTER;
+        void** ac = NULL_POINTER;
+        void** m = NULL_POINTER;
+        void** mc = NULL_POINTER;
+        void** d = NULL_POINTER;
+        void** dc = NULL_POINTER;
+        void** p = NULL_POINTER;
+        void** id = NULL_POINTER;
 
     /*??
-        log_message((void*) &INFO_LOG_LEVEL, (void*) &"Destroy all signals left in signal memory.");
+        log_message((void*) &INFORMATION_LOG_LEVEL, (void*) &"Destroy all signals left in signal memory.");
 
         int i = 0;
         get_array_count(m->signals, (void*) &i);
         i--;
-        void* s = NULL_POINTER;
-        void* a = NULL_POINTER;
+        void* s = *NULL_POINTER;
+        void* a = *NULL_POINTER;
 
         while (i >= 0) {
 
