@@ -1,7 +1,7 @@
 /*
  * $RCSfile: x_windows_allocator.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.5 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.7 $ $Date: 2007/04/16 15:50:29 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  * @description
  *
@@ -37,7 +37,7 @@
 #ifndef X_WINDOW_SYSTEM_ALLOCATOR_SOURCE
 #define X_WINDOW_SYSTEM_ALLOCATOR_SOURCE
 
-#include "../../globals/constants/abstraction_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
 
 /**
  * Allocates an x window system window.
