@@ -1,7 +1,7 @@
 /*
  * $RCSfile: xml_node_allocator.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,16 +20,17 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.6 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.10 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef XML_NODE_ALLOCATOR_SOURCE
 #define XML_NODE_ALLOCATOR_SOURCE
 
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/array.c"
 
@@ -47,8 +48,8 @@ void allocate_xml_node(void* p0, void* p1) {
     allocate_array(p0, p1, (void*) POINTER_ARRAY);
 
     // Initialise xml node name, attributes, value.
-    void* nav = NULL_POINTER;
-    void* c = NULL_POINTER;
+    void* nav = *NULL_POINTER;
+    void* c = *NULL_POINTER;
 
     // Create xml tag name, attributes, value.
     allocate_array((void*) &nav, p1, (void*) POINTER_ARRAY);
@@ -74,8 +75,8 @@ void deallocate_xml_node(void* p0, void* p1) {
     log_message_debug("Deallocate xml node.");
 
     // Initialise xml tag name, attributes, value.
-    void* nav = NULL_POINTER;
-    void* c = NULL_POINTER;
+    void* nav = *NULL_POINTER;
+    void* c = *NULL_POINTER;
 
     // Get xml tag name, attributes, value.
 //??    get_array_elements(p0, (void*) POINTER_ARRAY, (void*) &XML_TAG_NAME_ATTRIBUTE_VALUE_INDEX, (void*) &nav);
