@@ -1,7 +1,7 @@
 /*
  * $RCSfile: xml_property_allocator.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,15 +20,16 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.6 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.10 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef XML_PROPERTY_ALLOCATOR_SOURCE
 #define XML_PROPERTY_ALLOCATOR_SOURCE
 
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/log_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/array.c"
 
@@ -46,8 +47,8 @@ void allocate_xml_property(void* p0, void* p1) {
     allocate_array(p0, p1, (void*) POINTER_ARRAY);
 
     // Initialise xml attribute name, value.
-    void* nv = NULL_POINTER;
-    void* c = NULL_POINTER;
+    void* nv = *NULL_POINTER;
+    void* c = *NULL_POINTER;
 
     // Create xml attribute name, value.
     allocate_array((void*) &nv, p1, (void*) POINTER_ARRAY);
@@ -73,8 +74,8 @@ void deallocate_xml_property(void* p0, void* p1) {
     log_message_debug("Deallocate xml property.");
 
     // Initialise xml attribute name, value.
-    void* nv = NULL_POINTER;
-    void* c = NULL_POINTER;
+    void* nv = *NULL_POINTER;
+    void* c = *NULL_POINTER;
 
     // Get xml attribute name, value.
 //??    get_array_elements(p0, (void*) POINTER_ARRAY, (void*) &XML_ATTRIBUTE_NAME_VALUE_INDEX, (void*) &nv);
