@@ -1,7 +1,7 @@
 /*
  * $RCSfile: array.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -49,15 +49,16 @@
  * the array size needs to be given extra here because sizeof will not work.
  * See: http://pegasus.rutgers.edu/~elflord/cpp/gotchas/index.shtml
  *
- * @version $Revision: 1.9 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.14 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef ARRAY_SOURCE
 #define ARRAY_SOURCE
 
-#include "../globals/constants/abstraction_constants.c"
-#include "../globals/constants/log_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../globals/constants/log/log_message_constants.c"
+#include "../globals/constants/pointer/pointer_constants.c"
 #include "../globals/logger/logger.c"
 #include "../memoriser/array/character_array.c"
 #include "../memoriser/array/double_array.c"
@@ -75,10 +76,12 @@
  */
 void allocate_array(void* p0, void* p1, void* p2) {
 
-    if (p2 != NULL_POINTER) {
+    if (p2 != *NULL_POINTER) {
 
         int* t = (int*) p2;
 
+        log_message_debug("Allocate array.");
+
         if (*t == *POINTER_ARRAY) {
 
             allocate_pointer_array(p0, p1);
@@ -119,10 +122,12 @@ void allocate_array(void* p0, void* p1, void* p2) {
  */
 void deallocate_array(void* p0, void* p1, void* p2) {
 
-    if (p2 != NULL_POINTER) {
+    if (p2 != *NULL_POINTER) {
 
         int* t = (int*) p2;
 
+        log_message_debug("Deallocate array.");
+
         if (*t == *POINTER_ARRAY) {
 
             deallocate_pointer_array(p0, p1);
@@ -164,10 +169,12 @@ void deallocate_array(void* p0, void* p1, void* p2) {
  */
 void reallocate_array(void* p0, void* p1, void* p2, void* p3) {
 
-    if (p3 != NULL_POINTER) {
+    if (p3 != *NULL_POINTER) {
 
         int* t = (int*) p3;
 
+        log_message_debug("Reallocate array.");
+
         if (*t == *POINTER_ARRAY) {
 
             reallocate_pointer_array(p0, p1, p2);
@@ -213,10 +220,12 @@ void reallocate_array(void* p0, void* p1, void* p2, void* p3) {
  */
 void compare_array_elements(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* t = (int*) p4;
 
+        log_message_debug("Compare array elements.");
+
         if (*t == *POINTER_ARRAY) {
 
             compare_pointer_array_elements(p0, p1, p2, p3);
@@ -263,14 +272,16 @@ void compare_array_elements(void* p0, void* p1, void* p2, void* p3, void* p4) {
  */
 void compare_arrays(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
 
-    if (p3 != NULL_POINTER) {
+    if (p3 != *NULL_POINTER) {
 
         int* sc = (int*) p3;
 
-        if (p1 != NULL_POINTER) {
+        if (p1 != *NULL_POINTER) {
 
             int* fc = (int*) p1;
 
+            log_message_debug("Compare arrays.");
+
             if (*fc == *sc) {
 
                 compare_array_elements(p0, p2, p3, p4, p5);
@@ -297,10 +308,12 @@ void compare_arrays(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5)
  */
 void get_array_elements(void* p0, void* p1, void* p2, void* p3) {
 
-    if (p3 != NULL_POINTER) {
+    if (p3 != *NULL_POINTER) {
 
         int* t = (int*) p3;
 
+        log_message_debug("Get array elements.");
+
         if (*t == *POINTER_ARRAY) {
 
             get_pointer_array_elements(p0, p1, p2);
@@ -347,22 +360,24 @@ void get_array_elements(void* p0, void* p1, void* p2, void* p3) {
  */
 void get_index_in_array(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* position = (int*) p4;
         *position = -1;
 
-        if (p3 != NULL_POINTER) {
+        if (p3 != *NULL_POINTER) {
 
             int* sc = (int*) p3;
 
-            if (p1 != NULL_POINTER) {
+            if (p1 != *NULL_POINTER) {
 
                 int* ac = (int*) p1;
 
+                log_message_debug("Get index in array.");
+
                 int array_counter = 0;
                 int comp_res = 0;
-                void* start_comp = NULL_POINTER;
+                void* start_comp = *NULL_POINTER;
 
                 while (1) {
 
@@ -411,10 +426,12 @@ void get_index_in_array(void* p0, void* p1, void* p2, void* p3, void* p4, void*
  */
 void set_array_elements(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* t = (int*) p4;
 
+        log_message_debug("Set array elements.");
+
         if (*t == *POINTER_ARRAY) {
 
             set_pointer_array_elements(p0, p1, p2, p3);
@@ -457,10 +474,12 @@ void set_array_elements(void* p0, void* p1, void* p2, void* p3, void* p4) {
  */
 void remove_array_elements(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* t = (int*) p4;
 
+        log_message_debug("Remove array elements.");
+
         if (*t == *POINTER_ARRAY) {
 
             remove_pointer_array_elements(p0, p1, p2, p3);
@@ -509,10 +528,12 @@ void remove_array_elements(void* p0, void* p1, void* p2, void* p3, void* p4) {
  */
 void get_array_elements_index(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5) {
 
-    if (p5 != NULL_POINTER) {
+    if (p5 != *NULL_POINTER) {
 
         int* t = (int*) p5;
 
+        log_message_debug("Get array elements index.");
+
         if (*t == *POINTER_ARRAY) {
 
             get_pointer_array_elements_index(p0, p1, p2, p3, p4);
