@@ -1,7 +1,7 @@
 /*
  * $RCSfile: integer_array.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -38,7 +38,7 @@
  *
  * Array elements are accessed over their index (array base pointer + index).
  *
- * @version $Revision: 1.9 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.15 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -47,7 +47,9 @@
 
 #include <stdlib.h>
 #include <string.h>
-#include "../../globals/constants/log_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/variables/variables.c"
 #include "../../globals/logger/logger.c"
 
@@ -55,23 +57,23 @@
  * Allocates the integer array.
  *
  * @param p0 the array (Hand over as reference!)
- * @param p1 the size
+ * @param p1 the array size
  */
 void allocate_integer_array(void* p0, void* p1) {
 
-    if (p1 != NULL_POINTER) {
+    if (p1 != *NULL_POINTER) {
 
         int* s = (int*) p1;
 
-        if (p0 != NULL_POINTER) {
+        if (p0 != *NULL_POINTER) {
 
             void** a = (void**) p0;
 
-            log_message((void*) INFO_LOG_LEVEL, (void*) CREATE_INTEGER_ARRAY_MESSAGE, (void*) CREATE_INTEGER_ARRAY_MESSAGE_COUNT);
+            log_message((void*) INFORMATION_LOG_LEVEL, (void*) CREATE_INTEGER_ARRAY_MESSAGE, (void*) CREATE_INTEGER_ARRAY_MESSAGE_COUNT);
 
             // Determine the memory area to be allocated.
             // It is the product of the given size and the type size.
-            int m = *s * *INTEGER_PRIMITIVE_SIZE;
+            size_t m = *s * *INTEGER_PRIMITIVE_SIZE;
 
             // A minimal space in memory is always allocated,
             // even if the requested size is zero.
@@ -79,7 +81,7 @@ void allocate_integer_array(void* p0, void* p1) {
             *a = (void*) malloc(m);
 
             // Initialise array elements with null pointer.
-            memset(*a, 0, m);
+            memset(*a, *NUMBER_0_INTEGER, m);
 
         } else {
 
@@ -96,19 +98,19 @@ void allocate_integer_array(void* p0, void* p1) {
  * Deallocates the integer array.
  *
  * @param p0 the array (Hand over as reference!)
- * @param p1 the size
+ * @param p1 the array size
  */
 void deallocate_integer_array(void* p0, void* p1) {
 
-    if (p1 != NULL_POINTER) {
+    if (p1 != *NULL_POINTER) {
 
         int* s = (int*) p1;
 
-        if (p0 != NULL_POINTER) {
+        if (p0 != *NULL_POINTER) {
 
             void** a = (void**) p0;
 
-            log_message((void*) INFO_LOG_LEVEL, (void*) DESTROY_INTEGER_ARRAY_MESSAGE, (void*) DESTROY_INTEGER_ARRAY_MESSAGE_COUNT);
+            log_message((void*) INFORMATION_LOG_LEVEL, (void*) DESTROY_INTEGER_ARRAY_MESSAGE, (void*) DESTROY_INTEGER_ARRAY_MESSAGE_COUNT);
 
             free(*a);
 
@@ -127,28 +129,28 @@ void deallocate_integer_array(void* p0, void* p1) {
  * Reallocates the integer array.
  *
  * @param p0 the array (Hand over as reference!)
- * @param p1 the count
- * @param p2 the size
+ * @param p1 the array count
+ * @param p2 the array size
  */
 void reallocate_integer_array(void* p0, void* p1, void* p2) {
 
-    if (p2 != NULL_POINTER) {
+    if (p2 != *NULL_POINTER) {
 
         int* s = (int*) p2;
 
-        if (p1 != NULL_POINTER) {
+        if (p1 != *NULL_POINTER) {
 
             int* c = (int*) p1;
 
-            if (p0 != NULL_POINTER) {
+            if (p0 != *NULL_POINTER) {
 
                 void** a = (void**) p0;
 
-                log_message((void*) INFO_LOG_LEVEL, (void*) RESIZE_INTEGER_ARRAY_MESSAGE, (void*) RESIZE_INTEGER_ARRAY_MESSAGE_COUNT);
+                log_message((void*) INFORMATION_LOG_LEVEL, (void*) RESIZE_INTEGER_ARRAY_MESSAGE, (void*) RESIZE_INTEGER_ARRAY_MESSAGE_COUNT);
 
                 // Determine the memory area to be allocated.
                 // It is the product of the given size and the type size.
-                int m = *s * *INTEGER_PRIMITIVE_SIZE;
+                size_t m = *s * *INTEGER_PRIMITIVE_SIZE;
 
                 // Create a new array with extended size.
                 *a = (void*) realloc(*a, m);
@@ -163,7 +165,7 @@ void reallocate_integer_array(void* p0, void* p1, void* p2) {
 
                 // Initialise ONLY NEW array elements with null pointer.
                 // Leave existing elements untouched.
-                memset(e, 0, n);
+                memset(e, *NUMBER_0_INTEGER, n);
 
             } else {
 
@@ -189,38 +191,38 @@ void reallocate_integer_array(void* p0, void* p1, void* p2) {
  *
  * @param p0 the first array
  * @param p1 the second array
- * @param p2 the count
+ * @param p2 the array count
  * @param p3 the result (Hand over as reference!)
  */
 void compare_integer_array_elements(void* p0, void* p1, void* p2, void* p3) {
 
-    if (p3 != NULL_POINTER) {
+    if (p3 != *NULL_POINTER) {
 
         int* r = (int*) p3;
 
-        if (p2 != NULL_POINTER) {
+        if (p2 != *NULL_POINTER) {
 
             int* c = (int*) p2;
 
-            if (p1 != NULL_POINTER) {
+            if (p1 != *NULL_POINTER) {
 
-                if (p0 != NULL_POINTER) {
+                if (p0 != *NULL_POINTER) {
 
                     // The loop variable.
-                    int j = 0;
+                    int j = *NUMBER_0_INTEGER;
                     // The first element.
-                    int* e0 = NULL_POINTER;
+                    int* e0 = (int*) *NULL_POINTER;
                     // The second element.
-                    int* e1 = NULL_POINTER;
+                    int* e1 = (int*) *NULL_POINTER;
                     // The size.
-                    int s = 0;
+                    int s = *NUMBER_0_INTEGER;
 
-                    while (1) {
+                    while (*NUMBER_1_INTEGER) {
 
                         if (j >= *c) {
 
                             // All elements have been compared and are equal.
-                            *r = 1;
+                            *r = *NUMBER_1_INTEGER;
 
                             break;
                         }
@@ -267,47 +269,47 @@ void compare_integer_array_elements(void* p0, void* p1, void* p2, void* p3) {
  *
  * @param p0 the array
  * @param p1 the index
- * @param p2 the elements (Hand over as array!)
- * @param p3 the count
+ * @param p2 the elements
+ * @param p3 the elements count
  */
 void set_integer_array_elements(void* p0, void* p1, void* p2, void* p3) {
 
-    if (p3 != NULL_POINTER) {
+    if (p3 != *NULL_POINTER) {
 
-        int* c = (int*) p3;
+        int* sc = (int*) p3;
 
-        if (p2 != NULL_POINTER) {
+        if (p2 != *NULL_POINTER) {
 
-            if (p1 != NULL_POINTER) {
+            if (p1 != *NULL_POINTER) {
 
                 int* i = (int*) p1;
 
-                if (p0 != NULL_POINTER) {
+                if (p0 != *NULL_POINTER) {
 
                     // The destination base.
                     void* db = (void*) (p0 + (*i * *INTEGER_PRIMITIVE_SIZE));
                     // The source element.
-                    int* se = NULL_POINTER;
+                    int* se = (int*) *NULL_POINTER;
                     // The destination element.
-                    int* de = NULL_POINTER;
+                    int* de = (int*) *NULL_POINTER;
                     // The loop variable.
-                    int j = 0;
-                    // The size.
-                    int s = 0;
+                    int j = *NUMBER_0_INTEGER;
+                    // The offset.
+                    int o = *NUMBER_0_INTEGER;
 
-                    while (1) {
+                    while (*NUMBER_1_INTEGER) {
 
-                        if (j >= *c) {
+                        if (j >= *sc) {
 
                             break;
                         }
 
                         // Determine size.
-                        s = j * *INTEGER_PRIMITIVE_SIZE;
+                        o = j * *INTEGER_PRIMITIVE_SIZE;
 
                         // Determine source and destination element.
-                        se = (int*) (p2 + s);
-                        de = (int*) (db + s);
+                        se = (int*) (p2 + o);
+                        de = (int*) (db + o);
 
                         // Set destination element.
                         *de = *se;
@@ -340,40 +342,40 @@ void set_integer_array_elements(void* p0, void* p1, void* p2, void* p3) {
  * Removes the integer array elements.
  *
  * @param p0 the array
- * @param p1 the size
+ * @param p1 the array size
  * @param p2 the index
- * @param p3 the count
+ * @param p3 the elements count
  */
 void remove_integer_array_elements(void* p0, void* p1, void* p2, void* p3) {
 
-    if (p3 != NULL_POINTER) {
+    if (p3 != *NULL_POINTER) {
 
         int* c = (int*) p3;
 
-        if (p2 != NULL_POINTER) {
+        if (p2 != *NULL_POINTER) {
 
             int* i = (int*) p2;
 
-            if (p1 != NULL_POINTER) {
+            if (p1 != *NULL_POINTER) {
 
                 int* m = (int*) p1;
 
-                if (p0 != NULL_POINTER) {
+                if (p0 != *NULL_POINTER) {
 
                     // The destination base.
                     void* db = (void*) (p0 + (*i * *INTEGER_PRIMITIVE_SIZE));
                     // The source base.
                     void* sb = (void*) (db + (*c * *INTEGER_PRIMITIVE_SIZE));
                     // The source element.
-                    int* se = NULL_POINTER;
+                    int* se = (int*) *NULL_POINTER;
                     // The destination element.
-                    int* de = NULL_POINTER;
+                    int* de = (int*) *NULL_POINTER;
                     // The remaining elements size.
                     int r = *m - (*i + *c);
                     // The loop variable.
-                    int j = 0;
+                    int j = *NUMBER_0_INTEGER;
                     // The size.
-                    int s = 0;
+                    int s = *NUMBER_0_INTEGER;
 
                     // Starting from the given index, move all remaining elements
                     // one place towards the beginning of the elements.
@@ -382,7 +384,7 @@ void remove_integer_array_elements(void* p0, void* p1, void* p2, void* p3) {
                     // index = 4 (remove "..")
                     // count = 2
                     // rest = 11 - (4 + 2) = 11 - 6 = 5
-                    while (1) {
+                    while (*NUMBER_1_INTEGER) {
 
                         if (j >= r) {
 
@@ -438,18 +440,18 @@ void remove_integer_array_elements(void* p0, void* p1, void* p2, void* p3) {
  */
 void get_integer_array_elements(void* p0, void* p1, void* p2) {
 
-    if (p2 != NULL_POINTER) {
+    if (p2 != *NULL_POINTER) {
 
-        void** e = (void**) p2;
+        void** d = (void**) p2;
 
-        if (p1 != NULL_POINTER) {
+        if (p1 != *NULL_POINTER) {
 
             int* i = (int*) p1;
 
-            if (p0 != NULL_POINTER) {
+            if (p0 != *NULL_POINTER) {
 
                 // Determine element.
-                *e = (void*) (p0 + (*i * *INTEGER_PRIMITIVE_SIZE));
+                *d = (void*) (p0 + (*i * *INTEGER_PRIMITIVE_SIZE));
 
             } else {
 
@@ -482,30 +484,30 @@ void get_integer_array_elements(void* p0, void* p1, void* p2) {
  */
 void get_integer_array_elements_index(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* i = (int*) p4;
 
-        if (p3 != NULL_POINTER) {
+        if (p3 != *NULL_POINTER) {
 
             int* ec = (int*) p3;
 
-            if (p1 != NULL_POINTER) {
+            if (p1 != *NULL_POINTER) {
 
                 int* ac = (int*) p1;
 
-                if (p0 != NULL_POINTER) {
+                if (p0 != *NULL_POINTER) {
 
                     // The iteration limit.
-                    int l = *ac - *ec + 1;
+                    int l = *ac - *ec + *NUMBER_1_INTEGER;
                     // The element.
-                    void* e = NULL_POINTER;
+                    void* e = *NULL_POINTER;
                     // The loop variable.
-                    int j = 0;
+                    int j = *NUMBER_0_INTEGER;
                     // The comparison result.
-                    int r = 0;
+                    int r = *NUMBER_0_INTEGER;
 
-                    while (1) {
+                    while (*NUMBER_1_INTEGER) {
 
                         if (j >= l) {
 
@@ -516,7 +518,7 @@ void get_integer_array_elements_index(void* p0, void* p1, void* p2, void* p3, vo
                         get_integer_array_elements(p0, (void*) &j, (void*) &e);
                         compare_integer_array_elements(e, p2, p3, (void*) &r);
 
-                        if (r == 1) {
+                        if (r == *NUMBER_1_INTEGER) {
 
                             // The element has been found.
                             *i = j;
