@@ -1,7 +1,7 @@
 /*
  * $RCSfile: inline_communicator.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,7 +24,7 @@
  * - receive an inline stream into a byte array
  * - send an inline stream from a byte array
  *
- * @version $Revision: 1.8 $ $Date: 2006/06/18 14:57:34 $ $Author: christian $
+ * @version $Revision: 1.11 $ $Date: 2007/05/16 19:29:02 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -32,6 +32,8 @@
 #define INLINE_COMMUNICATOR_SOURCE
 
 #include <stdio.h>
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/array.c"
 
@@ -46,19 +48,19 @@
  */
 void read_inline(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* sc = (int*) p4;
 
-        if (p2 != NULL_POINTER) {
+        if (p2 != *NULL_POINTER) {
 
             int* ds = (int*) p2;
 
-            if (p1 != NULL_POINTER) {
+            if (p1 != *NULL_POINTER) {
 
                 int* dc = (int*) p1;
 
-                if (p0 != NULL_POINTER) {
+                if (p0 != *NULL_POINTER) {
 
                     void** d = (void**) p0;
 
@@ -69,7 +71,7 @@ void read_inline(void* p0, void* p1, void* p2, void* p3, void* p4) {
                     reallocate_array(p0, p1, p2, (void*) CHARACTER_ARRAY);
 
                     // The destination array index to start writing at.
-                    int i = 0;
+                    int i = *NUMBER_0_INTEGER;
 
                     set_array_elements(*d, (void*) &i, p3, p4, (void*) CHARACTER_ARRAY);
 
