@@ -1,7 +1,7 @@
 /*
  * $RCSfile: character_vector_converter.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,16 +20,18 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.2 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.9 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef CHARACTER_VECTOR_CONVERTER_SOURCE
 #define CHARACTER_VECTOR_CONVERTER_SOURCE
 
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/log_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
+#include "../../memoriser/array.c"
 
 /**
  * Parses the byte stream and creates a character vector model from it.
@@ -42,19 +44,19 @@
  */
 void parse_character_vector(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* sc = (int*) p4;
 
-        if (p2 != NULL_POINTER) {
+        if (p2 != *NULL_POINTER) {
 
             int* ds = (int*) p2;
 
-            if (p1 != NULL_POINTER) {
+            if (p1 != *NULL_POINTER) {
 
                 int* dc = (int*) p1;
 
-                if (p0 != NULL_POINTER) {
+                if (p0 != *NULL_POINTER) {
 
                     void** d = (void**) p0;
 
@@ -126,6 +128,60 @@ void parse_character_vector(void* p0, void* p1, void* p2, void* p3, void* p4) {
  * @param p4 the source count
  */
 void serialise_character_vector(void* p0, void* p1, void* p2, void* p3, void* p4) {
+
+    if (p4 != *NULL_POINTER) {
+
+        int* sc = (int*) p4;
+
+        if (p2 != *NULL_POINTER) {
+
+            int* ds = (int*) p2;
+
+            if (p1 != *NULL_POINTER) {
+
+                int* dc = (int*) p1;
+
+                if (p0 != *NULL_POINTER) {
+
+                    void** d = (void**) p0;
+
+                    log_message_debug("Serialise character vector.");
+
+                    if ((*dc + *sc) >= *ds) {
+
+                        // The new destination character vector size.
+                        // CAUTION! Add constant in case *dc is zero!
+                        *ds = (*dc * *CHARACTER_VECTOR_REALLOCATE_FACTOR) + *sc;
+
+                        // Reallocate destination character vector.
+                        reallocate_array(p0, p1, p2, (void*) CHARACTER_ARRAY);
+                    }
+
+                    // Set source into destination character vector.
+                    set_array_elements(*d, p1, p3, p4, (void*) CHARACTER_ARRAY);
+
+                    // Increment destination count.
+                    *dc = *dc + *sc;
+
+                } else {
+
+                    log_message_debug("Could not serialise character vector. The destination is null.");
+                }
+
+            } else {
+
+                log_message_debug("Could not serialise character vector. The destination count is null.");
+            }
+
+        } else {
+
+            log_message_debug("Could not serialise character vector. The destination size is null.");
+        }
+
+    } else {
+
+        log_message_debug("Could not serialise character vector. The source count is null.");
+    }
 }
 
 /* CHARACTER_VECTOR_CONVERTER_SOURCE */
