@@ -1,7 +1,7 @@
 /*
  * $RCSfile: double_vector_converter.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.6 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.11 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -30,10 +30,11 @@
 #include <string.h>
 //?? #include <stdio.h>
 //?? #include <stdlib.h>
-#include "../../globals/constants/ascii_character_constants.c"
-//?? #include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/log_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/character/character_constants.c"
+//?? #include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 //?? #include "../../memoriser/allocator.c"
 #include "../../memoriser/array.c"
@@ -49,18 +50,18 @@
  */
 void parse_double(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* sc = (int*) p4;
 
-        if (p0 != NULL_POINTER ) {
+        if (p0 != *NULL_POINTER ) {
 
             void** d = (void**) p0;
 
             log_message_debug("Parse double.");
 
             // The temporary null-terminated string.
-            char* tmp = NULL_POINTER;
+            char* tmp = (char*) *NULL_POINTER;
             int tmps = *sc + 1;
 
             // Create temporary null-terminated string.
@@ -76,14 +77,14 @@ void parse_double(void* p0, void* p1, void* p2, void* p3, void* p4) {
             i = *sc;
 
             // Add string termination to temporary null-terminated string.
-            set_array_elements((void*) tmp, (void*) &i, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) NUMBER_1_INTEGER, (void*) CHARACTER_ARRAY);
+            set_array_elements((void*) tmp, (void*) &i, (void*) NULL_CONTROL_CHARACTER, (void*) NUMBER_1_INTEGER, (void*) CHARACTER_ARRAY);
 
             // The tail variable is useless here and only needed for the string
             // transformation function. If the whole string array consists of
             // many sub strings, separated by space characters, then each sub
             // string gets interpreted as integer number.
             // The tail variable in this case points to the remaining sub string.
-            char* tail = NULL_POINTER;
+            char* tail = (char*) *NULL_POINTER;
 
             // Transform string to double value.
             // The strtod function recognizes four special input strings.
@@ -130,22 +131,22 @@ void parse_double(void* p0, void* p1, void* p2, void* p3, void* p4) {
  */
 void serialise_double(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p2 != NULL_POINTER) {
+    if (p2 != *NULL_POINTER) {
 
         int* ds = (int*) p2;
 
-        if (p1 != NULL_POINTER) {
+        if (p1 != *NULL_POINTER) {
 
             int* dc = (int*) p1;
 
-            if (p0 != NULL_POINTER) {
+            if (p0 != *NULL_POINTER) {
 
                 char** d = (char**) p0;
 
                 log_message_debug("Serialise double.");
 
                 // The double value.
-                double* v = NULL_POINTER;
+                double* v = (double*) *NULL_POINTER;
 
                 // Get double value.
                 get_array_elements(p3, (void*) PRIMITIVE_VALUE_INDEX, (void*) &v, (void*) DOUBLE_ARRAY);
@@ -204,15 +205,15 @@ void serialise_double(void* p0, void* p1, void* p2, void* p3, void* p4) {
  */
 void parse_double_vector(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* sc = (int*) p4;
 
-        if (p3 != NULL_POINTER) {
+        if (p3 != *NULL_POINTER) {
 
             void** s = (void**) p3;
 
-            if (p0 != NULL_POINTER) {
+            if (p0 != *NULL_POINTER) {
 
                 void** d = (void**) p0;
 
@@ -224,7 +225,7 @@ void parse_double_vector(void* p0, void* p1, void* p2, void* p3, void* p4) {
                 // The comma index.
                 int i = -1;
                 // The double vector element count.
-                void* c = NULL_POINTER;
+                void* c = *NULL_POINTER;
                 // The double number.
                 int n = 0;
 
@@ -235,7 +236,7 @@ void parse_double_vector(void* p0, void* p1, void* p2, void* p3, void* p4) {
                         break;
                     }
 
-                    get_character_array_elements_index(p3, p4, (void*) COMMA_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) &i);
+                    get_character_array_elements_index(p3, p4, (void*) COMMA_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) &i);
 
                     if (i > 0) {
 
@@ -334,7 +335,7 @@ void parse_double_vector(void* p0, void* p1, void* p2, void* p3, void* p4) {
 void serialise_double_vector(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
 /*??
-//??    log_message((void*) &INFO_LOG_LEVEL, (void*) &"Finalise double vector.");
+//??    log_message((void*) &INFORMATION_LOG_LEVEL, (void*) &"Finalise double vector.");
 
     // Write output stream and transform from double vector.
 
