@@ -1,7 +1,7 @@
 /*
  * $RCSfile: fraction_converter.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,14 +20,15 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.4 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.8 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef FRACTION_CONVERTER_SOURCE
 #define FRACTION_CONVERTER_SOURCE
 
-#include "../../globals/constants/log_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 
 //
@@ -48,20 +49,20 @@
  */
 void parse_fraction(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* sc = (int*) p4;
 
-        if (p3 != NULL_POINTER) {
+        if (p3 != *NULL_POINTER) {
 
             void* s = (void*) p3;
 
-            if (p0 != NULL_POINTER) {
+            if (p0 != *NULL_POINTER) {
 
                 void** d = (void**) p0;
 
 /*??
-            //??    log_message((void*) &INFO_LOG_LEVEL, (void*) &"Initialise fraction.");
+            //??    log_message((void*) &INFORMATION_LOG_LEVEL, (void*) &"Initialise fraction.");
 
             //??    sscanf(p1, %l, (void*) &(m->value));
 
@@ -102,7 +103,7 @@ void parse_fraction(void* p0, void* p1, void* p2, void* p3, void* p4) {
 void serialise_fraction(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
 /*??
-            //??    log_message((void*) &INFO_LOG_LEVEL, (void*) &"Finalise fraction.");
+            //??    log_message((void*) &INFORMATION_LOG_LEVEL, (void*) &"Finalise fraction.");
 
                 // Initialise elements.
                 int d = 0;
