@@ -1,7 +1,7 @@
 /*
  * $RCSfile: x_window_system_converter.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.7 $ $Date: 2006/06/04 00:54:45 $ $Author: christian $
+ * @version $Revision: 1.15 $ $Date: 2007/05/31 22:11:22 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -29,11 +29,13 @@
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/ascii_character_constants.c"
-#include "../../globals/constants/model_constants.c"
-#include "../../globals/constants/name_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/character/character_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/cybol/cybol_model_constants.c"
+#include "../../globals/constants/cybol/cybol_name_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/variables/variables.c"
 #include "../../memoriser/accessor.c"
 
@@ -65,19 +67,19 @@ void parse_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4) {
 void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
     void* p5, void* p6, void* p7, void* p8) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* sc = (int*) p4;
 
-        log_message_debug("Encode compound into x window system model.");
+        log_message_debug("Serialise x window system.");
 
         // The display, which is a subsumption of
         // xserver, screens, hardware (input devices etc.).
-        struct _XDisplay** di = (struct _XDisplay**) &NULL_POINTER;
+        struct _XDisplay** di = (struct _XDisplay**) NULL_POINTER;
         // The window.
-        int** w = NULL_POINTER;
+        int** w = (int**) NULL_POINTER;
         // The graphic context.
-        struct _XGC** gc = (struct _XGC**) &NULL_POINTER;
+        struct _XGC** gc = (struct _XGC**) NULL_POINTER;
         // The window attributes.
         XWindowAttributes wa;
 
@@ -90,20 +92,23 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
         XGetWindowAttributes(*di, **w, &wa);
 
         // The source whole size.
-        void** wsa = &NULL_POINTER;
-        void** wsac = &NULL_POINTER;
-        void** wsas = &NULL_POINTER;
-        void** wsm = &NULL_POINTER;
-        void** wsmc = &NULL_POINTER;
-        void** wsms = &NULL_POINTER;
-        void** wsd = &NULL_POINTER;
-        void** wsdc = &NULL_POINTER;
-        void** wsds = &NULL_POINTER;
+        void** wsn = NULL_POINTER;
+        void** wsnc = NULL_POINTER;
+        void** wsns = NULL_POINTER;
+        void** wsa = NULL_POINTER;
+        void** wsac = NULL_POINTER;
+        void** wsas = NULL_POINTER;
+        void** wsm = NULL_POINTER;
+        void** wsmc = NULL_POINTER;
+        void** wsms = NULL_POINTER;
+        void** wsd = NULL_POINTER;
+        void** wsdc = NULL_POINTER;
+        void** wsds = NULL_POINTER;
 
         // The source whole size coordinates.
-        int** wsmx = (int**) &NULL_POINTER;
-        int** wsmy = (int**) &NULL_POINTER;
-        int** wsmz = (int**) &NULL_POINTER;
+        int* wsmx = (int*) *NULL_POINTER;
+        int* wsmy = (int*) *NULL_POINTER;
+        int* wsmz = (int*) *NULL_POINTER;
 
         // The original area position coordinates, set to the zero origo.
         int oapx = *NUMBER_0_INTEGER;
@@ -123,29 +128,30 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
         int fasy = oasy;
         int fasz = oasz;
 
-        if (p5 != NULL_POINTER) {
+        if (p5 != *NULL_POINTER) {
 
             // Get source whole size from details.
             get_universal_compound_element_by_name(p5, p6,
                 (void*) UI_SIZE_NAME, (void*) UI_SIZE_NAME_COUNT,
+                (void*) &wsn, (void*) &wsnc, (void*) &wsns,
                 (void*) &wsa, (void*) &wsac, (void*) &wsas,
                 (void*) &wsm, (void*) &wsmc, (void*) &wsms,
                 (void*) &wsd, (void*) &wsdc, (void*) &wsds,
                 p7, p8);
 
             // Determine source whole size coordinates.
-            get(*wsm, (void*) NUMBER_0_INTEGER, (void*) &wsmx, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
-            get(*wsm, (void*) NUMBER_1_INTEGER, (void*) &wsmy, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
-            get(*wsm, (void*) NUMBER_2_INTEGER, (void*) &wsmz, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+            get(*wsm, (void*) NUMBER_0_INTEGER, (void*) &wsmx, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
+            get(*wsm, (void*) NUMBER_1_INTEGER, (void*) &wsmy, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
+            get(*wsm, (void*) NUMBER_2_INTEGER, (void*) &wsmz, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
 
             // Set original area position coordinates, set to the zero origo.
             oapx = *NUMBER_0_INTEGER;
             oapy = *NUMBER_0_INTEGER;
             oapz = *NUMBER_0_INTEGER;
             // Set original area size coordinates, initialised with whole coordinates.
-            oasx = **wsmx;
-            oasy = **wsmy;
-            oasz = **wsmz;
+            oasx = *wsmx;
+            oasy = *wsmy;
+            oasz = *wsmz;
 
             // Set free area position coordinates, initialised with original area position coordinates.
             fapx = oapx;
@@ -157,110 +163,134 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
             fasz = oasz;
         }
 
-        // The source part abstraction, model, details.
-        void** a = &NULL_POINTER;
-        void** ac = &NULL_POINTER;
-        void** as = &NULL_POINTER;
-        void** m = &NULL_POINTER;
-        void** mc = &NULL_POINTER;
-        void** ms = &NULL_POINTER;
-        void** d = &NULL_POINTER;
-        void** dc = &NULL_POINTER;
-        void** ds = &NULL_POINTER;
-        // The source part layout.
-        void** la = &NULL_POINTER;
-        void** lac = &NULL_POINTER;
-        void** las = &NULL_POINTER;
-        void** lm = &NULL_POINTER;
-        void** lmc = &NULL_POINTER;
-        void** lms = &NULL_POINTER;
-        void** ld = &NULL_POINTER;
-        void** ldc = &NULL_POINTER;
-        void** lds = &NULL_POINTER;
-        // The source part cell.
-        void** ca = &NULL_POINTER;
-        void** cac = &NULL_POINTER;
-        void** cas = &NULL_POINTER;
-        void** cm = &NULL_POINTER;
-        void** cmc = &NULL_POINTER;
-        void** cms = &NULL_POINTER;
-        void** cd = &NULL_POINTER;
-        void** cdc = &NULL_POINTER;
-        void** cds = &NULL_POINTER;
-        // The source part position.
-        void** pa = &NULL_POINTER;
-        void** pac = &NULL_POINTER;
-        void** pas = &NULL_POINTER;
-        void** pm = &NULL_POINTER;
-        void** pmc = &NULL_POINTER;
-        void** pms = &NULL_POINTER;
-        void** pd = &NULL_POINTER;
-        void** pdc = &NULL_POINTER;
-        void** pds = &NULL_POINTER;
-        // The source part shape.
-        void** sha = &NULL_POINTER;
-        void** shac = &NULL_POINTER;
-        void** shas = &NULL_POINTER;
-        void** shm = &NULL_POINTER;
-        void** shmc = &NULL_POINTER;
-        void** shms = &NULL_POINTER;
-        void** shd = &NULL_POINTER;
-        void** shdc = &NULL_POINTER;
-        void** shds = &NULL_POINTER;
-        // The source part size.
-        void** sa = &NULL_POINTER;
-        void** sac = &NULL_POINTER;
-        void** sas = &NULL_POINTER;
-        void** sm = &NULL_POINTER;
-        void** smc = &NULL_POINTER;
-        void** sms = &NULL_POINTER;
-        void** sd = &NULL_POINTER;
-        void** sdc = &NULL_POINTER;
-        void** sds = &NULL_POINTER;
-        // The source part title.
-        void** ta = &NULL_POINTER;
-        void** tac = &NULL_POINTER;
-        void** tas = &NULL_POINTER;
-        void** tm = &NULL_POINTER;
-        void** tmc = &NULL_POINTER;
-        void** tms = &NULL_POINTER;
-        void** td = &NULL_POINTER;
-        void** tdc = &NULL_POINTER;
-        void** tds = &NULL_POINTER;
-        // The source part icon.
-        void** ia = &NULL_POINTER;
-        void** iac = &NULL_POINTER;
-        void** ias = &NULL_POINTER;
-        void** im = &NULL_POINTER;
-        void** imc = &NULL_POINTER;
-        void** ims = &NULL_POINTER;
-        void** id = &NULL_POINTER;
-        void** idc = &NULL_POINTER;
-        void** ids = &NULL_POINTER;
+        // The source part name, abstraction, model, details.
+        void** n = NULL_POINTER;
+        void** nc = NULL_POINTER;
+        void** ns = NULL_POINTER;
+        void** a = NULL_POINTER;
+        void** ac = NULL_POINTER;
+        void** as = NULL_POINTER;
+        void** m = NULL_POINTER;
+        void** mc = NULL_POINTER;
+        void** ms = NULL_POINTER;
+        void** d = NULL_POINTER;
+        void** dc = NULL_POINTER;
+        void** ds = NULL_POINTER;
+        // The source part layout name, abstraction, model, details.
+        void** ln = NULL_POINTER;
+        void** lnc = NULL_POINTER;
+        void** lns = NULL_POINTER;
+        void** la = NULL_POINTER;
+        void** lac = NULL_POINTER;
+        void** las = NULL_POINTER;
+        void** lm = NULL_POINTER;
+        void** lmc = NULL_POINTER;
+        void** lms = NULL_POINTER;
+        void** ld = NULL_POINTER;
+        void** ldc = NULL_POINTER;
+        void** lds = NULL_POINTER;
+        // The source part cell name, abstraction, model, details.
+        void** cn = NULL_POINTER;
+        void** cnc = NULL_POINTER;
+        void** cns = NULL_POINTER;
+        void** ca = NULL_POINTER;
+        void** cac = NULL_POINTER;
+        void** cas = NULL_POINTER;
+        void** cm = NULL_POINTER;
+        void** cmc = NULL_POINTER;
+        void** cms = NULL_POINTER;
+        void** cd = NULL_POINTER;
+        void** cdc = NULL_POINTER;
+        void** cds = NULL_POINTER;
+        // The source part position name, abstraction, model, details.
+        void** pn = NULL_POINTER;
+        void** pnc = NULL_POINTER;
+        void** pns = NULL_POINTER;
+        void** pa = NULL_POINTER;
+        void** pac = NULL_POINTER;
+        void** pas = NULL_POINTER;
+        void** pm = NULL_POINTER;
+        void** pmc = NULL_POINTER;
+        void** pms = NULL_POINTER;
+        void** pd = NULL_POINTER;
+        void** pdc = NULL_POINTER;
+        void** pds = NULL_POINTER;
+        // The source part shape name, abstraction, model, details.
+        void** shn = NULL_POINTER;
+        void** shnc = NULL_POINTER;
+        void** shns = NULL_POINTER;
+        void** sha = NULL_POINTER;
+        void** shac = NULL_POINTER;
+        void** shas = NULL_POINTER;
+        void** shm = NULL_POINTER;
+        void** shmc = NULL_POINTER;
+        void** shms = NULL_POINTER;
+        void** shd = NULL_POINTER;
+        void** shdc = NULL_POINTER;
+        void** shds = NULL_POINTER;
+        // The source part size name, abstraction, model, details.
+        void** sn = NULL_POINTER;
+        void** snc = NULL_POINTER;
+        void** sns = NULL_POINTER;
+        void** sa = NULL_POINTER;
+        void** sac = NULL_POINTER;
+        void** sas = NULL_POINTER;
+        void** sm = NULL_POINTER;
+        void** smc = NULL_POINTER;
+        void** sms = NULL_POINTER;
+        void** sd = NULL_POINTER;
+        void** sdc = NULL_POINTER;
+        void** sds = NULL_POINTER;
+        // The source part title name, abstraction, model, details.
+        void** tn = NULL_POINTER;
+        void** tnc = NULL_POINTER;
+        void** tns = NULL_POINTER;
+        void** ta = NULL_POINTER;
+        void** tac = NULL_POINTER;
+        void** tas = NULL_POINTER;
+        void** tm = NULL_POINTER;
+        void** tmc = NULL_POINTER;
+        void** tms = NULL_POINTER;
+        void** td = NULL_POINTER;
+        void** tdc = NULL_POINTER;
+        void** tds = NULL_POINTER;
+        // The source part icon name, abstraction, model, details.
+        void** in = NULL_POINTER;
+        void** inc = NULL_POINTER;
+        void** ins = NULL_POINTER;
+        void** ia = NULL_POINTER;
+        void** iac = NULL_POINTER;
+        void** ias = NULL_POINTER;
+        void** im = NULL_POINTER;
+        void** imc = NULL_POINTER;
+        void** ims = NULL_POINTER;
+        void** id = NULL_POINTER;
+        void** idc = NULL_POINTER;
+        void** ids = NULL_POINTER;
 
         // The terminated title.
-        void* tt = NULL_POINTER;
-        int tts = -1;
+        void* tt = *NULL_POINTER;
+        int tts = *NUMBER_MINUS_1_INTEGER;
         // The terminated icon name.
-        void* ti = NULL_POINTER;
-        int tis = -1;
+        void* ti = *NULL_POINTER;
+        int tis = *NUMBER_MINUS_1_INTEGER;
 
         // The source part position coordinates.
-        int** pmx = (int**) &NULL_POINTER;
-        int** pmy = (int**) &NULL_POINTER;
-        int** pmz = (int**) &NULL_POINTER;
+        int* pmx = (int*) *NULL_POINTER;
+        int* pmy = (int*) *NULL_POINTER;
+        int* pmz = (int*) *NULL_POINTER;
         // The source part size coordinates.
-        int** smx = (int**) &NULL_POINTER;
-        int** smy = (int**) &NULL_POINTER;
-        int** smz = (int**) &NULL_POINTER;
+        int* smx = (int*) *NULL_POINTER;
+        int* smy = (int*) *NULL_POINTER;
+        int* smz = (int*) *NULL_POINTER;
 
         // The loop count.
-        int j = 0;
+        int j = *NUMBER_0_INTEGER;
         // The comparison result.
-        int r = 0;
+        int r = *NUMBER_0_INTEGER;
 
         // Iterate through compound parts.
-        while (1) {
+        while (*NUMBER_1_INTEGER) {
 
             if (j >= *sc) {
 
@@ -269,6 +299,7 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
 
             // Get source part at index j.
             get_compound_element_by_index(p3, p4, (void*) &j,
+                (void*) &n, (void*) &nc, (void*) &ns,
                 (void*) &a, (void*) &ac, (void*) &as,
                 (void*) &m, (void*) &mc, (void*) &ms,
                 (void*) &d, (void*) &dc, (void*) &ds);
@@ -276,6 +307,7 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
             // Get source part layout from details.
             get_universal_compound_element_by_name(*d, *dc,
                 (void*) UI_LAYOUT_NAME, (void*) UI_LAYOUT_NAME_COUNT,
+                (void*) &ln, (void*) &lnc, (void*) &lns,
                 (void*) &la, (void*) &lac, (void*) &las,
                 (void*) &lm, (void*) &lmc, (void*) &lms,
                 (void*) &ld, (void*) &ldc, (void*) &lds,
@@ -283,6 +315,7 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
             // Get source part cell from details.
             get_universal_compound_element_by_name(*d, *dc,
                 (void*) UI_CELL_NAME, (void*) UI_CELL_NAME_COUNT,
+                (void*) &cn, (void*) &cnc, (void*) &cns,
                 (void*) &ca, (void*) &cac, (void*) &cas,
                 (void*) &cm, (void*) &cmc, (void*) &cms,
                 (void*) &cd, (void*) &cdc, (void*) &cds,
@@ -290,6 +323,7 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
             // Get source part position from details.
             get_universal_compound_element_by_name(*d, *dc,
                 (void*) UI_POSITION_NAME, (void*) UI_POSITION_NAME_COUNT,
+                (void*) &pn, (void*) &pnc, (void*) &pns,
                 (void*) &pa, (void*) &pac, (void*) &pas,
                 (void*) &pm, (void*) &pmc, (void*) &pms,
                 (void*) &pd, (void*) &pdc, (void*) &pds,
@@ -297,25 +331,30 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
             // Get source part size from details.
             get_universal_compound_element_by_name(*d, *dc,
                 (void*) UI_SIZE_NAME, (void*) UI_SIZE_NAME_COUNT,
+                (void*) &sn, (void*) &snc, (void*) &sns,
                 (void*) &sa, (void*) &sac, (void*) &sas,
                 (void*) &sm, (void*) &smc, (void*) &sms,
                 (void*) &sd, (void*) &sdc, (void*) &sds,
                 p7, p8);
 
             // Get source part position coordinates.
-            get(*pm, (void*) NUMBER_0_INTEGER, (void*) &pmx, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
-            get(*pm, (void*) NUMBER_1_INTEGER, (void*) &pmy, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
-            get(*pm, (void*) NUMBER_2_INTEGER, (void*) &pmz, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+            get(*pm, (void*) NUMBER_0_INTEGER, (void*) &pmx, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
+            get(*pm, (void*) NUMBER_1_INTEGER, (void*) &pmy, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
+            get(*pm, (void*) NUMBER_2_INTEGER, (void*) &pmz, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
             // Get source part size coordinates.
-            get(*sm, (void*) NUMBER_0_INTEGER, (void*) &smx, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
-            get(*sm, (void*) NUMBER_1_INTEGER, (void*) &smy, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
-            get(*sm, (void*) NUMBER_2_INTEGER, (void*) &smz, (void*) POINTER_VECTOR_ABSTRACTION, (void*) POINTER_VECTOR_ABSTRACTION_COUNT);
+            get(*sm, (void*) NUMBER_0_INTEGER, (void*) &smx, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
+            get(*sm, (void*) NUMBER_1_INTEGER, (void*) &smy, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
+            get(*sm, (void*) NUMBER_2_INTEGER, (void*) &smz, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
+
+    fprintf(stderr, "layout: %s\n", *lm);
+    fprintf(stderr, "layout count: %i\n", *((int*) *lmc));
 
             compare_arrays(*lm, *lmc, (void*) UI_ROOT_LAYOUT_MODEL, (void*) UI_ROOT_LAYOUT_MODEL_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-            if (r == 0) {
+            if (r == *NUMBER_0_INTEGER) {
 
                 // The source part is no root window.
+                log_message_debug("Debug: This is not a root window.");
 
                 // Calculate coordinates according to given layout.
 /*??
@@ -326,18 +365,18 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
 */
 
                 // Draw graphical element using given coordinates.
-                XDrawRectangle(*di, **w, *gc, **pmx, **pmy, **smx - 1, **smy - 1);
+                XDrawRectangle(*di, **w, *gc, *pmx, *pmy, *smx - *NUMBER_1_INTEGER, *smy - *NUMBER_1_INTEGER);
 
                 // Reset comparison result.
-                r = 0;
+                r = *NUMBER_0_INTEGER;
 
                 compare_arrays(*a, *ac, (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-                if (r != 0) {
+                if (r != *NUMBER_0_INTEGER) {
 
                     // The terminated text.
-                    char* text = NULL_POINTER;
-                    int texts = *((int*) *mc) + 1;
+                    char* text = (char*) *NULL_POINTER;
+                    int texts = *((int*) *mc) + *NUMBER_1_INTEGER;
 
                     // Create terminated text.
                     allocate_array((void*) &text, (void*) &texts, (void*) CHARACTER_ARRAY);
@@ -345,10 +384,10 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
                     // Set terminated text by first copying the actual name
                     // and then adding the null termination character.
                     set_array_elements(text, (void*) NUMBER_0_INTEGER, *m, *mc, (void*) CHARACTER_ARRAY);
-                    set_array_elements(text, *mc, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+                    set_array_elements(text, *mc, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
 
                     // Draw the text (character vector / string).
-                    XDrawString(*di, **w, *gc, **pmx, **pmy + 20, text, texts);
+                    XDrawString(*di, **w, *gc, *pmx, *pmy + *NUMBER_20_INTEGER, text, texts);
 
                     // Destroy terminated text.
                     deallocate_array((void*) &text, (void*) &texts, (void*) CHARACTER_ARRAY);
@@ -475,15 +514,17 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
             } else {
 
                 // The source part is a root window.
+                log_message_debug("Debug: This is a root window.");
 
                 // Move window to new position coordinates for part.
-                XMoveWindow(*di, **w, **pmx, **pmy);
+                XMoveWindow(*di, **w, *pmx, *pmy);
                 // Resize window to new size coordinates for part.
-                XResizeWindow(*di, **w, **smx, **smy);
+                XResizeWindow(*di, **w, *smx, *smy);
 
                 // Get source part title from details.
                 get_universal_compound_element_by_name(*d, *dc,
                     (void*) GUI_TITLE_NAME, (void*) GUI_TITLE_NAME_COUNT,
+                    (void*) &tn, (void*) &tnc, (void*) &tns,
                     (void*) &ta, (void*) &tac, (void*) &tas,
                     (void*) &tm, (void*) &tmc, (void*) &tms,
                     (void*) &td, (void*) &tdc, (void*) &tds,
@@ -491,17 +532,18 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
                 // Get source part icon from details.
                 get_universal_compound_element_by_name(*d, *dc,
                     (void*) GUI_ICON_NAME, (void*) GUI_ICON_NAME_COUNT,
+                    (void*) &in, (void*) &inc, (void*) &ins,
                     (void*) &ia, (void*) &iac, (void*) &ias,
                     (void*) &im, (void*) &imc, (void*) &ims,
                     (void*) &id, (void*) &idc, (void*) &ids,
                     p7, p8);
 
                 // The terminated title.
-                tt = NULL_POINTER;
-                tts = *((int*) *tmc) + 1;
+                tt = *NULL_POINTER;
+                tts = *((int*) *tmc) + *NUMBER_1_INTEGER;
                 // The terminated icon name.
-                ti = NULL_POINTER;
-                tis = *((int*) *imc) + 1;
+                ti = *NULL_POINTER;
+                tis = *((int*) *imc) + *NUMBER_1_INTEGER;
 
                 // Create terminated title.
                 allocate_array((void*) &tt, (void*) &tts, (void*) CHARACTER_ARRAY);
@@ -511,11 +553,11 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
                 // Set terminated title by first copying the actual name
                 // and then adding the null termination character.
                 set_array_elements(tt, (void*) NUMBER_0_INTEGER, *tm, *tmc, (void*) CHARACTER_ARRAY);
-                set_array_elements(tt, *tmc, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+                set_array_elements(tt, *tmc, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
                 // Set terminated icon name by first copying the actual name
                 // and then adding the null termination character.
                 set_array_elements(ti, (void*) NUMBER_0_INTEGER, *im, *imc, (void*) CHARACTER_ARRAY);
-                set_array_elements(ti, *imc, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+                set_array_elements(ti, *imc, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
 
                 // Set terminated window title.
                 XStoreName(*di, **w, (char*) tt);
@@ -529,90 +571,94 @@ void serialise_x_window_system(void* p0, void* p1, void* p2, void* p3, void* p4,
             }
 
             // Reset comparison result.
-            r = 0;
+            r = *NUMBER_0_INTEGER;
 
             compare_arrays(*a, *ac, (void*) COMPOUND_ABSTRACTION, (void*) COMPOUND_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-            if (r != 0) {
+            if (r != *NUMBER_0_INTEGER) {
 
                 // The part model is a compound.
+                log_message_debug("Debug: The part model is a compound.");
 
                 // Recursively call this procedure for compound part model.
-                serialise_x_window_system(p0, p1, p2, *m, (void*) *mc, *d, *dc, p7, p8);
+                serialise_x_window_system(p0, p1, p2, *m, *mc, *d, *dc, p7, p8);
             }
 
-            // Reset source part abstraction, model, details.
-            a = &NULL_POINTER;
-            ac = &NULL_POINTER;
-            as = &NULL_POINTER;
-            m = &NULL_POINTER;
-            mc = &NULL_POINTER;
-            ms = &NULL_POINTER;
-            d = &NULL_POINTER;
-            dc = &NULL_POINTER;
-            ds = &NULL_POINTER;
+            // Reset source part name, abstraction, model, details.
+            n = NULL_POINTER;
+            nc = NULL_POINTER;
+            ns = NULL_POINTER;
+            a = NULL_POINTER;
+            ac = NULL_POINTER;
+            as = NULL_POINTER;
+            m = NULL_POINTER;
+            mc = NULL_POINTER;
+            ms = NULL_POINTER;
+            d = NULL_POINTER;
+            dc = NULL_POINTER;
+            ds = NULL_POINTER;
             // Reset source part layout.
-            la = &NULL_POINTER;
-            lac = &NULL_POINTER;
-            las = &NULL_POINTER;
-            lm = &NULL_POINTER;
-            lmc = &NULL_POINTER;
-            lms = &NULL_POINTER;
-            ld = &NULL_POINTER;
-            ldc = &NULL_POINTER;
-            lds = &NULL_POINTER;
+            la = NULL_POINTER;
+            lac = NULL_POINTER;
+            las = NULL_POINTER;
+            lm = NULL_POINTER;
+            lmc = NULL_POINTER;
+            lms = NULL_POINTER;
+            ld = NULL_POINTER;
+            ldc = NULL_POINTER;
+            lds = NULL_POINTER;
             // Reset source part cell.
-            ca = &NULL_POINTER;
-            cac = &NULL_POINTER;
-            cas = &NULL_POINTER;
-            cm = &NULL_POINTER;
-            cmc = &NULL_POINTER;
-            cms = &NULL_POINTER;
-            cd = &NULL_POINTER;
-            cdc = &NULL_POINTER;
-            cds = &NULL_POINTER;
+            ca = NULL_POINTER;
+            cac = NULL_POINTER;
+            cas = NULL_POINTER;
+            cm = NULL_POINTER;
+            cmc = NULL_POINTER;
+            cms = NULL_POINTER;
+            cd = NULL_POINTER;
+            cdc = NULL_POINTER;
+            cds = NULL_POINTER;
             // Reset source part position.
-            pa = &NULL_POINTER;
-            pac = &NULL_POINTER;
-            pas = &NULL_POINTER;
-            pm = &NULL_POINTER;
-            pmc = &NULL_POINTER;
-            pms = &NULL_POINTER;
-            pd = &NULL_POINTER;
-            pdc = &NULL_POINTER;
-            pds = &NULL_POINTER;
+            pa = NULL_POINTER;
+            pac = NULL_POINTER;
+            pas = NULL_POINTER;
+            pm = NULL_POINTER;
+            pmc = NULL_POINTER;
+            pms = NULL_POINTER;
+            pd = NULL_POINTER;
+            pdc = NULL_POINTER;
+            pds = NULL_POINTER;
             // Reset source part size.
-            sa = &NULL_POINTER;
-            sac = &NULL_POINTER;
-            sas = &NULL_POINTER;
-            sm = &NULL_POINTER;
-            smc = &NULL_POINTER;
-            sms = &NULL_POINTER;
-            sd = &NULL_POINTER;
-            sdc = &NULL_POINTER;
-            sds = &NULL_POINTER;
+            sa = NULL_POINTER;
+            sac = NULL_POINTER;
+            sas = NULL_POINTER;
+            sm = NULL_POINTER;
+            smc = NULL_POINTER;
+            sms = NULL_POINTER;
+            sd = NULL_POINTER;
+            sdc = NULL_POINTER;
+            sds = NULL_POINTER;
             // The source part title and icon are not reset,
             // since only one window may be the root of all graphical parts
             // and further windows must not occur as part.
 
             // Reset source part position coordinates.
-            pmx = (int**) &NULL_POINTER;
-            pmy = (int**) &NULL_POINTER;
-            pmz = (int**) &NULL_POINTER;
+            pmx = (int*) *NULL_POINTER;
+            pmy = (int*) *NULL_POINTER;
+            pmz = (int*) *NULL_POINTER;
             // Reset source part size coordinates.
-            smx = (int**) &NULL_POINTER;
-            smy = (int**) &NULL_POINTER;
-            smz = (int**) &NULL_POINTER;
+            smx = (int*) *NULL_POINTER;
+            smy = (int*) *NULL_POINTER;
+            smz = (int*) *NULL_POINTER;
 
             // Reset terminated title.
-            tt = NULL_POINTER;
-            tts = -1;
+            tt = *NULL_POINTER;
+            tts = *NUMBER_MINUS_1_INTEGER;
             // Reset terminated icon name.
-            ti = NULL_POINTER;
-            tis = -1;
+            ti = *NULL_POINTER;
+            tis = *NUMBER_MINUS_1_INTEGER;
 
             // Reset comparison result.
-            r = 0;
+            r = *NUMBER_0_INTEGER;
 
             // Increment loop count.
             j++;
