@@ -1,7 +1,7 @@
 /*
  * $RCSfile: xml_converter.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,7 +24,7 @@
  * - parse an xml stream into an xml model
  * - serialise an xml model into an xml stream
  *
- * @version $Revision: 1.13 $ $Date: 2006/06/24 18:06:57 $ $Author: christian $
+ * @version $Revision: 1.19 $ $Date: 2007/05/26 21:19:58 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -32,10 +32,11 @@
 #define XML_CONVERTER_SOURCE
 
 #include <libxml/parser.h>
-#include "../../globals/constants/character_constants.c"
-#include "../../globals/constants/cybol_constants.c"
-#include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/log_constants.c"
+#include "../../globals/constants/character/character_constants.c"
+#include "../../globals/constants/cybol/cybol_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/log/log_message_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/allocator.c"
 #include "../../memoriser/allocator/xml_node_allocator.c"
@@ -56,7 +57,7 @@
  */
 void parse_xml_comment_tag(void* p0, void* p1) {
 
-    if (p1 != NULL_POINTER) {
+    if (p1 != *NULL_POINTER) {
 
         int* sc = (int*) p1;
 
@@ -150,7 +151,7 @@ void parse_xml_comment_tag(void* p0, void* p1) {
  */
 void parse_xml_tag(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* sc = (int*) p4;
 
@@ -233,15 +234,15 @@ void parse_xml_tag(void* p0, void* p1, void* p2, void* p3, void* p4) {
  */
 void parse_xml(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* sc = (int*) p4;
 
-        if (p3 != NULL_POINTER) {
+        if (p3 != *NULL_POINTER) {
 
             void* s = (void*) p3;
 
-            if (p0 != NULL_POINTER) {
+            if (p0 != *NULL_POINTER) {
 
                 void** d = (void**) p0;
 
@@ -253,8 +254,10 @@ void parse_xml(void* p0, void* p1, void* p2, void* p3, void* p4) {
                 // messages of the xml parser.
                 if (*sc > 0) {
 
+                    log_message_debug("Information: Parse xml.");
+
                     // The temporary null-terminated file name.
-                    void* tmp = NULL_POINTER;
+                    void* tmp = *NULL_POINTER;
                     int tmps = *sc + 1;
 
                     // Create temporary null-terminated file name.
@@ -263,7 +266,7 @@ void parse_xml(void* p0, void* p1, void* p2, void* p3, void* p4) {
                     // Set terminated file name by first copying the actual name
                     // and then adding the null termination character.
                     set_array_elements(tmp, (void*) NUMBER_0_INTEGER, p3, p4, (void*) CHARACTER_ARRAY);
-                    set_array_elements(tmp, p4, (void*) NULL_CONTROL_ASCII_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
+                    set_array_elements(tmp, p4, (void*) NULL_CONTROL_CHARACTER, (void*) PRIMITIVE_COUNT, (void*) CHARACTER_ARRAY);
 
                     // Initialise the library.
                     // Check potential ABI mismatches between the version
@@ -282,14 +285,14 @@ void parse_xml(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
                 } else {
 
-                    log_message_debug("Could not parse xml. The file name count is null.");
+                    log_message_debug("Error: Could not parse xml. The file name count is null.");
                 }
 
                 //?? END of temporary workaround for using the libxml2 parser.
 
 /*??
             // The comparison result.
-            int* r = NULL_POINTER;
+            int* r = (int*) *NULL_POINTER;
             allocate((void*) &r, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
             *r = 0;
             // The current byte within the stream.
@@ -346,7 +349,7 @@ void parse_xml(void* p0, void* p1, void* p2, void* p3, void* p4) {
                             bc = bc - BEGIN_TAG_BEGIN_COUNT;
 
                             // Initialise xml tag.
-                            void* t = NULL_POINTER;
+                            void* t = *NULL_POINTER;
                             int tc = 0;
                             int ts = 0;
 
@@ -391,17 +394,17 @@ void parse_xml(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
             } else {
 
-//??                log_message((void*) &ERROR_LOG_LEVEL, (void*) &"Could not parse xml. The destination is null.");
+                log_message_debug("Error: Could not parse xml. The destination is null.");
             }
 
         } else {
 
-//??            log_message((void*) &ERROR_LOG_LEVEL, (void*) &"Could not parse xml. The file name is null.");
+            log_message_debug("Error: Could not parse xml. The source is null.");
         }
 
     } else {
 
-//??        log_message((void*) &ERROR_LOG_LEVEL, (void*) &"Could not parse xml. The file name count is null.");
+        log_message_debug("Error: Could not parse xml. The source count is null.");
     }
 }
 
