@@ -1,7 +1,7 @@
 /*
  * $RCSfile: mapper.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,14 +20,14 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.3 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.5 $ $Date: 2007/04/16 15:50:29 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef MAPPER_SOURCE
 #define MAPPER_SOURCE
 
-#include "../globals/constants/abstraction_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
 #include "../memoriser/array.c"
 #include "../memoriser/mapper/terminal_background_mapper.c"
 #include "../memoriser/mapper/terminal_foreground_mapper.c"
