@@ -1,7 +1,7 @@
 /*
  * $RCSfile: character_control_sequence_mapper.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,17 +20,18 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.6 $ $Date: 2006/04/20 22:36:11 $ $Author: christian $
+ * @version $Revision: 1.9 $ $Date: 2007/05/16 19:29:02 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef CHARACTER_ESCAPE_CODE_MAPPER_SOURCE
 #define CHARACTER_ESCAPE_CODE_MAPPER_SOURCE
 
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/ascii_character_constants.c"
-#include "../../globals/constants/escape_code_constants.c"
-#include "../../globals/constants/structure_constants.c"
+#include "../../globals/constants/character/character_constants.c"
+#include "../../globals/constants/console/console_escape_code_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/memory_structure/memory_structure_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/variables/variables.c"
 
 /**
@@ -53,11 +54,11 @@
  */
 void get_escape_code(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p1 != NULL_POINTER) {
+    if (p1 != *NULL_POINTER) {
 
         int* dc = (int*) p1;
 
-        if (p0 != NULL_POINTER) {
+        if (p0 != *NULL_POINTER) {
 
             void** d = (void**) p0;
 
@@ -66,7 +67,7 @@ void get_escape_code(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
             if (r == 0) {
 
-                compare_arrays(p3, p4, SPACE_ASCII_CHARACTER, PRIMITIVE_COUNT, &r, (void*) CHARACTER_ARRAY);
+                compare_arrays(p3, p4, SPACE_CHARACTER, PRIMITIVE_COUNT, &r, (void*) CHARACTER_ARRAY);
 
                 if (r == 1) {
 
@@ -77,7 +78,7 @@ void get_escape_code(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
             if (r == 0) {
 
-                compare_arrays(p3, p4, SPACE_ASCII_CHARACTER, PRIMITIVE_COUNT, &r, (void*) CHARACTER_ARRAY);
+                compare_arrays(p3, p4, SPACE_CHARACTER, PRIMITIVE_COUNT, &r, (void*) CHARACTER_ARRAY);
 
                 if (r == 1) {
 
