@@ -1,7 +1,7 @@
 /*
  * $RCSfile: translator.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,19 +20,19 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.12 $ $Date: 2006/06/04 00:54:45 $ $Author: christian $
+ * @version $Revision: 1.17 $ $Date: 2007/04/16 15:50:29 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
 #ifndef TRANSLATOR_SOURCE
 #define TRANSLATOR_SOURCE
 
-#include "../globals/constants/abstraction_constants.c"
-#include "../globals/constants/model_constants.c"
+#include "../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../globals/constants/cybol/cybol_model_constants.c"
 #include "../globals/variables/variables.c"
 #include "../memoriser/array.c"
+#include "../memoriser/translator/xdt_translator.c"
 #include "../memoriser/translator/cybol_translator.c"
-#include "../memoriser/translator/html_translator.c"
 
 /**
  * Decodes the document model according to the given document type
@@ -63,21 +63,21 @@ void decode(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
 
     if (r == 0) {
 
-        compare_arrays(p5, p6, (void*) HTML_ABSTRACTION, (void*) HTML_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+        compare_arrays(p5, p6, (void*) HXP_ABSTRACTION, (void*) HXP_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
         if (r != 0) {
 
-//??            decode_html(p0, p1, p2, p3, p4);
+//??            decode_hxp(p0, p1, p2, p3, p4);
         }
     }
 
     if (r == 0) {
 
-        compare_arrays(p5, p6, (void*) SXW_ABSTRACTION, (void*) SXW_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+        compare_arrays(p5, p6, (void*) XDT_ABSTRACTION, (void*) XDT_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
         if (r != 0) {
 
-//??            decode_sxw(p0, p1, p2, p3, p4);
+            decode_xdt(p0, p1, p2, p3, p4);
         }
     }
 
@@ -90,7 +90,6 @@ void decode(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
 //??            decode_hxp(p0, p1, p2, p3, p4);
         }
     }
-
 }
 
 /**
@@ -122,11 +121,11 @@ void encode(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
 
     if (r == 0) {
 
-        compare_arrays(p5, p6, (void*) HTML_ABSTRACTION, (void*) HTML_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
+        compare_arrays(p5, p6, (void*) XDT_ABSTRACTION, (void*) XDT_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
         if (r != 0) {
 
-//??            encode_html(p0, p1, p2, p3, p4);
+            encode_xdt(p0, p1, p2, p3, p4);
         }
     }
 
@@ -149,51 +148,6 @@ void encode(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5, void* p6
 //??            encode_hxp(p0, p1, p2, p3, p4);
         }
     }
-
-}
-
-/**
- * Encodes a cyboi model according to the given document type
- * and creates a document model from it.
- *
- * @param dest the destination (Hand over as reference!)
- * @param dest_count the destination count
- * @param dest_size the destination size
- * @param source_abstr the source abstraction
- * @param source_abstr_count the source abstraction count
- * @param source_model the source model
- * @param source_model_count the source model count
- * @param source_detail the source detail
- * @param source_detail_count the source detail count
- * @param type the type
- * @param type_count the type count
- * @param know the knowledege memeory
- * @param know_count the knowledege memeory count
- * @param know_size the knowledege memeory size
- */
-void encode_model(void** dest, int* dest_count, int* dest_size,
-                  void* source_abstr, int* source_abstr_count,
-                  void* source_model, int* source_model_count,
-                  void* source_detail, int* source_detail_count,
-                  void* type, int* type_count,
-                  void* know, int* know_count) {
-
-    // The comparison result.
-    int r = 0;
-
-    if (r == 0) {
-
-        compare_arrays(type, type_count, (void*) HTML_ABSTRACTION, (void*) HTML_ABSTRACTION_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
-
-        if (r != 0) {
-
-            encode_html(dest, dest_count, dest_size,
-                source_abstr, source_abstr_count,
-                source_model, source_model_count,
-                source_detail, source_detail_count,
-                know, know_count);
-        }
-    }
 }
 
 /* TRANSLATOR_SOURCE */
