@@ -1,7 +1,7 @@
 /*
  * $RCSfile: cybol_translator.c,v $
  *
- * Copyright (c) 1999-2006. Christian Heller and the CYBOP developers.
+ * Copyright (c) 1999-2007. Christian Heller and the CYBOP developers.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -20,7 +20,7 @@
  * http://www.cybop.net
  * - Cybernetics Oriented Programming -
  *
- * @version $Revision: 1.13 $ $Date: 2006/06/25 22:08:25 $ $Author: christian $
+ * @version $Revision: 1.19 $ $Date: 2007/05/16 19:29:02 $ $Author: christian $
  * @author Christian Heller <christian.heller@tuxtax.de>
  */
 
@@ -29,11 +29,12 @@
 
 #include <string.h>
 #include <libxml/tree.h>
-#include "../../globals/constants/abstraction_constants.c"
-#include "../../globals/constants/channel_constants.c"
-#include "../../globals/constants/cybol_constants.c"
-#include "../../globals/constants/integer_constants.c"
-#include "../../globals/constants/name_constants.c"
+#include "../../globals/constants/cybol/cybol_abstraction_constants.c"
+#include "../../globals/constants/cybol/cybol_channel_constants.c"
+#include "../../globals/constants/cybol/cybol_constants.c"
+#include "../../globals/constants/integer/integer_constants.c"
+#include "../../globals/constants/cybol/cybol_name_constants.c"
+#include "../../globals/constants/pointer/pointer_constants.c"
 #include "../../globals/logger/logger.c"
 #include "../../memoriser/array.c"
 #include "../../memoriser/allocator.c"
@@ -43,27 +44,60 @@
 //
 
 /**
- * Receives a file system model.
+ * Receives and creates a transient destination model
+ * from a persistent source model.
  *
- * @param p0 the destination
- * @param p1 the destination count
- * @param p2 the destination size
- * @param p3 the source model
- * @param p4 the source model count
- * @param p5 the source abstraction
- * @param p6 the source abstraction count
- * @param p7 the source channel
- * @param p8 the source channel count
+ * Primitive models need to be handled differently than compound models.
+ *
+ * persistent:
+ * - stored permanently
+ * - outside CYBOI
+ * - longer than CYBOI lives
+ *
+ * transient:
+ * - stored in computer memory (RAM)
+ * - only accessible from within CYBOI
+ * - created and destroyed by CYBOI
+ * - not available anymore after CYBOI has been destroyed
+ *
+ * @param p0 the destination model (Hand over as reference!)
+ * @param p1 the destination model count
+ * @param p2 the destination model size
+ * @param p3 the destination details (Hand over as reference!)
+ * @param p4 the destination details count
+ * @param p5 the destination details size
+ * @param p6 the source model
+ * @param p7 the source model count
+ * @param p8 the source abstraction
+ * @param p9 the source abstraction count
+ * @param p10 the source channel
+ * @param p11 the source channel count
  */
-void receive_file_system_model(void* p0, void* p1, void* p2, void* p3, void* p4,
-    void* p5, void* p6, void* p7, void* p8);
+void receive_file_system_model(void* p0, void* p1, void* p2, void* p3, void* p4, void* p5,
+    void* p6, void* p7, void* p8, void* p9, void* p10, void* p11);
 
+/**
+ * Sets the compound element by name.
+ *
+ * @param p0 the compound
+ * @param p1 the compound count
+ * @param p2 the compound size
+ * @param p3 the name
+ * @param p4 the name count
+ * @param p5 the name size
+ * @param p6 the abstraction
+ * @param p7 the abstraction count
+ * @param p8 the abstraction size
+ * @param p9 the model
+ * @param p10 the model count
+ * @param p11 the model size
+ * @param p12 the details
+ * @param p13 the details count
+ * @param p14 the details size
+ */
 void set_compound_element_by_name(void* p0, void* p1, void* p2,
-    void* p3, void* p4, void* p5,
-    void* p6, void* p7, void* p8,
-    void* p9, void* p10, void* p11,
-    void* p12, void* p13, void* p14,
-    void* p15, void* p16, void* p17);
+    void* p3, void* p4, void* p5, void* p6, void* p7, void* p8,
+    void* p9, void* p10, void* p11, void* p12, void* p13, void* p14);
 
 //
 // Cybol property.
@@ -85,59 +119,59 @@ void set_compound_element_by_name(void* p0, void* p1, void* p2,
 void decode_cybol_property(void* p0, void* p1, void* p2, void* p3,
     void* p4, void* p5, void* p6, void* p7, void* p8) {
 
-    if (p8 != NULL_POINTER) {
+    if (p8 != *NULL_POINTER) {
 
         xmlNode* cn = (xmlNode*) p8;
 
-        if (p7 != NULL_POINTER) {
+        if (p7 != *NULL_POINTER) {
 
             int* mc = (int*) p7;
 
-            if (p6 != NULL_POINTER) {
+            if (p6 != *NULL_POINTER) {
 
                 void** m = (void**) p6;
 
-                if (p5 != NULL_POINTER) {
+                if (p5 != *NULL_POINTER) {
 
                     int* ac = (int*) p5;
 
-                    if (p4 != NULL_POINTER) {
+                    if (p4 != *NULL_POINTER) {
 
                         void** a = (void**) p4;
 
-                        if (p3 != NULL_POINTER) {
+                        if (p3 != *NULL_POINTER) {
 
                             int* cc = (int*) p3;
 
-                            if (p2 != NULL_POINTER) {
+                            if (p2 != *NULL_POINTER) {
 
                                 void** c = (void**) p2;
 
-                                if (p1 != NULL_POINTER) {
+                                if (p1 != *NULL_POINTER) {
 
                                     int* nc = (int*) p1;
 
-                                    if (p0 != NULL_POINTER) {
+                                    if (p0 != *NULL_POINTER) {
 
                                         void** n = (void**) p0;
 
                                         log_message_debug("Decode cybol property.");
 
-                                        if (cn != NULL_POINTER) {
+                                        if (cn != *NULL_POINTER) {
 
                                             // Determine first child node property.
                                             xmlAttr* p = cn->properties;
                                             // The property name.
-                                            void* pn = NULL_POINTER;
-                                            int pnc = 0;
+                                            void* pn = *NULL_POINTER;
+                                            int pnc = *NUMBER_0_INTEGER;
                                             // The property value.
-                                            xmlNode* pv = NULL_POINTER;
+                                            xmlNode* pv = (xmlNode*) *NULL_POINTER;
                                             // The comparison result.
-                                            int r = 0;
+                                            int r = *NUMBER_0_INTEGER;
 
-                                            while (1) {
+                                            while (*NUMBER_1_INTEGER) {
 
-                                                if (p == NULL_POINTER) {
+                                                if (p == *NULL_POINTER) {
 
                                                     break;
                                                 }
@@ -145,7 +179,7 @@ void decode_cybol_property(void* p0, void* p1, void* p2, void* p3,
                                                 // Get property value.
                                                 pv = p->children;
 
-                                                if (pv != NULL_POINTER) {
+                                                if (pv != *NULL_POINTER) {
 
                                                     // Get property name.
                                                     pn = (void*) p->name;
@@ -155,7 +189,7 @@ void decode_cybol_property(void* p0, void* p1, void* p2, void* p3,
 
                                                         compare_arrays(pn, (void*) &pnc, (void*) NAME_ATTRIBUTE, (void*) NAME_ATTRIBUTE_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-                                                        if (r == 1) {
+                                                        if (r == *NUMBER_1_INTEGER) {
 
                                                             // Get source name.
                                                             *n = pv->content;
@@ -163,11 +197,11 @@ void decode_cybol_property(void* p0, void* p1, void* p2, void* p3,
                                                         }
                                                     }
 
-                                                    if (r != 1) {
+                                                    if (r != *NUMBER_1_INTEGER) {
 
                                                         compare_arrays(pn, (void*) &pnc, (void*) CHANNEL_ATTRIBUTE, (void*) CHANNEL_ATTRIBUTE_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-                                                        if (r == 1) {
+                                                        if (r == *NUMBER_1_INTEGER) {
 
                                                             // Get source channel.
                                                             *c = pv->content;
@@ -175,11 +209,11 @@ void decode_cybol_property(void* p0, void* p1, void* p2, void* p3,
                                                         }
                                                     }
 
-                                                    if (r != 1) {
+                                                    if (r != *NUMBER_1_INTEGER) {
 
                                                         compare_arrays(pn, (void*) &pnc, (void*) ABSTRACTION_ATTRIBUTE, (void*) ABSTRACTION_ATTRIBUTE_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-                                                        if (r == 1) {
+                                                        if (r == *NUMBER_1_INTEGER) {
 
                                                             // Get source abstraction.
                                                             *a = pv->content;
@@ -187,11 +221,11 @@ void decode_cybol_property(void* p0, void* p1, void* p2, void* p3,
                                                         }
                                                     }
 
-                                                    if (r != 1) {
+                                                    if (r != *NUMBER_1_INTEGER) {
 
                                                         compare_arrays(pn, (void*) &pnc, (void*) MODEL_ATTRIBUTE, (void*) MODEL_ATTRIBUTE_COUNT, (void*) &r, (void*) CHARACTER_ARRAY);
 
-                                                        if (r == 1) {
+                                                        if (r == *NUMBER_1_INTEGER) {
 
                                                             // Get source model.
                                                             *m = pv->content;
@@ -200,12 +234,12 @@ void decode_cybol_property(void* p0, void* p1, void* p2, void* p3,
                                                     }
 
                                                     // Reset property name.
-                                                    pn = NULL_POINTER;
-                                                    pnc = 0;
+                                                    pn = *NULL_POINTER;
+                                                    pnc = *NUMBER_0_INTEGER;
                                                     // Reset property value.
-                                                    pv = NULL_POINTER;
+                                                    pv = (xmlNode*) *NULL_POINTER;
                                                     // Reset comparison result.
-                                                    r = 0;
+                                                    r = *NUMBER_0_INTEGER;
 
                                                 } else {
 
@@ -293,11 +327,11 @@ void encode_cybol_property(void* p0, void* p1, void* p2, void* p3, void* p4) {
  */
 void decode_cybol_node(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
-    if (p3 != NULL_POINTER) {
+    if (p3 != *NULL_POINTER) {
 
         xmlNode* s = (xmlNode*) p3;
 
-        if (p0 != NULL_POINTER) {
+        if (p0 != *NULL_POINTER) {
 
             void** d = (void**) p0;
 
@@ -306,39 +340,39 @@ void decode_cybol_node(void* p0, void* p1, void* p2, void* p3, void* p4) {
             // Determine first child node.
             xmlNode* c = s->children;
             // The child count.
-            int cc = 0;
+            int cc = *NUMBER_0_INTEGER;
             // The source name.
-            void* sn = NULL_POINTER;
-            int snc = 0;
+            void* sn = *NULL_POINTER;
+            int snc = *NUMBER_0_INTEGER;
             // The source channel.
-            void* sc = NULL_POINTER;
-            int scc = 0;
+            void* sc = *NULL_POINTER;
+            int scc = *NUMBER_0_INTEGER;
             // The source abstraction.
-            void* sa = NULL_POINTER;
-            int sac = 0;
+            void* sa = *NULL_POINTER;
+            int sac = *NUMBER_0_INTEGER;
             // The source model.
-            void* sm = NULL_POINTER;
-            int smc = 0;
+            void* sm = *NULL_POINTER;
+            int smc = *NUMBER_0_INTEGER;
             // The destination name.
-            void* dn = NULL_POINTER;
-            int* dnc = NULL_POINTER;
-            int* dns = NULL_POINTER;
+            void* dn = *NULL_POINTER;
+            int* dnc = (int*) *NULL_POINTER;
+            int* dns = (int*) *NULL_POINTER;
             // The destination abstraction.
-            void* da = NULL_POINTER;
-            int* dac = NULL_POINTER;
-            int* das = NULL_POINTER;
+            void* da = *NULL_POINTER;
+            int* dac = (int*) *NULL_POINTER;
+            int* das = (int*) *NULL_POINTER;
             // The destination model.
-            void* dm = NULL_POINTER;
-            int* dmc = NULL_POINTER;
-            int* dms = NULL_POINTER;
+            void* dm = *NULL_POINTER;
+            int* dmc = (int*) *NULL_POINTER;
+            int* dms = (int*) *NULL_POINTER;
             // The destination details.
-            void* dd = NULL_POINTER;
-            int* ddc = NULL_POINTER;
-            int* dds = NULL_POINTER;
+            void* dd = *NULL_POINTER;
+            int* ddc = (int*) *NULL_POINTER;
+            int* dds = (int*) *NULL_POINTER;
 
-            while (1) {
+            while (*NUMBER_1_INTEGER) {
 
-                if (c == NULL_POINTER) {
+                if (c == *NULL_POINTER) {
 
                     break;
                 }
@@ -362,10 +396,11 @@ void decode_cybol_node(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
                     // Create destination name.
                     allocate((void*) &dnc, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-                    *dnc = 0;
+                    *dnc = *NUMBER_0_INTEGER;
                     allocate((void*) &dns, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-                    *dns = 0;
+                    *dns = *NUMBER_0_INTEGER;
                     receive_file_system_model((void*) &dn, (void*) dnc, (void*) dns,
+                        *NULL_POINTER, *NULL_POINTER, *NULL_POINTER,
                         sn, (void*) &snc,
                         (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
                         (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
@@ -375,48 +410,46 @@ void decode_cybol_node(void* p0, void* p1, void* p2, void* p3, void* p4) {
 
                     // Create destination abstraction.
                     allocate((void*) &dac, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-                    *dac = 0;
+                    *dac = *NUMBER_0_INTEGER;
                     allocate((void*) &das, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-                    *das = 0;
+                    *das = *NUMBER_0_INTEGER;
                     receive_file_system_model((void*) &da, (void*) dac, (void*) das,
+                        *NULL_POINTER, *NULL_POINTER, *NULL_POINTER,
                         sa, (void*) &sac,
                         (void*) CHARACTER_VECTOR_ABSTRACTION, (void*) CHARACTER_VECTOR_ABSTRACTION_COUNT,
                         (void*) INLINE_CHANNEL, (void*) INLINE_CHANNEL_COUNT);
 
                     // Create destination model.
                     allocate((void*) &dmc, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-                    *dmc = 0;
+                    *dmc = *NUMBER_0_INTEGER;
                     allocate((void*) &dms, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-                    *dms = 0;
+                    *dms = *NUMBER_0_INTEGER;
                     receive_file_system_model((void*) &dm, (void*) dmc, (void*) dms,
+                        *NULL_POINTER, *NULL_POINTER, *NULL_POINTER,
                         sm, (void*) &smc,
                         sa, (void*) &sac,
                         sc, (void*) &scc);
 
-                    // If child node has children, then create details model for it.
-                    if (c->children != NULL_POINTER) {
+                    // Create details model.
+                    //
+                    // CAUTION! Do ALWAYS allocate the details, even if it has no entries!
+                    // This is because at runtime, properties may be assigned to the details
+                    // so that it MUST NOT be null.
+                    allocate((void*) &ddc, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
+                    *ddc = *NUMBER_0_INTEGER;
+                    allocate((void*) &dds, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
+                    *dds = *NUMBER_0_INTEGER;
+                    allocate((void*) &dd, (void*) dds, (void*) COMPOUND_ABSTRACTION, (void*) COMPOUND_ABSTRACTION_COUNT);
 
-                        // Create details model.
-                        allocate((void*) &ddc, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-                        *ddc = 0;
-                        allocate((void*) &dds, (void*) PRIMITIVE_COUNT, (void*) INTEGER_VECTOR_ABSTRACTION, (void*) INTEGER_VECTOR_ABSTRACTION_COUNT);
-                        *dds = 0;
-                        allocate((void*) &dd, (void*) dds,
-                            (void*) COMPOUND_ABSTRACTION, (void*) COMPOUND_ABSTRACTION_COUNT);
+                    // If child node has children, then create details model for it.
+                    if (c->children != *NULL_POINTER) {
 
                         // Decode child node children.
-                        decode_cybol_node((void*) &dd, (void*) ddc, (void*) dds,
-                            (void*) c, (void*) &cc);
-
-                        //?? Read details??
-                        // Filter out all tags with name attribute value "super" and
-                        // hand over model to create parts of super model.
-                        // Add all details to details model.
-                        // Do NOT add super tags to details model!
+                        decode_cybol_node((void*) &dd, (void*) ddc, (void*) dds, (void*) c, (void*) &cc);
                     }
 
                     // Add model to compound.
-                    set_compound_element_by_name(*d, p1, p2, NULL_POINTER, NULL_POINTER, NULL_POINTER,
+                    set_compound_element_by_name(*d, p1, p2,
                         dn, (void*) dnc, (void*) dns,
                         da, (void*) dac, (void*) das,
                         dm, (void*) dmc, (void*) dms,
@@ -430,33 +463,33 @@ void decode_cybol_node(void* p0, void* p1, void* p2, void* p3, void* p4) {
                     //?? no whole keeps a reference to it anymore?
 
                     // Reset source name.
-                    sn = NULL_POINTER;
-                    snc = 0;
+                    sn = *NULL_POINTER;
+                    snc = *NUMBER_0_INTEGER;
                     // Reset source channel.
-                    sc = NULL_POINTER;
-                    scc = 0;
+                    sc = *NULL_POINTER;
+                    scc = *NUMBER_0_INTEGER;
                     // Reset source abstraction.
-                    sa = NULL_POINTER;
-                    sac = 0;
+                    sa = *NULL_POINTER;
+                    sac = *NUMBER_0_INTEGER;
                     // Reset source model.
-                    sm = NULL_POINTER;
-                    smc = 0;
+                    sm = *NULL_POINTER;
+                    smc = *NUMBER_0_INTEGER;
                     // Reset destination name.
-                    dn = NULL_POINTER;
-                    dnc = NULL_POINTER;
-                    dns = NULL_POINTER;
+                    dn = *NULL_POINTER;
+                    dnc = (int*) *NULL_POINTER;
+                    dns = (int*) *NULL_POINTER;
                     // Reset destination abstraction.
-                    da = NULL_POINTER;
-                    dac = NULL_POINTER;
-                    das = NULL_POINTER;
+                    da = *NULL_POINTER;
+                    dac = (int*) *NULL_POINTER;
+                    das = (int*) *NULL_POINTER;
                     // Reset destination model.
-                    dm = NULL_POINTER;
-                    dmc = NULL_POINTER;
-                    dms = NULL_POINTER;
+                    dm = *NULL_POINTER;
+                    dmc = (int*) *NULL_POINTER;
+                    dms = (int*) *NULL_POINTER;
                     // Reset destination details.
-                    dd = NULL_POINTER;
-                    ddc = NULL_POINTER;
-                    dds = NULL_POINTER;
+                    dd = *NULL_POINTER;
+                    ddc = (int*) *NULL_POINTER;
+                    dds = (int*) *NULL_POINTER;
                 }
 
                 c = c->next;
@@ -505,13 +538,13 @@ void decode_cybol(void* p0, void* p1, void* p2, void* p3, void* p4) {
     //?? which must be deleted for the cyboi model,
     //?? or neglected in the "count" number!
 
-    if (p4 != NULL_POINTER) {
+    if (p4 != *NULL_POINTER) {
 
         int* sc = (int*) p4;
 
-        if (p3 != NULL_POINTER) {
+        if (p3 != *NULL_POINTER) {
 
-            if (p0 != NULL_POINTER) {
+            if (p0 != *NULL_POINTER) {
 
                 void** d = (void**) p0;
 
